/* -*- java -*-
 * (C) Copyright IBM Corp. 1997-1998  All rights reserved.
 *
 * US Government Users Restricted Rights Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * IBM will not be liable for any damages suffered by you as a result
 * of using the Program. In no event will IBM be liable for any
 * special, indirect or consequential damages or lost profits even if
 * IBM has been advised of the possibility of their occurrence. IBM
 * will not be liable for any third party claims against you.
 */

package com.ibm.xml.parser;

import java.io.BufferedReader;
import java.io.InputStreamReader;

/**
 *
 * @version 1.1
 * @author TAMURA Kent &lt;kent@trl.ibm.co.jp&gt;
 */
public final class XMLChar {
    private static final short M_CHAR = 1<<0;
    private static final short M_LETTER = 1<<1;
    private static final short M_SPACE = 1<<2;
    private static final short M_NAMECHAR = 1<<3;

    /*
    private static final short M_BASECHAR = 1<<4;
    private static final short M_IDEOGRAPHIC = 1<<5;
    private static final short M_COMBININGCHAR = 1<<6;
    private static final short M_IGNORABLE = 1<<7;
    private static final short M_EXTENDER = 1<<8;
    private static final short M_DIGIT = 1<<9;
    */
    public static final String S_SPACES = " \t\r\n";

    private XMLChar() {
    }

    public static boolean isChar(int ch) {
        if (ch >= 0x110000 || ch < 0)  return false;
        if (ch >= 0x010000)  return true;
	return ch < 128 ? 0 != (M_CHAR & s_asciiflags[ch])
            : 0 != (M_CHAR & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }

    public static boolean isSpace(int ch) {
        /*
        if (ch >= 0x10000 || ch < 0)  return false;
	return ch < 128 ? 0 != (M_SPACE & s_asciiflags[ch])
            : 0 != (M_SPACE & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
        if (ch >= 0x10000 || ch < 0)  return false;
        */
	return 0 <= ch && ch < 128 && 0 != (M_SPACE & s_asciiflags[ch]);
    }
/*
    public static boolean isDigit(char ch) {
	return 0 != (M_DIGIT & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
*/
    public static boolean isLetter(int ch) {
        if (ch >= 0x10000 || ch < 0)  return false;
	return ch < 128 ? 0 != (M_LETTER & s_asciiflags[ch])
            : 0 != (M_LETTER & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
/*
    public static boolean isBaseChar(char ch) {
	return 0 != (M_BASECHAR & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
    public static boolean isIdeographic(char ch) {
	return 0 != (M_IDEOGRAPHIC & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
    public static boolean isCombiningChar(char ch) {
	return 0 != (M_COMBININGCHAR & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
    public static boolean isIgnorable(char ch) {
	return 0 != (M_IGNORABLE & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
    public static boolean isExtender(char ch) {
	return 0 != (M_EXTENDER & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }
*/
    public static boolean isNameChar(int ch) {
        if (ch >= 0x10000 || ch < 0)  return false;
	return ch < 128 ? 0 != (M_NAMECHAR & s_asciiflags[ch])
            : 0 != (M_NAMECHAR & XMLCharTable.s_flags[(XMLCharTable.s_blocks[ch>>8]<<8)+(ch&0xff)]);
    }

    private static final byte[] s_asciiflags = {
	0x0,		/* 0,0 */
	0x0,		/* 0,1 */
	0x0,		/* 0,2 */
	0x0,		/* 0,3 */
	0x0,		/* 0,4 */
	0x0,		/* 0,5 */
	0x0,		/* 0,6 */
	0x0,		/* 0,7 */
	0x0,		/* 0,8 */
	0x5,		/* 0,9 */
	0x5,		/* 0,10 */
	0x0,		/* 0,11 */
	0x0,		/* 0,12 */
	0x5,		/* 0,13 */
	0x0,		/* 0,14 */
	0x0,		/* 0,15 */
	0x0,		/* 0,16 */
	0x0,		/* 0,17 */
	0x0,		/* 0,18 */
	0x0,		/* 0,19 */
	0x0,		/* 0,20 */
	0x0,		/* 0,21 */
	0x0,		/* 0,22 */
	0x0,		/* 0,23 */
	0x0,		/* 0,24 */
	0x0,		/* 0,25 */
	0x0,		/* 0,26 */
	0x0,		/* 0,27 */
	0x0,		/* 0,28 */
	0x0,		/* 0,29 */
	0x0,		/* 0,30 */
	0x0,		/* 0,31 */
	0x5,		/* 0,32 */
	0x1,		/* 0,33 */
	0x1,		/* 0,34 */
	0x1,		/* 0,35 */
	0x1,		/* 0,36 */
	0x1,		/* 0,37 */
	0x1,		/* 0,38 */
	0x1,		/* 0,39 */
	0x1,		/* 0,40 */
	0x1,		/* 0,41 */
	0x1,		/* 0,42 */
	0x1,		/* 0,43 */
	0x1,		/* 0,44 */
	0x9,		/* 0,45 */
	0x9,		/* 0,46 */
	0x1,		/* 0,47 */
	0x9,		/* 0,48 */
	0x9,		/* 0,49 */
	0x9,		/* 0,50 */
	0x9,		/* 0,51 */
	0x9,		/* 0,52 */
	0x9,		/* 0,53 */
	0x9,		/* 0,54 */
	0x9,		/* 0,55 */
	0x9,		/* 0,56 */
	0x9,		/* 0,57 */
	0x9,		/* 0,58 */
	0x1,		/* 0,59 */
	0x1,		/* 0,60 */
	0x1,		/* 0,61 */
	0x1,		/* 0,62 */
	0x1,		/* 0,63 */
	0x1,		/* 0,64 */
	0xb,		/* 0,65 */
	0xb,		/* 0,66 */
	0xb,		/* 0,67 */
	0xb,		/* 0,68 */
	0xb,		/* 0,69 */
	0xb,		/* 0,70 */
	0xb,		/* 0,71 */
	0xb,		/* 0,72 */
	0xb,		/* 0,73 */
	0xb,		/* 0,74 */
	0xb,		/* 0,75 */
	0xb,		/* 0,76 */
	0xb,		/* 0,77 */
	0xb,		/* 0,78 */
	0xb,		/* 0,79 */
	0xb,		/* 0,80 */
	0xb,		/* 0,81 */
	0xb,		/* 0,82 */
	0xb,		/* 0,83 */
	0xb,		/* 0,84 */
	0xb,		/* 0,85 */
	0xb,		/* 0,86 */
	0xb,		/* 0,87 */
	0xb,		/* 0,88 */
	0xb,		/* 0,89 */
	0xb,		/* 0,90 */
	0x1,		/* 0,91 */
	0x1,		/* 0,92 */
	0x1,		/* 0,93 */
	0x1,		/* 0,94 */
	0x9,		/* 0,95 */
	0x1,		/* 0,96 */
	0xb,		/* 0,97 */
	0xb,		/* 0,98 */
	0xb,		/* 0,99 */
	0xb,		/* 0,100 */
	0xb,		/* 0,101 */
	0xb,		/* 0,102 */
	0xb,		/* 0,103 */
	0xb,		/* 0,104 */
	0xb,		/* 0,105 */
	0xb,		/* 0,106 */
	0xb,		/* 0,107 */
	0xb,		/* 0,108 */
	0xb,		/* 0,109 */
	0xb,		/* 0,110 */
	0xb,		/* 0,111 */
	0xb,		/* 0,112 */
	0xb,		/* 0,113 */
	0xb,		/* 0,114 */
	0xb,		/* 0,115 */
	0xb,		/* 0,116 */
	0xb,		/* 0,117 */
	0xb,		/* 0,118 */
	0xb,		/* 0,119 */
	0xb,		/* 0,120 */
	0xb,		/* 0,121 */
	0xb,		/* 0,122 */
	0x1,		/* 0,123 */
	0x1,		/* 0,124 */
	0x1,		/* 0,125 */
	0x1,		/* 0,126 */
	0x1,		/* 0,127 */
    };
}

class XMLCharTable {
    static final byte[] s_flags = {
	0x0,		/* 0,0 */
	0x0,		/* 0,1 */
	0x0,		/* 0,2 */
	0x0,		/* 0,3 */
	0x0,		/* 0,4 */
	0x0,		/* 0,5 */
	0x0,		/* 0,6 */
	0x0,		/* 0,7 */
	0x0,		/* 0,8 */
	0x5,		/* 0,9 */
	0x5,		/* 0,10 */
	0x0,		/* 0,11 */
	0x0,		/* 0,12 */
	0x5,		/* 0,13 */
	0x0,		/* 0,14 */
	0x0,		/* 0,15 */
	0x0,		/* 0,16 */
	0x0,		/* 0,17 */
	0x0,		/* 0,18 */
	0x0,		/* 0,19 */
	0x0,		/* 0,20 */
	0x0,		/* 0,21 */
	0x0,		/* 0,22 */
	0x0,		/* 0,23 */
	0x0,		/* 0,24 */
	0x0,		/* 0,25 */
	0x0,		/* 0,26 */
	0x0,		/* 0,27 */
	0x0,		/* 0,28 */
	0x0,		/* 0,29 */
	0x0,		/* 0,30 */
	0x0,		/* 0,31 */
	0x5,		/* 0,32 */
	0x1,		/* 0,33 */
	0x1,		/* 0,34 */
	0x1,		/* 0,35 */
	0x1,		/* 0,36 */
	0x1,		/* 0,37 */
	0x1,		/* 0,38 */
	0x1,		/* 0,39 */
	0x1,		/* 0,40 */
	0x1,		/* 0,41 */
	0x1,		/* 0,42 */
	0x1,		/* 0,43 */
	0x1,		/* 0,44 */
	0x9,		/* 0,45 */
	0x9,		/* 0,46 */
	0x1,		/* 0,47 */
	0x9,		/* 0,48 */
	0x9,		/* 0,49 */
	0x9,		/* 0,50 */
	0x9,		/* 0,51 */
	0x9,		/* 0,52 */
	0x9,		/* 0,53 */
	0x9,		/* 0,54 */
	0x9,		/* 0,55 */
	0x9,		/* 0,56 */
	0x9,		/* 0,57 */
	0x9,		/* 0,58 */
	0x1,		/* 0,59 */
	0x1,		/* 0,60 */
	0x1,		/* 0,61 */
	0x1,		/* 0,62 */
	0x1,		/* 0,63 */
	0x1,		/* 0,64 */
	0xb,		/* 0,65 */
	0xb,		/* 0,66 */
	0xb,		/* 0,67 */
	0xb,		/* 0,68 */
	0xb,		/* 0,69 */
	0xb,		/* 0,70 */
	0xb,		/* 0,71 */
	0xb,		/* 0,72 */
	0xb,		/* 0,73 */
	0xb,		/* 0,74 */
	0xb,		/* 0,75 */
	0xb,		/* 0,76 */
	0xb,		/* 0,77 */
	0xb,		/* 0,78 */
	0xb,		/* 0,79 */
	0xb,		/* 0,80 */
	0xb,		/* 0,81 */
	0xb,		/* 0,82 */
	0xb,		/* 0,83 */
	0xb,		/* 0,84 */
	0xb,		/* 0,85 */
	0xb,		/* 0,86 */
	0xb,		/* 0,87 */
	0xb,		/* 0,88 */
	0xb,		/* 0,89 */
	0xb,		/* 0,90 */
	0x1,		/* 0,91 */
	0x1,		/* 0,92 */
	0x1,		/* 0,93 */
	0x1,		/* 0,94 */
	0x9,		/* 0,95 */
	0x1,		/* 0,96 */
	0xb,		/* 0,97 */
	0xb,		/* 0,98 */
	0xb,		/* 0,99 */
	0xb,		/* 0,100 */
	0xb,		/* 0,101 */
	0xb,		/* 0,102 */
	0xb,		/* 0,103 */
	0xb,		/* 0,104 */
	0xb,		/* 0,105 */
	0xb,		/* 0,106 */
	0xb,		/* 0,107 */
	0xb,		/* 0,108 */
	0xb,		/* 0,109 */
	0xb,		/* 0,110 */
	0xb,		/* 0,111 */
	0xb,		/* 0,112 */
	0xb,		/* 0,113 */
	0xb,		/* 0,114 */
	0xb,		/* 0,115 */
	0xb,		/* 0,116 */
	0xb,		/* 0,117 */
	0xb,		/* 0,118 */
	0xb,		/* 0,119 */
	0xb,		/* 0,120 */
	0xb,		/* 0,121 */
	0xb,		/* 0,122 */
	0x1,		/* 0,123 */
	0x1,		/* 0,124 */
	0x1,		/* 0,125 */
	0x1,		/* 0,126 */
	0x1,		/* 0,127 */
	0x1,		/* 0,128 */
	0x1,		/* 0,129 */
	0x1,		/* 0,130 */
	0x1,		/* 0,131 */
	0x1,		/* 0,132 */
	0x1,		/* 0,133 */
	0x1,		/* 0,134 */
	0x1,		/* 0,135 */
	0x1,		/* 0,136 */
	0x1,		/* 0,137 */
	0x1,		/* 0,138 */
	0x1,		/* 0,139 */
	0x1,		/* 0,140 */
	0x1,		/* 0,141 */
	0x1,		/* 0,142 */
	0x1,		/* 0,143 */
	0x1,		/* 0,144 */
	0x1,		/* 0,145 */
	0x1,		/* 0,146 */
	0x1,		/* 0,147 */
	0x1,		/* 0,148 */
	0x1,		/* 0,149 */
	0x1,		/* 0,150 */
	0x1,		/* 0,151 */
	0x1,		/* 0,152 */
	0x1,		/* 0,153 */
	0x1,		/* 0,154 */
	0x1,		/* 0,155 */
	0x1,		/* 0,156 */
	0x1,		/* 0,157 */
	0x1,		/* 0,158 */
	0x1,		/* 0,159 */
	0x1,		/* 0,160 */
	0x1,		/* 0,161 */
	0x1,		/* 0,162 */
	0x1,		/* 0,163 */
	0x1,		/* 0,164 */
	0x1,		/* 0,165 */
	0x1,		/* 0,166 */
	0x1,		/* 0,167 */
	0x1,		/* 0,168 */
	0x1,		/* 0,169 */
	0x1,		/* 0,170 */
	0x1,		/* 0,171 */
	0x1,		/* 0,172 */
	0x1,		/* 0,173 */
	0x1,		/* 0,174 */
	0x1,		/* 0,175 */
	0x1,		/* 0,176 */
	0x1,		/* 0,177 */
	0x1,		/* 0,178 */
	0x1,		/* 0,179 */
	0x1,		/* 0,180 */
	0x1,		/* 0,181 */
	0x1,		/* 0,182 */
	0x9,		/* 0,183 */
	0x1,		/* 0,184 */
	0x1,		/* 0,185 */
	0x1,		/* 0,186 */
	0x1,		/* 0,187 */
	0x1,		/* 0,188 */
	0x1,		/* 0,189 */
	0x1,		/* 0,190 */
	0x1,		/* 0,191 */
	0xb,		/* 0,192 */
	0xb,		/* 0,193 */
	0xb,		/* 0,194 */
	0xb,		/* 0,195 */
	0xb,		/* 0,196 */
	0xb,		/* 0,197 */
	0xb,		/* 0,198 */
	0xb,		/* 0,199 */
	0xb,		/* 0,200 */
	0xb,		/* 0,201 */
	0xb,		/* 0,202 */
	0xb,		/* 0,203 */
	0xb,		/* 0,204 */
	0xb,		/* 0,205 */
	0xb,		/* 0,206 */
	0xb,		/* 0,207 */
	0xb,		/* 0,208 */
	0xb,		/* 0,209 */
	0xb,		/* 0,210 */
	0xb,		/* 0,211 */
	0xb,		/* 0,212 */
	0xb,		/* 0,213 */
	0xb,		/* 0,214 */
	0x1,		/* 0,215 */
	0xb,		/* 0,216 */
	0xb,		/* 0,217 */
	0xb,		/* 0,218 */
	0xb,		/* 0,219 */
	0xb,		/* 0,220 */
	0xb,		/* 0,221 */
	0xb,		/* 0,222 */
	0xb,		/* 0,223 */
	0xb,		/* 0,224 */
	0xb,		/* 0,225 */
	0xb,		/* 0,226 */
	0xb,		/* 0,227 */
	0xb,		/* 0,228 */
	0xb,		/* 0,229 */
	0xb,		/* 0,230 */
	0xb,		/* 0,231 */
	0xb,		/* 0,232 */
	0xb,		/* 0,233 */
	0xb,		/* 0,234 */
	0xb,		/* 0,235 */
	0xb,		/* 0,236 */
	0xb,		/* 0,237 */
	0xb,		/* 0,238 */
	0xb,		/* 0,239 */
	0xb,		/* 0,240 */
	0xb,		/* 0,241 */
	0xb,		/* 0,242 */
	0xb,		/* 0,243 */
	0xb,		/* 0,244 */
	0xb,		/* 0,245 */
	0xb,		/* 0,246 */
	0x1,		/* 0,247 */
	0xb,		/* 0,248 */
	0xb,		/* 0,249 */
	0xb,		/* 0,250 */
	0xb,		/* 0,251 */
	0xb,		/* 0,252 */
	0xb,		/* 0,253 */
	0xb,		/* 0,254 */
	0xb,		/* 0,255 */
	0xb,		/* 1,0 */
	0xb,		/* 1,1 */
	0xb,		/* 1,2 */
	0xb,		/* 1,3 */
	0xb,		/* 1,4 */
	0xb,		/* 1,5 */
	0xb,		/* 1,6 */
	0xb,		/* 1,7 */
	0xb,		/* 1,8 */
	0xb,		/* 1,9 */
	0xb,		/* 1,10 */
	0xb,		/* 1,11 */
	0xb,		/* 1,12 */
	0xb,		/* 1,13 */
	0xb,		/* 1,14 */
	0xb,		/* 1,15 */
	0xb,		/* 1,16 */
	0xb,		/* 1,17 */
	0xb,		/* 1,18 */
	0xb,		/* 1,19 */
	0xb,		/* 1,20 */
	0xb,		/* 1,21 */
	0xb,		/* 1,22 */
	0xb,		/* 1,23 */
	0xb,		/* 1,24 */
	0xb,		/* 1,25 */
	0xb,		/* 1,26 */
	0xb,		/* 1,27 */
	0xb,		/* 1,28 */
	0xb,		/* 1,29 */
	0xb,		/* 1,30 */
	0xb,		/* 1,31 */
	0xb,		/* 1,32 */
	0xb,		/* 1,33 */
	0xb,		/* 1,34 */
	0xb,		/* 1,35 */
	0xb,		/* 1,36 */
	0xb,		/* 1,37 */
	0xb,		/* 1,38 */
	0xb,		/* 1,39 */
	0xb,		/* 1,40 */
	0xb,		/* 1,41 */
	0xb,		/* 1,42 */
	0xb,		/* 1,43 */
	0xb,		/* 1,44 */
	0xb,		/* 1,45 */
	0xb,		/* 1,46 */
	0xb,		/* 1,47 */
	0xb,		/* 1,48 */
	0xb,		/* 1,49 */
	0x1,		/* 1,50 */
	0x1,		/* 1,51 */
	0xb,		/* 1,52 */
	0xb,		/* 1,53 */
	0xb,		/* 1,54 */
	0xb,		/* 1,55 */
	0xb,		/* 1,56 */
	0xb,		/* 1,57 */
	0xb,		/* 1,58 */
	0xb,		/* 1,59 */
	0xb,		/* 1,60 */
	0xb,		/* 1,61 */
	0xb,		/* 1,62 */
	0x1,		/* 1,63 */
	0x1,		/* 1,64 */
	0xb,		/* 1,65 */
	0xb,		/* 1,66 */
	0xb,		/* 1,67 */
	0xb,		/* 1,68 */
	0xb,		/* 1,69 */
	0xb,		/* 1,70 */
	0xb,		/* 1,71 */
	0xb,		/* 1,72 */
	0x1,		/* 1,73 */
	0xb,		/* 1,74 */
	0xb,		/* 1,75 */
	0xb,		/* 1,76 */
	0xb,		/* 1,77 */
	0xb,		/* 1,78 */
	0xb,		/* 1,79 */
	0xb,		/* 1,80 */
	0xb,		/* 1,81 */
	0xb,		/* 1,82 */
	0xb,		/* 1,83 */
	0xb,		/* 1,84 */
	0xb,		/* 1,85 */
	0xb,		/* 1,86 */
	0xb,		/* 1,87 */
	0xb,		/* 1,88 */
	0xb,		/* 1,89 */
	0xb,		/* 1,90 */
	0xb,		/* 1,91 */
	0xb,		/* 1,92 */
	0xb,		/* 1,93 */
	0xb,		/* 1,94 */
	0xb,		/* 1,95 */
	0xb,		/* 1,96 */
	0xb,		/* 1,97 */
	0xb,		/* 1,98 */
	0xb,		/* 1,99 */
	0xb,		/* 1,100 */
	0xb,		/* 1,101 */
	0xb,		/* 1,102 */
	0xb,		/* 1,103 */
	0xb,		/* 1,104 */
	0xb,		/* 1,105 */
	0xb,		/* 1,106 */
	0xb,		/* 1,107 */
	0xb,		/* 1,108 */
	0xb,		/* 1,109 */
	0xb,		/* 1,110 */
	0xb,		/* 1,111 */
	0xb,		/* 1,112 */
	0xb,		/* 1,113 */
	0xb,		/* 1,114 */
	0xb,		/* 1,115 */
	0xb,		/* 1,116 */
	0xb,		/* 1,117 */
	0xb,		/* 1,118 */
	0xb,		/* 1,119 */
	0xb,		/* 1,120 */
	0xb,		/* 1,121 */
	0xb,		/* 1,122 */
	0xb,		/* 1,123 */
	0xb,		/* 1,124 */
	0xb,		/* 1,125 */
	0xb,		/* 1,126 */
	0x1,		/* 1,127 */
	0xb,		/* 1,128 */
	0xb,		/* 1,129 */
	0xb,		/* 1,130 */
	0xb,		/* 1,131 */
	0xb,		/* 1,132 */
	0xb,		/* 1,133 */
	0xb,		/* 1,134 */
	0xb,		/* 1,135 */
	0xb,		/* 1,136 */
	0xb,		/* 1,137 */
	0xb,		/* 1,138 */
	0xb,		/* 1,139 */
	0xb,		/* 1,140 */
	0xb,		/* 1,141 */
	0xb,		/* 1,142 */
	0xb,		/* 1,143 */
	0xb,		/* 1,144 */
	0xb,		/* 1,145 */
	0xb,		/* 1,146 */
	0xb,		/* 1,147 */
	0xb,		/* 1,148 */
	0xb,		/* 1,149 */
	0xb,		/* 1,150 */
	0xb,		/* 1,151 */
	0xb,		/* 1,152 */
	0xb,		/* 1,153 */
	0xb,		/* 1,154 */
	0xb,		/* 1,155 */
	0xb,		/* 1,156 */
	0xb,		/* 1,157 */
	0xb,		/* 1,158 */
	0xb,		/* 1,159 */
	0xb,		/* 1,160 */
	0xb,		/* 1,161 */
	0xb,		/* 1,162 */
	0xb,		/* 1,163 */
	0xb,		/* 1,164 */
	0xb,		/* 1,165 */
	0xb,		/* 1,166 */
	0xb,		/* 1,167 */
	0xb,		/* 1,168 */
	0xb,		/* 1,169 */
	0xb,		/* 1,170 */
	0xb,		/* 1,171 */
	0xb,		/* 1,172 */
	0xb,		/* 1,173 */
	0xb,		/* 1,174 */
	0xb,		/* 1,175 */
	0xb,		/* 1,176 */
	0xb,		/* 1,177 */
	0xb,		/* 1,178 */
	0xb,		/* 1,179 */
	0xb,		/* 1,180 */
	0xb,		/* 1,181 */
	0xb,		/* 1,182 */
	0xb,		/* 1,183 */
	0xb,		/* 1,184 */
	0xb,		/* 1,185 */
	0xb,		/* 1,186 */
	0xb,		/* 1,187 */
	0xb,		/* 1,188 */
	0xb,		/* 1,189 */
	0xb,		/* 1,190 */
	0xb,		/* 1,191 */
	0xb,		/* 1,192 */
	0xb,		/* 1,193 */
	0xb,		/* 1,194 */
	0xb,		/* 1,195 */
	0x1,		/* 1,196 */
	0x1,		/* 1,197 */
	0x1,		/* 1,198 */
	0x1,		/* 1,199 */
	0x1,		/* 1,200 */
	0x1,		/* 1,201 */
	0x1,		/* 1,202 */
	0x1,		/* 1,203 */
	0x1,		/* 1,204 */
	0xb,		/* 1,205 */
	0xb,		/* 1,206 */
	0xb,		/* 1,207 */
	0xb,		/* 1,208 */
	0xb,		/* 1,209 */
	0xb,		/* 1,210 */
	0xb,		/* 1,211 */
	0xb,		/* 1,212 */
	0xb,		/* 1,213 */
	0xb,		/* 1,214 */
	0xb,		/* 1,215 */
	0xb,		/* 1,216 */
	0xb,		/* 1,217 */
	0xb,		/* 1,218 */
	0xb,		/* 1,219 */
	0xb,		/* 1,220 */
	0xb,		/* 1,221 */
	0xb,		/* 1,222 */
	0xb,		/* 1,223 */
	0xb,		/* 1,224 */
	0xb,		/* 1,225 */
	0xb,		/* 1,226 */
	0xb,		/* 1,227 */
	0xb,		/* 1,228 */
	0xb,		/* 1,229 */
	0xb,		/* 1,230 */
	0xb,		/* 1,231 */
	0xb,		/* 1,232 */
	0xb,		/* 1,233 */
	0xb,		/* 1,234 */
	0xb,		/* 1,235 */
	0xb,		/* 1,236 */
	0xb,		/* 1,237 */
	0xb,		/* 1,238 */
	0xb,		/* 1,239 */
	0xb,		/* 1,240 */
	0x1,		/* 1,241 */
	0x1,		/* 1,242 */
	0x1,		/* 1,243 */
	0xb,		/* 1,244 */
	0xb,		/* 1,245 */
	0x1,		/* 1,246 */
	0x1,		/* 1,247 */
	0x1,		/* 1,248 */
	0x1,		/* 1,249 */
	0xb,		/* 1,250 */
	0xb,		/* 1,251 */
	0xb,		/* 1,252 */
	0xb,		/* 1,253 */
	0xb,		/* 1,254 */
	0xb,		/* 1,255 */
	0xb,		/* 2,0 */
	0xb,		/* 2,1 */
	0xb,		/* 2,2 */
	0xb,		/* 2,3 */
	0xb,		/* 2,4 */
	0xb,		/* 2,5 */
	0xb,		/* 2,6 */
	0xb,		/* 2,7 */
	0xb,		/* 2,8 */
	0xb,		/* 2,9 */
	0xb,		/* 2,10 */
	0xb,		/* 2,11 */
	0xb,		/* 2,12 */
	0xb,		/* 2,13 */
	0xb,		/* 2,14 */
	0xb,		/* 2,15 */
	0xb,		/* 2,16 */
	0xb,		/* 2,17 */
	0xb,		/* 2,18 */
	0xb,		/* 2,19 */
	0xb,		/* 2,20 */
	0xb,		/* 2,21 */
	0xb,		/* 2,22 */
	0xb,		/* 2,23 */
	0x1,		/* 2,24 */
	0x1,		/* 2,25 */
	0x1,		/* 2,26 */
	0x1,		/* 2,27 */
	0x1,		/* 2,28 */
	0x1,		/* 2,29 */
	0x1,		/* 2,30 */
	0x1,		/* 2,31 */
	0x1,		/* 2,32 */
	0x1,		/* 2,33 */
	0x1,		/* 2,34 */
	0x1,		/* 2,35 */
	0x1,		/* 2,36 */
	0x1,		/* 2,37 */
	0x1,		/* 2,38 */
	0x1,		/* 2,39 */
	0x1,		/* 2,40 */
	0x1,		/* 2,41 */
	0x1,		/* 2,42 */
	0x1,		/* 2,43 */
	0x1,		/* 2,44 */
	0x1,		/* 2,45 */
	0x1,		/* 2,46 */
	0x1,		/* 2,47 */
	0x1,		/* 2,48 */
	0x1,		/* 2,49 */
	0x1,		/* 2,50 */
	0x1,		/* 2,51 */
	0x1,		/* 2,52 */
	0x1,		/* 2,53 */
	0x1,		/* 2,54 */
	0x1,		/* 2,55 */
	0x1,		/* 2,56 */
	0x1,		/* 2,57 */
	0x1,		/* 2,58 */
	0x1,		/* 2,59 */
	0x1,		/* 2,60 */
	0x1,		/* 2,61 */
	0x1,		/* 2,62 */
	0x1,		/* 2,63 */
	0x1,		/* 2,64 */
	0x1,		/* 2,65 */
	0x1,		/* 2,66 */
	0x1,		/* 2,67 */
	0x1,		/* 2,68 */
	0x1,		/* 2,69 */
	0x1,		/* 2,70 */
	0x1,		/* 2,71 */
	0x1,		/* 2,72 */
	0x1,		/* 2,73 */
	0x1,		/* 2,74 */
	0x1,		/* 2,75 */
	0x1,		/* 2,76 */
	0x1,		/* 2,77 */
	0x1,		/* 2,78 */
	0x1,		/* 2,79 */
	0xb,		/* 2,80 */
	0xb,		/* 2,81 */
	0xb,		/* 2,82 */
	0xb,		/* 2,83 */
	0xb,		/* 2,84 */
	0xb,		/* 2,85 */
	0xb,		/* 2,86 */
	0xb,		/* 2,87 */
	0xb,		/* 2,88 */
	0xb,		/* 2,89 */
	0xb,		/* 2,90 */
	0xb,		/* 2,91 */
	0xb,		/* 2,92 */
	0xb,		/* 2,93 */
	0xb,		/* 2,94 */
	0xb,		/* 2,95 */
	0xb,		/* 2,96 */
	0xb,		/* 2,97 */
	0xb,		/* 2,98 */
	0xb,		/* 2,99 */
	0xb,		/* 2,100 */
	0xb,		/* 2,101 */
	0xb,		/* 2,102 */
	0xb,		/* 2,103 */
	0xb,		/* 2,104 */
	0xb,		/* 2,105 */
	0xb,		/* 2,106 */
	0xb,		/* 2,107 */
	0xb,		/* 2,108 */
	0xb,		/* 2,109 */
	0xb,		/* 2,110 */
	0xb,		/* 2,111 */
	0xb,		/* 2,112 */
	0xb,		/* 2,113 */
	0xb,		/* 2,114 */
	0xb,		/* 2,115 */
	0xb,		/* 2,116 */
	0xb,		/* 2,117 */
	0xb,		/* 2,118 */
	0xb,		/* 2,119 */
	0xb,		/* 2,120 */
	0xb,		/* 2,121 */
	0xb,		/* 2,122 */
	0xb,		/* 2,123 */
	0xb,		/* 2,124 */
	0xb,		/* 2,125 */
	0xb,		/* 2,126 */
	0xb,		/* 2,127 */
	0xb,		/* 2,128 */
	0xb,		/* 2,129 */
	0xb,		/* 2,130 */
	0xb,		/* 2,131 */
	0xb,		/* 2,132 */
	0xb,		/* 2,133 */
	0xb,		/* 2,134 */
	0xb,		/* 2,135 */
	0xb,		/* 2,136 */
	0xb,		/* 2,137 */
	0xb,		/* 2,138 */
	0xb,		/* 2,139 */
	0xb,		/* 2,140 */
	0xb,		/* 2,141 */
	0xb,		/* 2,142 */
	0xb,		/* 2,143 */
	0xb,		/* 2,144 */
	0xb,		/* 2,145 */
	0xb,		/* 2,146 */
	0xb,		/* 2,147 */
	0xb,		/* 2,148 */
	0xb,		/* 2,149 */
	0xb,		/* 2,150 */
	0xb,		/* 2,151 */
	0xb,		/* 2,152 */
	0xb,		/* 2,153 */
	0xb,		/* 2,154 */
	0xb,		/* 2,155 */
	0xb,		/* 2,156 */
	0xb,		/* 2,157 */
	0xb,		/* 2,158 */
	0xb,		/* 2,159 */
	0xb,		/* 2,160 */
	0xb,		/* 2,161 */
	0xb,		/* 2,162 */
	0xb,		/* 2,163 */
	0xb,		/* 2,164 */
	0xb,		/* 2,165 */
	0xb,		/* 2,166 */
	0xb,		/* 2,167 */
	0xb,		/* 2,168 */
	0x1,		/* 2,169 */
	0x1,		/* 2,170 */
	0x1,		/* 2,171 */
	0x1,		/* 2,172 */
	0x1,		/* 2,173 */
	0x1,		/* 2,174 */
	0x1,		/* 2,175 */
	0x1,		/* 2,176 */
	0x1,		/* 2,177 */
	0x1,		/* 2,178 */
	0x1,		/* 2,179 */
	0x1,		/* 2,180 */
	0x1,		/* 2,181 */
	0x1,		/* 2,182 */
	0x1,		/* 2,183 */
	0x1,		/* 2,184 */
	0x1,		/* 2,185 */
	0x1,		/* 2,186 */
	0xb,		/* 2,187 */
	0xb,		/* 2,188 */
	0xb,		/* 2,189 */
	0xb,		/* 2,190 */
	0xb,		/* 2,191 */
	0xb,		/* 2,192 */
	0xb,		/* 2,193 */
	0x1,		/* 2,194 */
	0x1,		/* 2,195 */
	0x1,		/* 2,196 */
	0x1,		/* 2,197 */
	0x1,		/* 2,198 */
	0x1,		/* 2,199 */
	0x1,		/* 2,200 */
	0x1,		/* 2,201 */
	0x1,		/* 2,202 */
	0x1,		/* 2,203 */
	0x1,		/* 2,204 */
	0x1,		/* 2,205 */
	0x1,		/* 2,206 */
	0x1,		/* 2,207 */
	0x9,		/* 2,208 */
	0x9,		/* 2,209 */
	0x1,		/* 2,210 */
	0x1,		/* 2,211 */
	0x1,		/* 2,212 */
	0x1,		/* 2,213 */
	0x1,		/* 2,214 */
	0x1,		/* 2,215 */
	0x1,		/* 2,216 */
	0x1,		/* 2,217 */
	0x1,		/* 2,218 */
	0x1,		/* 2,219 */
	0x1,		/* 2,220 */
	0x1,		/* 2,221 */
	0x1,		/* 2,222 */
	0x1,		/* 2,223 */
	0x1,		/* 2,224 */
	0x1,		/* 2,225 */
	0x1,		/* 2,226 */
	0x1,		/* 2,227 */
	0x1,		/* 2,228 */
	0x1,		/* 2,229 */
	0x1,		/* 2,230 */
	0x1,		/* 2,231 */
	0x1,		/* 2,232 */
	0x1,		/* 2,233 */
	0x1,		/* 2,234 */
	0x1,		/* 2,235 */
	0x1,		/* 2,236 */
	0x1,		/* 2,237 */
	0x1,		/* 2,238 */
	0x1,		/* 2,239 */
	0x1,		/* 2,240 */
	0x1,		/* 2,241 */
	0x1,		/* 2,242 */
	0x1,		/* 2,243 */
	0x1,		/* 2,244 */
	0x1,		/* 2,245 */
	0x1,		/* 2,246 */
	0x1,		/* 2,247 */
	0x1,		/* 2,248 */
	0x1,		/* 2,249 */
	0x1,		/* 2,250 */
	0x1,		/* 2,251 */
	0x1,		/* 2,252 */
	0x1,		/* 2,253 */
	0x1,		/* 2,254 */
	0x1,		/* 2,255 */
	0x9,		/* 3,0 */
	0x9,		/* 3,1 */
	0x9,		/* 3,2 */
	0x9,		/* 3,3 */
	0x9,		/* 3,4 */
	0x9,		/* 3,5 */
	0x9,		/* 3,6 */
	0x9,		/* 3,7 */
	0x9,		/* 3,8 */
	0x9,		/* 3,9 */
	0x9,		/* 3,10 */
	0x9,		/* 3,11 */
	0x9,		/* 3,12 */
	0x9,		/* 3,13 */
	0x9,		/* 3,14 */
	0x9,		/* 3,15 */
	0x9,		/* 3,16 */
	0x9,		/* 3,17 */
	0x9,		/* 3,18 */
	0x9,		/* 3,19 */
	0x9,		/* 3,20 */
	0x9,		/* 3,21 */
	0x9,		/* 3,22 */
	0x9,		/* 3,23 */
	0x9,		/* 3,24 */
	0x9,		/* 3,25 */
	0x9,		/* 3,26 */
	0x9,		/* 3,27 */
	0x9,		/* 3,28 */
	0x9,		/* 3,29 */
	0x9,		/* 3,30 */
	0x9,		/* 3,31 */
	0x9,		/* 3,32 */
	0x9,		/* 3,33 */
	0x9,		/* 3,34 */
	0x9,		/* 3,35 */
	0x9,		/* 3,36 */
	0x9,		/* 3,37 */
	0x9,		/* 3,38 */
	0x9,		/* 3,39 */
	0x9,		/* 3,40 */
	0x9,		/* 3,41 */
	0x9,		/* 3,42 */
	0x9,		/* 3,43 */
	0x9,		/* 3,44 */
	0x9,		/* 3,45 */
	0x9,		/* 3,46 */
	0x9,		/* 3,47 */
	0x9,		/* 3,48 */
	0x9,		/* 3,49 */
	0x9,		/* 3,50 */
	0x9,		/* 3,51 */
	0x9,		/* 3,52 */
	0x9,		/* 3,53 */
	0x9,		/* 3,54 */
	0x9,		/* 3,55 */
	0x9,		/* 3,56 */
	0x9,		/* 3,57 */
	0x9,		/* 3,58 */
	0x9,		/* 3,59 */
	0x9,		/* 3,60 */
	0x9,		/* 3,61 */
	0x9,		/* 3,62 */
	0x9,		/* 3,63 */
	0x9,		/* 3,64 */
	0x9,		/* 3,65 */
	0x9,		/* 3,66 */
	0x9,		/* 3,67 */
	0x9,		/* 3,68 */
	0x9,		/* 3,69 */
	0x1,		/* 3,70 */
	0x1,		/* 3,71 */
	0x1,		/* 3,72 */
	0x1,		/* 3,73 */
	0x1,		/* 3,74 */
	0x1,		/* 3,75 */
	0x1,		/* 3,76 */
	0x1,		/* 3,77 */
	0x1,		/* 3,78 */
	0x1,		/* 3,79 */
	0x1,		/* 3,80 */
	0x1,		/* 3,81 */
	0x1,		/* 3,82 */
	0x1,		/* 3,83 */
	0x1,		/* 3,84 */
	0x1,		/* 3,85 */
	0x1,		/* 3,86 */
	0x1,		/* 3,87 */
	0x1,		/* 3,88 */
	0x1,		/* 3,89 */
	0x1,		/* 3,90 */
	0x1,		/* 3,91 */
	0x1,		/* 3,92 */
	0x1,		/* 3,93 */
	0x1,		/* 3,94 */
	0x1,		/* 3,95 */
	0x9,		/* 3,96 */
	0x9,		/* 3,97 */
	0x1,		/* 3,98 */
	0x1,		/* 3,99 */
	0x1,		/* 3,100 */
	0x1,		/* 3,101 */
	0x1,		/* 3,102 */
	0x1,		/* 3,103 */
	0x1,		/* 3,104 */
	0x1,		/* 3,105 */
	0x1,		/* 3,106 */
	0x1,		/* 3,107 */
	0x1,		/* 3,108 */
	0x1,		/* 3,109 */
	0x1,		/* 3,110 */
	0x1,		/* 3,111 */
	0x1,		/* 3,112 */
	0x1,		/* 3,113 */
	0x1,		/* 3,114 */
	0x1,		/* 3,115 */
	0x1,		/* 3,116 */
	0x1,		/* 3,117 */
	0x1,		/* 3,118 */
	0x1,		/* 3,119 */
	0x1,		/* 3,120 */
	0x1,		/* 3,121 */
	0x1,		/* 3,122 */
	0x1,		/* 3,123 */
	0x1,		/* 3,124 */
	0x1,		/* 3,125 */
	0x1,		/* 3,126 */
	0x1,		/* 3,127 */
	0x1,		/* 3,128 */
	0x1,		/* 3,129 */
	0x1,		/* 3,130 */
	0x1,		/* 3,131 */
	0x1,		/* 3,132 */
	0x1,		/* 3,133 */
	0xb,		/* 3,134 */
	0x9,		/* 3,135 */
	0xb,		/* 3,136 */
	0xb,		/* 3,137 */
	0xb,		/* 3,138 */
	0x1,		/* 3,139 */
	0xb,		/* 3,140 */
	0x1,		/* 3,141 */
	0xb,		/* 3,142 */
	0xb,		/* 3,143 */
	0xb,		/* 3,144 */
	0xb,		/* 3,145 */
	0xb,		/* 3,146 */
	0xb,		/* 3,147 */
	0xb,		/* 3,148 */
	0xb,		/* 3,149 */
	0xb,		/* 3,150 */
	0xb,		/* 3,151 */
	0xb,		/* 3,152 */
	0xb,		/* 3,153 */
	0xb,		/* 3,154 */
	0xb,		/* 3,155 */
	0xb,		/* 3,156 */
	0xb,		/* 3,157 */
	0xb,		/* 3,158 */
	0xb,		/* 3,159 */
	0xb,		/* 3,160 */
	0xb,		/* 3,161 */
	0x1,		/* 3,162 */
	0xb,		/* 3,163 */
	0xb,		/* 3,164 */
	0xb,		/* 3,165 */
	0xb,		/* 3,166 */
	0xb,		/* 3,167 */
	0xb,		/* 3,168 */
	0xb,		/* 3,169 */
	0xb,		/* 3,170 */
	0xb,		/* 3,171 */
	0xb,		/* 3,172 */
	0xb,		/* 3,173 */
	0xb,		/* 3,174 */
	0xb,		/* 3,175 */
	0xb,		/* 3,176 */
	0xb,		/* 3,177 */
	0xb,		/* 3,178 */
	0xb,		/* 3,179 */
	0xb,		/* 3,180 */
	0xb,		/* 3,181 */
	0xb,		/* 3,182 */
	0xb,		/* 3,183 */
	0xb,		/* 3,184 */
	0xb,		/* 3,185 */
	0xb,		/* 3,186 */
	0xb,		/* 3,187 */
	0xb,		/* 3,188 */
	0xb,		/* 3,189 */
	0xb,		/* 3,190 */
	0xb,		/* 3,191 */
	0xb,		/* 3,192 */
	0xb,		/* 3,193 */
	0xb,		/* 3,194 */
	0xb,		/* 3,195 */
	0xb,		/* 3,196 */
	0xb,		/* 3,197 */
	0xb,		/* 3,198 */
	0xb,		/* 3,199 */
	0xb,		/* 3,200 */
	0xb,		/* 3,201 */
	0xb,		/* 3,202 */
	0xb,		/* 3,203 */
	0xb,		/* 3,204 */
	0xb,		/* 3,205 */
	0xb,		/* 3,206 */
	0x1,		/* 3,207 */
	0xb,		/* 3,208 */
	0xb,		/* 3,209 */
	0xb,		/* 3,210 */
	0xb,		/* 3,211 */
	0xb,		/* 3,212 */
	0xb,		/* 3,213 */
	0xb,		/* 3,214 */
	0x1,		/* 3,215 */
	0x1,		/* 3,216 */
	0x1,		/* 3,217 */
	0xb,		/* 3,218 */
	0x1,		/* 3,219 */
	0xb,		/* 3,220 */
	0x1,		/* 3,221 */
	0xb,		/* 3,222 */
	0x1,		/* 3,223 */
	0xb,		/* 3,224 */
	0x1,		/* 3,225 */
	0xb,		/* 3,226 */
	0xb,		/* 3,227 */
	0xb,		/* 3,228 */
	0xb,		/* 3,229 */
	0xb,		/* 3,230 */
	0xb,		/* 3,231 */
	0xb,		/* 3,232 */
	0xb,		/* 3,233 */
	0xb,		/* 3,234 */
	0xb,		/* 3,235 */
	0xb,		/* 3,236 */
	0xb,		/* 3,237 */
	0xb,		/* 3,238 */
	0xb,		/* 3,239 */
	0xb,		/* 3,240 */
	0xb,		/* 3,241 */
	0xb,		/* 3,242 */
	0xb,		/* 3,243 */
	0x1,		/* 3,244 */
	0x1,		/* 3,245 */
	0x1,		/* 3,246 */
	0x1,		/* 3,247 */
	0x1,		/* 3,248 */
	0x1,		/* 3,249 */
	0x1,		/* 3,250 */
	0x1,		/* 3,251 */
	0x1,		/* 3,252 */
	0x1,		/* 3,253 */
	0x1,		/* 3,254 */
	0x1,		/* 3,255 */
	0x1,		/* 4,0 */
	0xb,		/* 4,1 */
	0xb,		/* 4,2 */
	0xb,		/* 4,3 */
	0xb,		/* 4,4 */
	0xb,		/* 4,5 */
	0xb,		/* 4,6 */
	0xb,		/* 4,7 */
	0xb,		/* 4,8 */
	0xb,		/* 4,9 */
	0xb,		/* 4,10 */
	0xb,		/* 4,11 */
	0xb,		/* 4,12 */
	0x1,		/* 4,13 */
	0xb,		/* 4,14 */
	0xb,		/* 4,15 */
	0xb,		/* 4,16 */
	0xb,		/* 4,17 */
	0xb,		/* 4,18 */
	0xb,		/* 4,19 */
	0xb,		/* 4,20 */
	0xb,		/* 4,21 */
	0xb,		/* 4,22 */
	0xb,		/* 4,23 */
	0xb,		/* 4,24 */
	0xb,		/* 4,25 */
	0xb,		/* 4,26 */
	0xb,		/* 4,27 */
	0xb,		/* 4,28 */
	0xb,		/* 4,29 */
	0xb,		/* 4,30 */
	0xb,		/* 4,31 */
	0xb,		/* 4,32 */
	0xb,		/* 4,33 */
	0xb,		/* 4,34 */
	0xb,		/* 4,35 */
	0xb,		/* 4,36 */
	0xb,		/* 4,37 */
	0xb,		/* 4,38 */
	0xb,		/* 4,39 */
	0xb,		/* 4,40 */
	0xb,		/* 4,41 */
	0xb,		/* 4,42 */
	0xb,		/* 4,43 */
	0xb,		/* 4,44 */
	0xb,		/* 4,45 */
	0xb,		/* 4,46 */
	0xb,		/* 4,47 */
	0xb,		/* 4,48 */
	0xb,		/* 4,49 */
	0xb,		/* 4,50 */
	0xb,		/* 4,51 */
	0xb,		/* 4,52 */
	0xb,		/* 4,53 */
	0xb,		/* 4,54 */
	0xb,		/* 4,55 */
	0xb,		/* 4,56 */
	0xb,		/* 4,57 */
	0xb,		/* 4,58 */
	0xb,		/* 4,59 */
	0xb,		/* 4,60 */
	0xb,		/* 4,61 */
	0xb,		/* 4,62 */
	0xb,		/* 4,63 */
	0xb,		/* 4,64 */
	0xb,		/* 4,65 */
	0xb,		/* 4,66 */
	0xb,		/* 4,67 */
	0xb,		/* 4,68 */
	0xb,		/* 4,69 */
	0xb,		/* 4,70 */
	0xb,		/* 4,71 */
	0xb,		/* 4,72 */
	0xb,		/* 4,73 */
	0xb,		/* 4,74 */
	0xb,		/* 4,75 */
	0xb,		/* 4,76 */
	0xb,		/* 4,77 */
	0xb,		/* 4,78 */
	0xb,		/* 4,79 */
	0x1,		/* 4,80 */
	0xb,		/* 4,81 */
	0xb,		/* 4,82 */
	0xb,		/* 4,83 */
	0xb,		/* 4,84 */
	0xb,		/* 4,85 */
	0xb,		/* 4,86 */
	0xb,		/* 4,87 */
	0xb,		/* 4,88 */
	0xb,		/* 4,89 */
	0xb,		/* 4,90 */
	0xb,		/* 4,91 */
	0xb,		/* 4,92 */
	0x1,		/* 4,93 */
	0xb,		/* 4,94 */
	0xb,		/* 4,95 */
	0xb,		/* 4,96 */
	0xb,		/* 4,97 */
	0xb,		/* 4,98 */
	0xb,		/* 4,99 */
	0xb,		/* 4,100 */
	0xb,		/* 4,101 */
	0xb,		/* 4,102 */
	0xb,		/* 4,103 */
	0xb,		/* 4,104 */
	0xb,		/* 4,105 */
	0xb,		/* 4,106 */
	0xb,		/* 4,107 */
	0xb,		/* 4,108 */
	0xb,		/* 4,109 */
	0xb,		/* 4,110 */
	0xb,		/* 4,111 */
	0xb,		/* 4,112 */
	0xb,		/* 4,113 */
	0xb,		/* 4,114 */
	0xb,		/* 4,115 */
	0xb,		/* 4,116 */
	0xb,		/* 4,117 */
	0xb,		/* 4,118 */
	0xb,		/* 4,119 */
	0xb,		/* 4,120 */
	0xb,		/* 4,121 */
	0xb,		/* 4,122 */
	0xb,		/* 4,123 */
	0xb,		/* 4,124 */
	0xb,		/* 4,125 */
	0xb,		/* 4,126 */
	0xb,		/* 4,127 */
	0xb,		/* 4,128 */
	0xb,		/* 4,129 */
	0x1,		/* 4,130 */
	0x9,		/* 4,131 */
	0x9,		/* 4,132 */
	0x9,		/* 4,133 */
	0x9,		/* 4,134 */
	0x1,		/* 4,135 */
	0x1,		/* 4,136 */
	0x1,		/* 4,137 */
	0x1,		/* 4,138 */
	0x1,		/* 4,139 */
	0x1,		/* 4,140 */
	0x1,		/* 4,141 */
	0x1,		/* 4,142 */
	0x1,		/* 4,143 */
	0xb,		/* 4,144 */
	0xb,		/* 4,145 */
	0xb,		/* 4,146 */
	0xb,		/* 4,147 */
	0xb,		/* 4,148 */
	0xb,		/* 4,149 */
	0xb,		/* 4,150 */
	0xb,		/* 4,151 */
	0xb,		/* 4,152 */
	0xb,		/* 4,153 */
	0xb,		/* 4,154 */
	0xb,		/* 4,155 */
	0xb,		/* 4,156 */
	0xb,		/* 4,157 */
	0xb,		/* 4,158 */
	0xb,		/* 4,159 */
	0xb,		/* 4,160 */
	0xb,		/* 4,161 */
	0xb,		/* 4,162 */
	0xb,		/* 4,163 */
	0xb,		/* 4,164 */
	0xb,		/* 4,165 */
	0xb,		/* 4,166 */
	0xb,		/* 4,167 */
	0xb,		/* 4,168 */
	0xb,		/* 4,169 */
	0xb,		/* 4,170 */
	0xb,		/* 4,171 */
	0xb,		/* 4,172 */
	0xb,		/* 4,173 */
	0xb,		/* 4,174 */
	0xb,		/* 4,175 */
	0xb,		/* 4,176 */
	0xb,		/* 4,177 */
	0xb,		/* 4,178 */
	0xb,		/* 4,179 */
	0xb,		/* 4,180 */
	0xb,		/* 4,181 */
	0xb,		/* 4,182 */
	0xb,		/* 4,183 */
	0xb,		/* 4,184 */
	0xb,		/* 4,185 */
	0xb,		/* 4,186 */
	0xb,		/* 4,187 */
	0xb,		/* 4,188 */
	0xb,		/* 4,189 */
	0xb,		/* 4,190 */
	0xb,		/* 4,191 */
	0xb,		/* 4,192 */
	0xb,		/* 4,193 */
	0xb,		/* 4,194 */
	0xb,		/* 4,195 */
	0xb,		/* 4,196 */
	0x1,		/* 4,197 */
	0x1,		/* 4,198 */
	0xb,		/* 4,199 */
	0xb,		/* 4,200 */
	0x1,		/* 4,201 */
	0x1,		/* 4,202 */
	0xb,		/* 4,203 */
	0xb,		/* 4,204 */
	0x1,		/* 4,205 */
	0x1,		/* 4,206 */
	0x1,		/* 4,207 */
	0xb,		/* 4,208 */
	0xb,		/* 4,209 */
	0xb,		/* 4,210 */
	0xb,		/* 4,211 */
	0xb,		/* 4,212 */
	0xb,		/* 4,213 */
	0xb,		/* 4,214 */
	0xb,		/* 4,215 */
	0xb,		/* 4,216 */
	0xb,		/* 4,217 */
	0xb,		/* 4,218 */
	0xb,		/* 4,219 */
	0xb,		/* 4,220 */
	0xb,		/* 4,221 */
	0xb,		/* 4,222 */
	0xb,		/* 4,223 */
	0xb,		/* 4,224 */
	0xb,		/* 4,225 */
	0xb,		/* 4,226 */
	0xb,		/* 4,227 */
	0xb,		/* 4,228 */
	0xb,		/* 4,229 */
	0xb,		/* 4,230 */
	0xb,		/* 4,231 */
	0xb,		/* 4,232 */
	0xb,		/* 4,233 */
	0xb,		/* 4,234 */
	0xb,		/* 4,235 */
	0x1,		/* 4,236 */
	0x1,		/* 4,237 */
	0xb,		/* 4,238 */
	0xb,		/* 4,239 */
	0xb,		/* 4,240 */
	0xb,		/* 4,241 */
	0xb,		/* 4,242 */
	0xb,		/* 4,243 */
	0xb,		/* 4,244 */
	0xb,		/* 4,245 */
	0x1,		/* 4,246 */
	0x1,		/* 4,247 */
	0xb,		/* 4,248 */
	0xb,		/* 4,249 */
	0x1,		/* 4,250 */
	0x1,		/* 4,251 */
	0x1,		/* 4,252 */
	0x1,		/* 4,253 */
	0x1,		/* 4,254 */
	0x1,		/* 4,255 */
	0x1,		/* 5,0 */
	0x1,		/* 5,1 */
	0x1,		/* 5,2 */
	0x1,		/* 5,3 */
	0x1,		/* 5,4 */
	0x1,		/* 5,5 */
	0x1,		/* 5,6 */
	0x1,		/* 5,7 */
	0x1,		/* 5,8 */
	0x1,		/* 5,9 */
	0x1,		/* 5,10 */
	0x1,		/* 5,11 */
	0x1,		/* 5,12 */
	0x1,		/* 5,13 */
	0x1,		/* 5,14 */
	0x1,		/* 5,15 */
	0x1,		/* 5,16 */
	0x1,		/* 5,17 */
	0x1,		/* 5,18 */
	0x1,		/* 5,19 */
	0x1,		/* 5,20 */
	0x1,		/* 5,21 */
	0x1,		/* 5,22 */
	0x1,		/* 5,23 */
	0x1,		/* 5,24 */
	0x1,		/* 5,25 */
	0x1,		/* 5,26 */
	0x1,		/* 5,27 */
	0x1,		/* 5,28 */
	0x1,		/* 5,29 */
	0x1,		/* 5,30 */
	0x1,		/* 5,31 */
	0x1,		/* 5,32 */
	0x1,		/* 5,33 */
	0x1,		/* 5,34 */
	0x1,		/* 5,35 */
	0x1,		/* 5,36 */
	0x1,		/* 5,37 */
	0x1,		/* 5,38 */
	0x1,		/* 5,39 */
	0x1,		/* 5,40 */
	0x1,		/* 5,41 */
	0x1,		/* 5,42 */
	0x1,		/* 5,43 */
	0x1,		/* 5,44 */
	0x1,		/* 5,45 */
	0x1,		/* 5,46 */
	0x1,		/* 5,47 */
	0x1,		/* 5,48 */
	0xb,		/* 5,49 */
	0xb,		/* 5,50 */
	0xb,		/* 5,51 */
	0xb,		/* 5,52 */
	0xb,		/* 5,53 */
	0xb,		/* 5,54 */
	0xb,		/* 5,55 */
	0xb,		/* 5,56 */
	0xb,		/* 5,57 */
	0xb,		/* 5,58 */
	0xb,		/* 5,59 */
	0xb,		/* 5,60 */
	0xb,		/* 5,61 */
	0xb,		/* 5,62 */
	0xb,		/* 5,63 */
	0xb,		/* 5,64 */
	0xb,		/* 5,65 */
	0xb,		/* 5,66 */
	0xb,		/* 5,67 */
	0xb,		/* 5,68 */
	0xb,		/* 5,69 */
	0xb,		/* 5,70 */
	0xb,		/* 5,71 */
	0xb,		/* 5,72 */
	0xb,		/* 5,73 */
	0xb,		/* 5,74 */
	0xb,		/* 5,75 */
	0xb,		/* 5,76 */
	0xb,		/* 5,77 */
	0xb,		/* 5,78 */
	0xb,		/* 5,79 */
	0xb,		/* 5,80 */
	0xb,		/* 5,81 */
	0xb,		/* 5,82 */
	0xb,		/* 5,83 */
	0xb,		/* 5,84 */
	0xb,		/* 5,85 */
	0xb,		/* 5,86 */
	0x1,		/* 5,87 */
	0x1,		/* 5,88 */
	0xb,		/* 5,89 */
	0x1,		/* 5,90 */
	0x1,		/* 5,91 */
	0x1,		/* 5,92 */
	0x1,		/* 5,93 */
	0x1,		/* 5,94 */
	0x1,		/* 5,95 */
	0x1,		/* 5,96 */
	0xb,		/* 5,97 */
	0xb,		/* 5,98 */
	0xb,		/* 5,99 */
	0xb,		/* 5,100 */
	0xb,		/* 5,101 */
	0xb,		/* 5,102 */
	0xb,		/* 5,103 */
	0xb,		/* 5,104 */
	0xb,		/* 5,105 */
	0xb,		/* 5,106 */
	0xb,		/* 5,107 */
	0xb,		/* 5,108 */
	0xb,		/* 5,109 */
	0xb,		/* 5,110 */
	0xb,		/* 5,111 */
	0xb,		/* 5,112 */
	0xb,		/* 5,113 */
	0xb,		/* 5,114 */
	0xb,		/* 5,115 */
	0xb,		/* 5,116 */
	0xb,		/* 5,117 */
	0xb,		/* 5,118 */
	0xb,		/* 5,119 */
	0xb,		/* 5,120 */
	0xb,		/* 5,121 */
	0xb,		/* 5,122 */
	0xb,		/* 5,123 */
	0xb,		/* 5,124 */
	0xb,		/* 5,125 */
	0xb,		/* 5,126 */
	0xb,		/* 5,127 */
	0xb,		/* 5,128 */
	0xb,		/* 5,129 */
	0xb,		/* 5,130 */
	0xb,		/* 5,131 */
	0xb,		/* 5,132 */
	0xb,		/* 5,133 */
	0xb,		/* 5,134 */
	0x1,		/* 5,135 */
	0x1,		/* 5,136 */
	0x1,		/* 5,137 */
	0x1,		/* 5,138 */
	0x1,		/* 5,139 */
	0x1,		/* 5,140 */
	0x1,		/* 5,141 */
	0x1,		/* 5,142 */
	0x1,		/* 5,143 */
	0x1,		/* 5,144 */
	0x9,		/* 5,145 */
	0x9,		/* 5,146 */
	0x9,		/* 5,147 */
	0x9,		/* 5,148 */
	0x9,		/* 5,149 */
	0x9,		/* 5,150 */
	0x9,		/* 5,151 */
	0x9,		/* 5,152 */
	0x9,		/* 5,153 */
	0x9,		/* 5,154 */
	0x9,		/* 5,155 */
	0x9,		/* 5,156 */
	0x9,		/* 5,157 */
	0x9,		/* 5,158 */
	0x9,		/* 5,159 */
	0x9,		/* 5,160 */
	0x9,		/* 5,161 */
	0x1,		/* 5,162 */
	0x9,		/* 5,163 */
	0x9,		/* 5,164 */
	0x9,		/* 5,165 */
	0x9,		/* 5,166 */
	0x9,		/* 5,167 */
	0x9,		/* 5,168 */
	0x9,		/* 5,169 */
	0x9,		/* 5,170 */
	0x9,		/* 5,171 */
	0x9,		/* 5,172 */
	0x9,		/* 5,173 */
	0x9,		/* 5,174 */
	0x9,		/* 5,175 */
	0x9,		/* 5,176 */
	0x9,		/* 5,177 */
	0x9,		/* 5,178 */
	0x9,		/* 5,179 */
	0x9,		/* 5,180 */
	0x9,		/* 5,181 */
	0x9,		/* 5,182 */
	0x9,		/* 5,183 */
	0x9,		/* 5,184 */
	0x9,		/* 5,185 */
	0x1,		/* 5,186 */
	0x9,		/* 5,187 */
	0x9,		/* 5,188 */
	0x9,		/* 5,189 */
	0x1,		/* 5,190 */
	0x9,		/* 5,191 */
	0x1,		/* 5,192 */
	0x9,		/* 5,193 */
	0x9,		/* 5,194 */
	0x1,		/* 5,195 */
	0x9,		/* 5,196 */
	0x1,		/* 5,197 */
	0x1,		/* 5,198 */
	0x1,		/* 5,199 */
	0x1,		/* 5,200 */
	0x1,		/* 5,201 */
	0x1,		/* 5,202 */
	0x1,		/* 5,203 */
	0x1,		/* 5,204 */
	0x1,		/* 5,205 */
	0x1,		/* 5,206 */
	0x1,		/* 5,207 */
	0xb,		/* 5,208 */
	0xb,		/* 5,209 */
	0xb,		/* 5,210 */
	0xb,		/* 5,211 */
	0xb,		/* 5,212 */
	0xb,		/* 5,213 */
	0xb,		/* 5,214 */
	0xb,		/* 5,215 */
	0xb,		/* 5,216 */
	0xb,		/* 5,217 */
	0xb,		/* 5,218 */
	0xb,		/* 5,219 */
	0xb,		/* 5,220 */
	0xb,		/* 5,221 */
	0xb,		/* 5,222 */
	0xb,		/* 5,223 */
	0xb,		/* 5,224 */
	0xb,		/* 5,225 */
	0xb,		/* 5,226 */
	0xb,		/* 5,227 */
	0xb,		/* 5,228 */
	0xb,		/* 5,229 */
	0xb,		/* 5,230 */
	0xb,		/* 5,231 */
	0xb,		/* 5,232 */
	0xb,		/* 5,233 */
	0xb,		/* 5,234 */
	0x1,		/* 5,235 */
	0x1,		/* 5,236 */
	0x1,		/* 5,237 */
	0x1,		/* 5,238 */
	0x1,		/* 5,239 */
	0xb,		/* 5,240 */
	0xb,		/* 5,241 */
	0xb,		/* 5,242 */
	0x1,		/* 5,243 */
	0x1,		/* 5,244 */
	0x1,		/* 5,245 */
	0x1,		/* 5,246 */
	0x1,		/* 5,247 */
	0x1,		/* 5,248 */
	0x1,		/* 5,249 */
	0x1,		/* 5,250 */
	0x1,		/* 5,251 */
	0x1,		/* 5,252 */
	0x1,		/* 5,253 */
	0x1,		/* 5,254 */
	0x1,		/* 5,255 */
	0x1,		/* 6,0 */
	0x1,		/* 6,1 */
	0x1,		/* 6,2 */
	0x1,		/* 6,3 */
	0x1,		/* 6,4 */
	0x1,		/* 6,5 */
	0x1,		/* 6,6 */
	0x1,		/* 6,7 */
	0x1,		/* 6,8 */
	0x1,		/* 6,9 */
	0x1,		/* 6,10 */
	0x1,		/* 6,11 */
	0x1,		/* 6,12 */
	0x1,		/* 6,13 */
	0x1,		/* 6,14 */
	0x1,		/* 6,15 */
	0x1,		/* 6,16 */
	0x1,		/* 6,17 */
	0x1,		/* 6,18 */
	0x1,		/* 6,19 */
	0x1,		/* 6,20 */
	0x1,		/* 6,21 */
	0x1,		/* 6,22 */
	0x1,		/* 6,23 */
	0x1,		/* 6,24 */
	0x1,		/* 6,25 */
	0x1,		/* 6,26 */
	0x1,		/* 6,27 */
	0x1,		/* 6,28 */
	0x1,		/* 6,29 */
	0x1,		/* 6,30 */
	0x1,		/* 6,31 */
	0x1,		/* 6,32 */
	0xb,		/* 6,33 */
	0xb,		/* 6,34 */
	0xb,		/* 6,35 */
	0xb,		/* 6,36 */
	0xb,		/* 6,37 */
	0xb,		/* 6,38 */
	0xb,		/* 6,39 */
	0xb,		/* 6,40 */
	0xb,		/* 6,41 */
	0xb,		/* 6,42 */
	0xb,		/* 6,43 */
	0xb,		/* 6,44 */
	0xb,		/* 6,45 */
	0xb,		/* 6,46 */
	0xb,		/* 6,47 */
	0xb,		/* 6,48 */
	0xb,		/* 6,49 */
	0xb,		/* 6,50 */
	0xb,		/* 6,51 */
	0xb,		/* 6,52 */
	0xb,		/* 6,53 */
	0xb,		/* 6,54 */
	0xb,		/* 6,55 */
	0xb,		/* 6,56 */
	0xb,		/* 6,57 */
	0xb,		/* 6,58 */
	0x1,		/* 6,59 */
	0x1,		/* 6,60 */
	0x1,		/* 6,61 */
	0x1,		/* 6,62 */
	0x1,		/* 6,63 */
	0x9,		/* 6,64 */
	0xb,		/* 6,65 */
	0xb,		/* 6,66 */
	0xb,		/* 6,67 */
	0xb,		/* 6,68 */
	0xb,		/* 6,69 */
	0xb,		/* 6,70 */
	0xb,		/* 6,71 */
	0xb,		/* 6,72 */
	0xb,		/* 6,73 */
	0xb,		/* 6,74 */
	0x9,		/* 6,75 */
	0x9,		/* 6,76 */
	0x9,		/* 6,77 */
	0x9,		/* 6,78 */
	0x9,		/* 6,79 */
	0x9,		/* 6,80 */
	0x9,		/* 6,81 */
	0x9,		/* 6,82 */
	0x1,		/* 6,83 */
	0x1,		/* 6,84 */
	0x1,		/* 6,85 */
	0x1,		/* 6,86 */
	0x1,		/* 6,87 */
	0x1,		/* 6,88 */
	0x1,		/* 6,89 */
	0x1,		/* 6,90 */
	0x1,		/* 6,91 */
	0x1,		/* 6,92 */
	0x1,		/* 6,93 */
	0x1,		/* 6,94 */
	0x1,		/* 6,95 */
	0x9,		/* 6,96 */
	0x9,		/* 6,97 */
	0x9,		/* 6,98 */
	0x9,		/* 6,99 */
	0x9,		/* 6,100 */
	0x9,		/* 6,101 */
	0x9,		/* 6,102 */
	0x9,		/* 6,103 */
	0x9,		/* 6,104 */
	0x9,		/* 6,105 */
	0x1,		/* 6,106 */
	0x1,		/* 6,107 */
	0x1,		/* 6,108 */
	0x1,		/* 6,109 */
	0x1,		/* 6,110 */
	0x1,		/* 6,111 */
	0x9,		/* 6,112 */
	0xb,		/* 6,113 */
	0xb,		/* 6,114 */
	0xb,		/* 6,115 */
	0xb,		/* 6,116 */
	0xb,		/* 6,117 */
	0xb,		/* 6,118 */
	0xb,		/* 6,119 */
	0xb,		/* 6,120 */
	0xb,		/* 6,121 */
	0xb,		/* 6,122 */
	0xb,		/* 6,123 */
	0xb,		/* 6,124 */
	0xb,		/* 6,125 */
	0xb,		/* 6,126 */
	0xb,		/* 6,127 */
	0xb,		/* 6,128 */
	0xb,		/* 6,129 */
	0xb,		/* 6,130 */
	0xb,		/* 6,131 */
	0xb,		/* 6,132 */
	0xb,		/* 6,133 */
	0xb,		/* 6,134 */
	0xb,		/* 6,135 */
	0xb,		/* 6,136 */
	0xb,		/* 6,137 */
	0xb,		/* 6,138 */
	0xb,		/* 6,139 */
	0xb,		/* 6,140 */
	0xb,		/* 6,141 */
	0xb,		/* 6,142 */
	0xb,		/* 6,143 */
	0xb,		/* 6,144 */
	0xb,		/* 6,145 */
	0xb,		/* 6,146 */
	0xb,		/* 6,147 */
	0xb,		/* 6,148 */
	0xb,		/* 6,149 */
	0xb,		/* 6,150 */
	0xb,		/* 6,151 */
	0xb,		/* 6,152 */
	0xb,		/* 6,153 */
	0xb,		/* 6,154 */
	0xb,		/* 6,155 */
	0xb,		/* 6,156 */
	0xb,		/* 6,157 */
	0xb,		/* 6,158 */
	0xb,		/* 6,159 */
	0xb,		/* 6,160 */
	0xb,		/* 6,161 */
	0xb,		/* 6,162 */
	0xb,		/* 6,163 */
	0xb,		/* 6,164 */
	0xb,		/* 6,165 */
	0xb,		/* 6,166 */
	0xb,		/* 6,167 */
	0xb,		/* 6,168 */
	0xb,		/* 6,169 */
	0xb,		/* 6,170 */
	0xb,		/* 6,171 */
	0xb,		/* 6,172 */
	0xb,		/* 6,173 */
	0xb,		/* 6,174 */
	0xb,		/* 6,175 */
	0xb,		/* 6,176 */
	0xb,		/* 6,177 */
	0xb,		/* 6,178 */
	0xb,		/* 6,179 */
	0xb,		/* 6,180 */
	0xb,		/* 6,181 */
	0xb,		/* 6,182 */
	0xb,		/* 6,183 */
	0x1,		/* 6,184 */
	0x1,		/* 6,185 */
	0xb,		/* 6,186 */
	0xb,		/* 6,187 */
	0xb,		/* 6,188 */
	0xb,		/* 6,189 */
	0xb,		/* 6,190 */
	0x1,		/* 6,191 */
	0xb,		/* 6,192 */
	0xb,		/* 6,193 */
	0xb,		/* 6,194 */
	0xb,		/* 6,195 */
	0xb,		/* 6,196 */
	0xb,		/* 6,197 */
	0xb,		/* 6,198 */
	0xb,		/* 6,199 */
	0xb,		/* 6,200 */
	0xb,		/* 6,201 */
	0xb,		/* 6,202 */
	0xb,		/* 6,203 */
	0xb,		/* 6,204 */
	0xb,		/* 6,205 */
	0xb,		/* 6,206 */
	0x1,		/* 6,207 */
	0xb,		/* 6,208 */
	0xb,		/* 6,209 */
	0xb,		/* 6,210 */
	0xb,		/* 6,211 */
	0x1,		/* 6,212 */
	0xb,		/* 6,213 */
	0x9,		/* 6,214 */
	0x9,		/* 6,215 */
	0x9,		/* 6,216 */
	0x9,		/* 6,217 */
	0x9,		/* 6,218 */
	0x9,		/* 6,219 */
	0x9,		/* 6,220 */
	0x9,		/* 6,221 */
	0x9,		/* 6,222 */
	0x9,		/* 6,223 */
	0x9,		/* 6,224 */
	0x9,		/* 6,225 */
	0x9,		/* 6,226 */
	0x9,		/* 6,227 */
	0x9,		/* 6,228 */
	0xb,		/* 6,229 */
	0xb,		/* 6,230 */
	0x9,		/* 6,231 */
	0x9,		/* 6,232 */
	0x1,		/* 6,233 */
	0x9,		/* 6,234 */
	0x9,		/* 6,235 */
	0x9,		/* 6,236 */
	0x9,		/* 6,237 */
	0x1,		/* 6,238 */
	0x1,		/* 6,239 */
	0x9,		/* 6,240 */
	0x9,		/* 6,241 */
	0x9,		/* 6,242 */
	0x9,		/* 6,243 */
	0x9,		/* 6,244 */
	0x9,		/* 6,245 */
	0x9,		/* 6,246 */
	0x9,		/* 6,247 */
	0x9,		/* 6,248 */
	0x9,		/* 6,249 */
	0x1,		/* 6,250 */
	0x1,		/* 6,251 */
	0x1,		/* 6,252 */
	0x1,		/* 6,253 */
	0x1,		/* 6,254 */
	0x1,		/* 6,255 */
	0x1,		/* 7,0 */
	0x1,		/* 7,1 */
	0x1,		/* 7,2 */
	0x1,		/* 7,3 */
	0x1,		/* 7,4 */
	0x1,		/* 7,5 */
	0x1,		/* 7,6 */
	0x1,		/* 7,7 */
	0x1,		/* 7,8 */
	0x1,		/* 7,9 */
	0x1,		/* 7,10 */
	0x1,		/* 7,11 */
	0x1,		/* 7,12 */
	0x1,		/* 7,13 */
	0x1,		/* 7,14 */
	0x1,		/* 7,15 */
	0x1,		/* 7,16 */
	0x1,		/* 7,17 */
	0x1,		/* 7,18 */
	0x1,		/* 7,19 */
	0x1,		/* 7,20 */
	0x1,		/* 7,21 */
	0x1,		/* 7,22 */
	0x1,		/* 7,23 */
	0x1,		/* 7,24 */
	0x1,		/* 7,25 */
	0x1,		/* 7,26 */
	0x1,		/* 7,27 */
	0x1,		/* 7,28 */
	0x1,		/* 7,29 */
	0x1,		/* 7,30 */
	0x1,		/* 7,31 */
	0x1,		/* 7,32 */
	0x1,		/* 7,33 */
	0x1,		/* 7,34 */
	0x1,		/* 7,35 */
	0x1,		/* 7,36 */
	0x1,		/* 7,37 */
	0x1,		/* 7,38 */
	0x1,		/* 7,39 */
	0x1,		/* 7,40 */
	0x1,		/* 7,41 */
	0x1,		/* 7,42 */
	0x1,		/* 7,43 */
	0x1,		/* 7,44 */
	0x1,		/* 7,45 */
	0x1,		/* 7,46 */
	0x1,		/* 7,47 */
	0x1,		/* 7,48 */
	0x1,		/* 7,49 */
	0x1,		/* 7,50 */
	0x1,		/* 7,51 */
	0x1,		/* 7,52 */
	0x1,		/* 7,53 */
	0x1,		/* 7,54 */
	0x1,		/* 7,55 */
	0x1,		/* 7,56 */
	0x1,		/* 7,57 */
	0x1,		/* 7,58 */
	0x1,		/* 7,59 */
	0x1,		/* 7,60 */
	0x1,		/* 7,61 */
	0x1,		/* 7,62 */
	0x1,		/* 7,63 */
	0x1,		/* 7,64 */
	0x1,		/* 7,65 */
	0x1,		/* 7,66 */
	0x1,		/* 7,67 */
	0x1,		/* 7,68 */
	0x1,		/* 7,69 */
	0x1,		/* 7,70 */
	0x1,		/* 7,71 */
	0x1,		/* 7,72 */
	0x1,		/* 7,73 */
	0x1,		/* 7,74 */
	0x1,		/* 7,75 */
	0x1,		/* 7,76 */
	0x1,		/* 7,77 */
	0x1,		/* 7,78 */
	0x1,		/* 7,79 */
	0x1,		/* 7,80 */
	0x1,		/* 7,81 */
	0x1,		/* 7,82 */
	0x1,		/* 7,83 */
	0x1,		/* 7,84 */
	0x1,		/* 7,85 */
	0x1,		/* 7,86 */
	0x1,		/* 7,87 */
	0x1,		/* 7,88 */
	0x1,		/* 7,89 */
	0x1,		/* 7,90 */
	0x1,		/* 7,91 */
	0x1,		/* 7,92 */
	0x1,		/* 7,93 */
	0x1,		/* 7,94 */
	0x1,		/* 7,95 */
	0x1,		/* 7,96 */
	0x1,		/* 7,97 */
	0x1,		/* 7,98 */
	0x1,		/* 7,99 */
	0x1,		/* 7,100 */
	0x1,		/* 7,101 */
	0x1,		/* 7,102 */
	0x1,		/* 7,103 */
	0x1,		/* 7,104 */
	0x1,		/* 7,105 */
	0x1,		/* 7,106 */
	0x1,		/* 7,107 */
	0x1,		/* 7,108 */
	0x1,		/* 7,109 */
	0x1,		/* 7,110 */
	0x1,		/* 7,111 */
	0x1,		/* 7,112 */
	0x1,		/* 7,113 */
	0x1,		/* 7,114 */
	0x1,		/* 7,115 */
	0x1,		/* 7,116 */
	0x1,		/* 7,117 */
	0x1,		/* 7,118 */
	0x1,		/* 7,119 */
	0x1,		/* 7,120 */
	0x1,		/* 7,121 */
	0x1,		/* 7,122 */
	0x1,		/* 7,123 */
	0x1,		/* 7,124 */
	0x1,		/* 7,125 */
	0x1,		/* 7,126 */
	0x1,		/* 7,127 */
	0x1,		/* 7,128 */
	0x1,		/* 7,129 */
	0x1,		/* 7,130 */
	0x1,		/* 7,131 */
	0x1,		/* 7,132 */
	0x1,		/* 7,133 */
	0x1,		/* 7,134 */
	0x1,		/* 7,135 */
	0x1,		/* 7,136 */
	0x1,		/* 7,137 */
	0x1,		/* 7,138 */
	0x1,		/* 7,139 */
	0x1,		/* 7,140 */
	0x1,		/* 7,141 */
	0x1,		/* 7,142 */
	0x1,		/* 7,143 */
	0x1,		/* 7,144 */
	0x1,		/* 7,145 */
	0x1,		/* 7,146 */
	0x1,		/* 7,147 */
	0x1,		/* 7,148 */
	0x1,		/* 7,149 */
	0x1,		/* 7,150 */
	0x1,		/* 7,151 */
	0x1,		/* 7,152 */
	0x1,		/* 7,153 */
	0x1,		/* 7,154 */
	0x1,		/* 7,155 */
	0x1,		/* 7,156 */
	0x1,		/* 7,157 */
	0x1,		/* 7,158 */
	0x1,		/* 7,159 */
	0x1,		/* 7,160 */
	0x1,		/* 7,161 */
	0x1,		/* 7,162 */
	0x1,		/* 7,163 */
	0x1,		/* 7,164 */
	0x1,		/* 7,165 */
	0x1,		/* 7,166 */
	0x1,		/* 7,167 */
	0x1,		/* 7,168 */
	0x1,		/* 7,169 */
	0x1,		/* 7,170 */
	0x1,		/* 7,171 */
	0x1,		/* 7,172 */
	0x1,		/* 7,173 */
	0x1,		/* 7,174 */
	0x1,		/* 7,175 */
	0x1,		/* 7,176 */
	0x1,		/* 7,177 */
	0x1,		/* 7,178 */
	0x1,		/* 7,179 */
	0x1,		/* 7,180 */
	0x1,		/* 7,181 */
	0x1,		/* 7,182 */
	0x1,		/* 7,183 */
	0x1,		/* 7,184 */
	0x1,		/* 7,185 */
	0x1,		/* 7,186 */
	0x1,		/* 7,187 */
	0x1,		/* 7,188 */
	0x1,		/* 7,189 */
	0x1,		/* 7,190 */
	0x1,		/* 7,191 */
	0x1,		/* 7,192 */
	0x1,		/* 7,193 */
	0x1,		/* 7,194 */
	0x1,		/* 7,195 */
	0x1,		/* 7,196 */
	0x1,		/* 7,197 */
	0x1,		/* 7,198 */
	0x1,		/* 7,199 */
	0x1,		/* 7,200 */
	0x1,		/* 7,201 */
	0x1,		/* 7,202 */
	0x1,		/* 7,203 */
	0x1,		/* 7,204 */
	0x1,		/* 7,205 */
	0x1,		/* 7,206 */
	0x1,		/* 7,207 */
	0x1,		/* 7,208 */
	0x1,		/* 7,209 */
	0x1,		/* 7,210 */
	0x1,		/* 7,211 */
	0x1,		/* 7,212 */
	0x1,		/* 7,213 */
	0x1,		/* 7,214 */
	0x1,		/* 7,215 */
	0x1,		/* 7,216 */
	0x1,		/* 7,217 */
	0x1,		/* 7,218 */
	0x1,		/* 7,219 */
	0x1,		/* 7,220 */
	0x1,		/* 7,221 */
	0x1,		/* 7,222 */
	0x1,		/* 7,223 */
	0x1,		/* 7,224 */
	0x1,		/* 7,225 */
	0x1,		/* 7,226 */
	0x1,		/* 7,227 */
	0x1,		/* 7,228 */
	0x1,		/* 7,229 */
	0x1,		/* 7,230 */
	0x1,		/* 7,231 */
	0x1,		/* 7,232 */
	0x1,		/* 7,233 */
	0x1,		/* 7,234 */
	0x1,		/* 7,235 */
	0x1,		/* 7,236 */
	0x1,		/* 7,237 */
	0x1,		/* 7,238 */
	0x1,		/* 7,239 */
	0x1,		/* 7,240 */
	0x1,		/* 7,241 */
	0x1,		/* 7,242 */
	0x1,		/* 7,243 */
	0x1,		/* 7,244 */
	0x1,		/* 7,245 */
	0x1,		/* 7,246 */
	0x1,		/* 7,247 */
	0x1,		/* 7,248 */
	0x1,		/* 7,249 */
	0x1,		/* 7,250 */
	0x1,		/* 7,251 */
	0x1,		/* 7,252 */
	0x1,		/* 7,253 */
	0x1,		/* 7,254 */
	0x1,		/* 7,255 */
	0x1,		/* 8,0 */
	0x9,		/* 8,1 */
	0x9,		/* 8,2 */
	0x9,		/* 8,3 */
	0x1,		/* 8,4 */
	0xb,		/* 8,5 */
	0xb,		/* 8,6 */
	0xb,		/* 8,7 */
	0xb,		/* 8,8 */
	0xb,		/* 8,9 */
	0xb,		/* 8,10 */
	0xb,		/* 8,11 */
	0xb,		/* 8,12 */
	0xb,		/* 8,13 */
	0xb,		/* 8,14 */
	0xb,		/* 8,15 */
	0xb,		/* 8,16 */
	0xb,		/* 8,17 */
	0xb,		/* 8,18 */
	0xb,		/* 8,19 */
	0xb,		/* 8,20 */
	0xb,		/* 8,21 */
	0xb,		/* 8,22 */
	0xb,		/* 8,23 */
	0xb,		/* 8,24 */
	0xb,		/* 8,25 */
	0xb,		/* 8,26 */
	0xb,		/* 8,27 */
	0xb,		/* 8,28 */
	0xb,		/* 8,29 */
	0xb,		/* 8,30 */
	0xb,		/* 8,31 */
	0xb,		/* 8,32 */
	0xb,		/* 8,33 */
	0xb,		/* 8,34 */
	0xb,		/* 8,35 */
	0xb,		/* 8,36 */
	0xb,		/* 8,37 */
	0xb,		/* 8,38 */
	0xb,		/* 8,39 */
	0xb,		/* 8,40 */
	0xb,		/* 8,41 */
	0xb,		/* 8,42 */
	0xb,		/* 8,43 */
	0xb,		/* 8,44 */
	0xb,		/* 8,45 */
	0xb,		/* 8,46 */
	0xb,		/* 8,47 */
	0xb,		/* 8,48 */
	0xb,		/* 8,49 */
	0xb,		/* 8,50 */
	0xb,		/* 8,51 */
	0xb,		/* 8,52 */
	0xb,		/* 8,53 */
	0xb,		/* 8,54 */
	0xb,		/* 8,55 */
	0xb,		/* 8,56 */
	0xb,		/* 8,57 */
	0x1,		/* 8,58 */
	0x1,		/* 8,59 */
	0x9,		/* 8,60 */
	0xb,		/* 8,61 */
	0x9,		/* 8,62 */
	0x9,		/* 8,63 */
	0x9,		/* 8,64 */
	0x9,		/* 8,65 */
	0x9,		/* 8,66 */
	0x9,		/* 8,67 */
	0x9,		/* 8,68 */
	0x9,		/* 8,69 */
	0x9,		/* 8,70 */
	0x9,		/* 8,71 */
	0x9,		/* 8,72 */
	0x9,		/* 8,73 */
	0x9,		/* 8,74 */
	0x9,		/* 8,75 */
	0x9,		/* 8,76 */
	0x9,		/* 8,77 */
	0x1,		/* 8,78 */
	0x1,		/* 8,79 */
	0x1,		/* 8,80 */
	0x9,		/* 8,81 */
	0x9,		/* 8,82 */
	0x9,		/* 8,83 */
	0x9,		/* 8,84 */
	0x1,		/* 8,85 */
	0x1,		/* 8,86 */
	0x1,		/* 8,87 */
	0xb,		/* 8,88 */
	0xb,		/* 8,89 */
	0xb,		/* 8,90 */
	0xb,		/* 8,91 */
	0xb,		/* 8,92 */
	0xb,		/* 8,93 */
	0xb,		/* 8,94 */
	0xb,		/* 8,95 */
	0xb,		/* 8,96 */
	0xb,		/* 8,97 */
	0x9,		/* 8,98 */
	0x9,		/* 8,99 */
	0x1,		/* 8,100 */
	0x1,		/* 8,101 */
	0x9,		/* 8,102 */
	0x9,		/* 8,103 */
	0x9,		/* 8,104 */
	0x9,		/* 8,105 */
	0x9,		/* 8,106 */
	0x9,		/* 8,107 */
	0x9,		/* 8,108 */
	0x9,		/* 8,109 */
	0x9,		/* 8,110 */
	0x9,		/* 8,111 */
	0x1,		/* 8,112 */
	0x1,		/* 8,113 */
	0x1,		/* 8,114 */
	0x1,		/* 8,115 */
	0x1,		/* 8,116 */
	0x1,		/* 8,117 */
	0x1,		/* 8,118 */
	0x1,		/* 8,119 */
	0x1,		/* 8,120 */
	0x1,		/* 8,121 */
	0x1,		/* 8,122 */
	0x1,		/* 8,123 */
	0x1,		/* 8,124 */
	0x1,		/* 8,125 */
	0x1,		/* 8,126 */
	0x1,		/* 8,127 */
	0x1,		/* 8,128 */
	0x9,		/* 8,129 */
	0x9,		/* 8,130 */
	0x9,		/* 8,131 */
	0x1,		/* 8,132 */
	0xb,		/* 8,133 */
	0xb,		/* 8,134 */
	0xb,		/* 8,135 */
	0xb,		/* 8,136 */
	0xb,		/* 8,137 */
	0xb,		/* 8,138 */
	0xb,		/* 8,139 */
	0xb,		/* 8,140 */
	0x1,		/* 8,141 */
	0x1,		/* 8,142 */
	0xb,		/* 8,143 */
	0xb,		/* 8,144 */
	0x1,		/* 8,145 */
	0x1,		/* 8,146 */
	0xb,		/* 8,147 */
	0xb,		/* 8,148 */
	0xb,		/* 8,149 */
	0xb,		/* 8,150 */
	0xb,		/* 8,151 */
	0xb,		/* 8,152 */
	0xb,		/* 8,153 */
	0xb,		/* 8,154 */
	0xb,		/* 8,155 */
	0xb,		/* 8,156 */
	0xb,		/* 8,157 */
	0xb,		/* 8,158 */
	0xb,		/* 8,159 */
	0xb,		/* 8,160 */
	0xb,		/* 8,161 */
	0xb,		/* 8,162 */
	0xb,		/* 8,163 */
	0xb,		/* 8,164 */
	0xb,		/* 8,165 */
	0xb,		/* 8,166 */
	0xb,		/* 8,167 */
	0xb,		/* 8,168 */
	0x1,		/* 8,169 */
	0xb,		/* 8,170 */
	0xb,		/* 8,171 */
	0xb,		/* 8,172 */
	0xb,		/* 8,173 */
	0xb,		/* 8,174 */
	0xb,		/* 8,175 */
	0xb,		/* 8,176 */
	0x1,		/* 8,177 */
	0xb,		/* 8,178 */
	0x1,		/* 8,179 */
	0x1,		/* 8,180 */
	0x1,		/* 8,181 */
	0xb,		/* 8,182 */
	0xb,		/* 8,183 */
	0xb,		/* 8,184 */
	0xb,		/* 8,185 */
	0x1,		/* 8,186 */
	0x1,		/* 8,187 */
	0x9,		/* 8,188 */
	0x1,		/* 8,189 */
	0x9,		/* 8,190 */
	0x9,		/* 8,191 */
	0x9,		/* 8,192 */
	0x9,		/* 8,193 */
	0x9,		/* 8,194 */
	0x9,		/* 8,195 */
	0x9,		/* 8,196 */
	0x1,		/* 8,197 */
	0x1,		/* 8,198 */
	0x9,		/* 8,199 */
	0x9,		/* 8,200 */
	0x1,		/* 8,201 */
	0x1,		/* 8,202 */
	0x9,		/* 8,203 */
	0x9,		/* 8,204 */
	0x9,		/* 8,205 */
	0x1,		/* 8,206 */
	0x1,		/* 8,207 */
	0x1,		/* 8,208 */
	0x1,		/* 8,209 */
	0x1,		/* 8,210 */
	0x1,		/* 8,211 */
	0x1,		/* 8,212 */
	0x1,		/* 8,213 */
	0x1,		/* 8,214 */
	0x9,		/* 8,215 */
	0x1,		/* 8,216 */
	0x1,		/* 8,217 */
	0x1,		/* 8,218 */
	0x1,		/* 8,219 */
	0xb,		/* 8,220 */
	0xb,		/* 8,221 */
	0x1,		/* 8,222 */
	0xb,		/* 8,223 */
	0xb,		/* 8,224 */
	0xb,		/* 8,225 */
	0x9,		/* 8,226 */
	0x9,		/* 8,227 */
	0x1,		/* 8,228 */
	0x1,		/* 8,229 */
	0x9,		/* 8,230 */
	0x9,		/* 8,231 */
	0x9,		/* 8,232 */
	0x9,		/* 8,233 */
	0x9,		/* 8,234 */
	0x9,		/* 8,235 */
	0x9,		/* 8,236 */
	0x9,		/* 8,237 */
	0x9,		/* 8,238 */
	0x9,		/* 8,239 */
	0xb,		/* 8,240 */
	0xb,		/* 8,241 */
	0x1,		/* 8,242 */
	0x1,		/* 8,243 */
	0x1,		/* 8,244 */
	0x1,		/* 8,245 */
	0x1,		/* 8,246 */
	0x1,		/* 8,247 */
	0x1,		/* 8,248 */
	0x1,		/* 8,249 */
	0x1,		/* 8,250 */
	0x1,		/* 8,251 */
	0x1,		/* 8,252 */
	0x1,		/* 8,253 */
	0x1,		/* 8,254 */
	0x1,		/* 8,255 */
	0x1,		/* 9,0 */
	0x1,		/* 9,1 */
	0x9,		/* 9,2 */
	0x1,		/* 9,3 */
	0x1,		/* 9,4 */
	0xb,		/* 9,5 */
	0xb,		/* 9,6 */
	0xb,		/* 9,7 */
	0xb,		/* 9,8 */
	0xb,		/* 9,9 */
	0xb,		/* 9,10 */
	0x1,		/* 9,11 */
	0x1,		/* 9,12 */
	0x1,		/* 9,13 */
	0x1,		/* 9,14 */
	0xb,		/* 9,15 */
	0xb,		/* 9,16 */
	0x1,		/* 9,17 */
	0x1,		/* 9,18 */
	0xb,		/* 9,19 */
	0xb,		/* 9,20 */
	0xb,		/* 9,21 */
	0xb,		/* 9,22 */
	0xb,		/* 9,23 */
	0xb,		/* 9,24 */
	0xb,		/* 9,25 */
	0xb,		/* 9,26 */
	0xb,		/* 9,27 */
	0xb,		/* 9,28 */
	0xb,		/* 9,29 */
	0xb,		/* 9,30 */
	0xb,		/* 9,31 */
	0xb,		/* 9,32 */
	0xb,		/* 9,33 */
	0xb,		/* 9,34 */
	0xb,		/* 9,35 */
	0xb,		/* 9,36 */
	0xb,		/* 9,37 */
	0xb,		/* 9,38 */
	0xb,		/* 9,39 */
	0xb,		/* 9,40 */
	0x1,		/* 9,41 */
	0xb,		/* 9,42 */
	0xb,		/* 9,43 */
	0xb,		/* 9,44 */
	0xb,		/* 9,45 */
	0xb,		/* 9,46 */
	0xb,		/* 9,47 */
	0xb,		/* 9,48 */
	0x1,		/* 9,49 */
	0xb,		/* 9,50 */
	0xb,		/* 9,51 */
	0x1,		/* 9,52 */
	0xb,		/* 9,53 */
	0xb,		/* 9,54 */
	0x1,		/* 9,55 */
	0xb,		/* 9,56 */
	0xb,		/* 9,57 */
	0x1,		/* 9,58 */
	0x1,		/* 9,59 */
	0x9,		/* 9,60 */
	0x1,		/* 9,61 */
	0x9,		/* 9,62 */
	0x9,		/* 9,63 */
	0x9,		/* 9,64 */
	0x9,		/* 9,65 */
	0x9,		/* 9,66 */
	0x1,		/* 9,67 */
	0x1,		/* 9,68 */
	0x1,		/* 9,69 */
	0x1,		/* 9,70 */
	0x9,		/* 9,71 */
	0x9,		/* 9,72 */
	0x1,		/* 9,73 */
	0x1,		/* 9,74 */
	0x9,		/* 9,75 */
	0x9,		/* 9,76 */
	0x9,		/* 9,77 */
	0x1,		/* 9,78 */
	0x1,		/* 9,79 */
	0x1,		/* 9,80 */
	0x1,		/* 9,81 */
	0x1,		/* 9,82 */
	0x1,		/* 9,83 */
	0x1,		/* 9,84 */
	0x1,		/* 9,85 */
	0x1,		/* 9,86 */
	0x1,		/* 9,87 */
	0x1,		/* 9,88 */
	0xb,		/* 9,89 */
	0xb,		/* 9,90 */
	0xb,		/* 9,91 */
	0xb,		/* 9,92 */
	0x1,		/* 9,93 */
	0xb,		/* 9,94 */
	0x1,		/* 9,95 */
	0x1,		/* 9,96 */
	0x1,		/* 9,97 */
	0x1,		/* 9,98 */
	0x1,		/* 9,99 */
	0x1,		/* 9,100 */
	0x1,		/* 9,101 */
	0x9,		/* 9,102 */
	0x9,		/* 9,103 */
	0x9,		/* 9,104 */
	0x9,		/* 9,105 */
	0x9,		/* 9,106 */
	0x9,		/* 9,107 */
	0x9,		/* 9,108 */
	0x9,		/* 9,109 */
	0x9,		/* 9,110 */
	0x9,		/* 9,111 */
	0x9,		/* 9,112 */
	0x9,		/* 9,113 */
	0xb,		/* 9,114 */
	0xb,		/* 9,115 */
	0xb,		/* 9,116 */
	0x1,		/* 9,117 */
	0x1,		/* 9,118 */
	0x1,		/* 9,119 */
	0x1,		/* 9,120 */
	0x1,		/* 9,121 */
	0x1,		/* 9,122 */
	0x1,		/* 9,123 */
	0x1,		/* 9,124 */
	0x1,		/* 9,125 */
	0x1,		/* 9,126 */
	0x1,		/* 9,127 */
	0x1,		/* 9,128 */
	0x9,		/* 9,129 */
	0x9,		/* 9,130 */
	0x9,		/* 9,131 */
	0x1,		/* 9,132 */
	0xb,		/* 9,133 */
	0xb,		/* 9,134 */
	0xb,		/* 9,135 */
	0xb,		/* 9,136 */
	0xb,		/* 9,137 */
	0xb,		/* 9,138 */
	0xb,		/* 9,139 */
	0x1,		/* 9,140 */
	0xb,		/* 9,141 */
	0x1,		/* 9,142 */
	0xb,		/* 9,143 */
	0xb,		/* 9,144 */
	0xb,		/* 9,145 */
	0x1,		/* 9,146 */
	0xb,		/* 9,147 */
	0xb,		/* 9,148 */
	0xb,		/* 9,149 */
	0xb,		/* 9,150 */
	0xb,		/* 9,151 */
	0xb,		/* 9,152 */
	0xb,		/* 9,153 */
	0xb,		/* 9,154 */
	0xb,		/* 9,155 */
	0xb,		/* 9,156 */
	0xb,		/* 9,157 */
	0xb,		/* 9,158 */
	0xb,		/* 9,159 */
	0xb,		/* 9,160 */
	0xb,		/* 9,161 */
	0xb,		/* 9,162 */
	0xb,		/* 9,163 */
	0xb,		/* 9,164 */
	0xb,		/* 9,165 */
	0xb,		/* 9,166 */
	0xb,		/* 9,167 */
	0xb,		/* 9,168 */
	0x1,		/* 9,169 */
	0xb,		/* 9,170 */
	0xb,		/* 9,171 */
	0xb,		/* 9,172 */
	0xb,		/* 9,173 */
	0xb,		/* 9,174 */
	0xb,		/* 9,175 */
	0xb,		/* 9,176 */
	0x1,		/* 9,177 */
	0xb,		/* 9,178 */
	0xb,		/* 9,179 */
	0x1,		/* 9,180 */
	0xb,		/* 9,181 */
	0xb,		/* 9,182 */
	0xb,		/* 9,183 */
	0xb,		/* 9,184 */
	0xb,		/* 9,185 */
	0x1,		/* 9,186 */
	0x1,		/* 9,187 */
	0x9,		/* 9,188 */
	0xb,		/* 9,189 */
	0x9,		/* 9,190 */
	0x9,		/* 9,191 */
	0x9,		/* 9,192 */
	0x9,		/* 9,193 */
	0x9,		/* 9,194 */
	0x9,		/* 9,195 */
	0x9,		/* 9,196 */
	0x9,		/* 9,197 */
	0x1,		/* 9,198 */
	0x9,		/* 9,199 */
	0x9,		/* 9,200 */
	0x9,		/* 9,201 */
	0x1,		/* 9,202 */
	0x9,		/* 9,203 */
	0x9,		/* 9,204 */
	0x9,		/* 9,205 */
	0x1,		/* 9,206 */
	0x1,		/* 9,207 */
	0x1,		/* 9,208 */
	0x1,		/* 9,209 */
	0x1,		/* 9,210 */
	0x1,		/* 9,211 */
	0x1,		/* 9,212 */
	0x1,		/* 9,213 */
	0x1,		/* 9,214 */
	0x1,		/* 9,215 */
	0x1,		/* 9,216 */
	0x1,		/* 9,217 */
	0x1,		/* 9,218 */
	0x1,		/* 9,219 */
	0x1,		/* 9,220 */
	0x1,		/* 9,221 */
	0x1,		/* 9,222 */
	0x1,		/* 9,223 */
	0xb,		/* 9,224 */
	0x1,		/* 9,225 */
	0x1,		/* 9,226 */
	0x1,		/* 9,227 */
	0x1,		/* 9,228 */
	0x1,		/* 9,229 */
	0x9,		/* 9,230 */
	0x9,		/* 9,231 */
	0x9,		/* 9,232 */
	0x9,		/* 9,233 */
	0x9,		/* 9,234 */
	0x9,		/* 9,235 */
	0x9,		/* 9,236 */
	0x9,		/* 9,237 */
	0x9,		/* 9,238 */
	0x9,		/* 9,239 */
	0x1,		/* 9,240 */
	0x1,		/* 9,241 */
	0x1,		/* 9,242 */
	0x1,		/* 9,243 */
	0x1,		/* 9,244 */
	0x1,		/* 9,245 */
	0x1,		/* 9,246 */
	0x1,		/* 9,247 */
	0x1,		/* 9,248 */
	0x1,		/* 9,249 */
	0x1,		/* 9,250 */
	0x1,		/* 9,251 */
	0x1,		/* 9,252 */
	0x1,		/* 9,253 */
	0x1,		/* 9,254 */
	0x1,		/* 9,255 */
	0x1,		/* 10,0 */
	0x9,		/* 10,1 */
	0x9,		/* 10,2 */
	0x9,		/* 10,3 */
	0x1,		/* 10,4 */
	0xb,		/* 10,5 */
	0xb,		/* 10,6 */
	0xb,		/* 10,7 */
	0xb,		/* 10,8 */
	0xb,		/* 10,9 */
	0xb,		/* 10,10 */
	0xb,		/* 10,11 */
	0xb,		/* 10,12 */
	0x1,		/* 10,13 */
	0x1,		/* 10,14 */
	0xb,		/* 10,15 */
	0xb,		/* 10,16 */
	0x1,		/* 10,17 */
	0x1,		/* 10,18 */
	0xb,		/* 10,19 */
	0xb,		/* 10,20 */
	0xb,		/* 10,21 */
	0xb,		/* 10,22 */
	0xb,		/* 10,23 */
	0xb,		/* 10,24 */
	0xb,		/* 10,25 */
	0xb,		/* 10,26 */
	0xb,		/* 10,27 */
	0xb,		/* 10,28 */
	0xb,		/* 10,29 */
	0xb,		/* 10,30 */
	0xb,		/* 10,31 */
	0xb,		/* 10,32 */
	0xb,		/* 10,33 */
	0xb,		/* 10,34 */
	0xb,		/* 10,35 */
	0xb,		/* 10,36 */
	0xb,		/* 10,37 */
	0xb,		/* 10,38 */
	0xb,		/* 10,39 */
	0xb,		/* 10,40 */
	0x1,		/* 10,41 */
	0xb,		/* 10,42 */
	0xb,		/* 10,43 */
	0xb,		/* 10,44 */
	0xb,		/* 10,45 */
	0xb,		/* 10,46 */
	0xb,		/* 10,47 */
	0xb,		/* 10,48 */
	0x1,		/* 10,49 */
	0xb,		/* 10,50 */
	0xb,		/* 10,51 */
	0x1,		/* 10,52 */
	0x1,		/* 10,53 */
	0xb,		/* 10,54 */
	0xb,		/* 10,55 */
	0xb,		/* 10,56 */
	0xb,		/* 10,57 */
	0x1,		/* 10,58 */
	0x1,		/* 10,59 */
	0x9,		/* 10,60 */
	0xb,		/* 10,61 */
	0x9,		/* 10,62 */
	0x9,		/* 10,63 */
	0x9,		/* 10,64 */
	0x9,		/* 10,65 */
	0x9,		/* 10,66 */
	0x9,		/* 10,67 */
	0x1,		/* 10,68 */
	0x1,		/* 10,69 */
	0x1,		/* 10,70 */
	0x9,		/* 10,71 */
	0x9,		/* 10,72 */
	0x1,		/* 10,73 */
	0x1,		/* 10,74 */
	0x9,		/* 10,75 */
	0x9,		/* 10,76 */
	0x9,		/* 10,77 */
	0x1,		/* 10,78 */
	0x1,		/* 10,79 */
	0x1,		/* 10,80 */
	0x1,		/* 10,81 */
	0x1,		/* 10,82 */
	0x1,		/* 10,83 */
	0x1,		/* 10,84 */
	0x1,		/* 10,85 */
	0x9,		/* 10,86 */
	0x9,		/* 10,87 */
	0x1,		/* 10,88 */
	0x1,		/* 10,89 */
	0x1,		/* 10,90 */
	0x1,		/* 10,91 */
	0xb,		/* 10,92 */
	0xb,		/* 10,93 */
	0x1,		/* 10,94 */
	0xb,		/* 10,95 */
	0xb,		/* 10,96 */
	0xb,		/* 10,97 */
	0x1,		/* 10,98 */
	0x1,		/* 10,99 */
	0x1,		/* 10,100 */
	0x1,		/* 10,101 */
	0x9,		/* 10,102 */
	0x9,		/* 10,103 */
	0x9,		/* 10,104 */
	0x9,		/* 10,105 */
	0x9,		/* 10,106 */
	0x9,		/* 10,107 */
	0x9,		/* 10,108 */
	0x9,		/* 10,109 */
	0x9,		/* 10,110 */
	0x9,		/* 10,111 */
	0x1,		/* 10,112 */
	0x1,		/* 10,113 */
	0x1,		/* 10,114 */
	0x1,		/* 10,115 */
	0x1,		/* 10,116 */
	0x1,		/* 10,117 */
	0x1,		/* 10,118 */
	0x1,		/* 10,119 */
	0x1,		/* 10,120 */
	0x1,		/* 10,121 */
	0x1,		/* 10,122 */
	0x1,		/* 10,123 */
	0x1,		/* 10,124 */
	0x1,		/* 10,125 */
	0x1,		/* 10,126 */
	0x1,		/* 10,127 */
	0x1,		/* 10,128 */
	0x1,		/* 10,129 */
	0x9,		/* 10,130 */
	0x9,		/* 10,131 */
	0x1,		/* 10,132 */
	0xb,		/* 10,133 */
	0xb,		/* 10,134 */
	0xb,		/* 10,135 */
	0xb,		/* 10,136 */
	0xb,		/* 10,137 */
	0xb,		/* 10,138 */
	0x1,		/* 10,139 */
	0x1,		/* 10,140 */
	0x1,		/* 10,141 */
	0xb,		/* 10,142 */
	0xb,		/* 10,143 */
	0xb,		/* 10,144 */
	0x1,		/* 10,145 */
	0xb,		/* 10,146 */
	0xb,		/* 10,147 */
	0xb,		/* 10,148 */
	0xb,		/* 10,149 */
	0x1,		/* 10,150 */
	0x1,		/* 10,151 */
	0x1,		/* 10,152 */
	0xb,		/* 10,153 */
	0xb,		/* 10,154 */
	0x1,		/* 10,155 */
	0xb,		/* 10,156 */
	0x1,		/* 10,157 */
	0xb,		/* 10,158 */
	0xb,		/* 10,159 */
	0x1,		/* 10,160 */
	0x1,		/* 10,161 */
	0x1,		/* 10,162 */
	0xb,		/* 10,163 */
	0xb,		/* 10,164 */
	0x1,		/* 10,165 */
	0x1,		/* 10,166 */
	0x1,		/* 10,167 */
	0xb,		/* 10,168 */
	0xb,		/* 10,169 */
	0xb,		/* 10,170 */
	0x1,		/* 10,171 */
	0x1,		/* 10,172 */
	0x1,		/* 10,173 */
	0xb,		/* 10,174 */
	0xb,		/* 10,175 */
	0xb,		/* 10,176 */
	0xb,		/* 10,177 */
	0xb,		/* 10,178 */
	0xb,		/* 10,179 */
	0xb,		/* 10,180 */
	0xb,		/* 10,181 */
	0x1,		/* 10,182 */
	0xb,		/* 10,183 */
	0xb,		/* 10,184 */
	0xb,		/* 10,185 */
	0x1,		/* 10,186 */
	0x1,		/* 10,187 */
	0x1,		/* 10,188 */
	0x1,		/* 10,189 */
	0x9,		/* 10,190 */
	0x9,		/* 10,191 */
	0x9,		/* 10,192 */
	0x9,		/* 10,193 */
	0x9,		/* 10,194 */
	0x1,		/* 10,195 */
	0x1,		/* 10,196 */
	0x1,		/* 10,197 */
	0x9,		/* 10,198 */
	0x9,		/* 10,199 */
	0x9,		/* 10,200 */
	0x1,		/* 10,201 */
	0x9,		/* 10,202 */
	0x9,		/* 10,203 */
	0x9,		/* 10,204 */
	0x9,		/* 10,205 */
	0x1,		/* 10,206 */
	0x1,		/* 10,207 */
	0x1,		/* 10,208 */
	0x1,		/* 10,209 */
	0x1,		/* 10,210 */
	0x1,		/* 10,211 */
	0x1,		/* 10,212 */
	0x1,		/* 10,213 */
	0x1,		/* 10,214 */
	0x9,		/* 10,215 */
	0x1,		/* 10,216 */
	0x1,		/* 10,217 */
	0x1,		/* 10,218 */
	0x1,		/* 10,219 */
	0x1,		/* 10,220 */
	0x1,		/* 10,221 */
	0x1,		/* 10,222 */
	0x1,		/* 10,223 */
	0x1,		/* 10,224 */
	0x1,		/* 10,225 */
	0x1,		/* 10,226 */
	0x1,		/* 10,227 */
	0x1,		/* 10,228 */
	0x1,		/* 10,229 */
	0x1,		/* 10,230 */
	0x9,		/* 10,231 */
	0x9,		/* 10,232 */
	0x9,		/* 10,233 */
	0x9,		/* 10,234 */
	0x9,		/* 10,235 */
	0x9,		/* 10,236 */
	0x9,		/* 10,237 */
	0x9,		/* 10,238 */
	0x9,		/* 10,239 */
	0x1,		/* 10,240 */
	0x1,		/* 10,241 */
	0x1,		/* 10,242 */
	0x1,		/* 10,243 */
	0x1,		/* 10,244 */
	0x1,		/* 10,245 */
	0x1,		/* 10,246 */
	0x1,		/* 10,247 */
	0x1,		/* 10,248 */
	0x1,		/* 10,249 */
	0x1,		/* 10,250 */
	0x1,		/* 10,251 */
	0x1,		/* 10,252 */
	0x1,		/* 10,253 */
	0x1,		/* 10,254 */
	0x1,		/* 10,255 */
	0x1,		/* 11,0 */
	0x9,		/* 11,1 */
	0x9,		/* 11,2 */
	0x9,		/* 11,3 */
	0x1,		/* 11,4 */
	0xb,		/* 11,5 */
	0xb,		/* 11,6 */
	0xb,		/* 11,7 */
	0xb,		/* 11,8 */
	0xb,		/* 11,9 */
	0xb,		/* 11,10 */
	0xb,		/* 11,11 */
	0xb,		/* 11,12 */
	0x1,		/* 11,13 */
	0xb,		/* 11,14 */
	0xb,		/* 11,15 */
	0xb,		/* 11,16 */
	0x1,		/* 11,17 */
	0xb,		/* 11,18 */
	0xb,		/* 11,19 */
	0xb,		/* 11,20 */
	0xb,		/* 11,21 */
	0xb,		/* 11,22 */
	0xb,		/* 11,23 */
	0xb,		/* 11,24 */
	0xb,		/* 11,25 */
	0xb,		/* 11,26 */
	0xb,		/* 11,27 */
	0xb,		/* 11,28 */
	0xb,		/* 11,29 */
	0xb,		/* 11,30 */
	0xb,		/* 11,31 */
	0xb,		/* 11,32 */
	0xb,		/* 11,33 */
	0xb,		/* 11,34 */
	0xb,		/* 11,35 */
	0xb,		/* 11,36 */
	0xb,		/* 11,37 */
	0xb,		/* 11,38 */
	0xb,		/* 11,39 */
	0xb,		/* 11,40 */
	0x1,		/* 11,41 */
	0xb,		/* 11,42 */
	0xb,		/* 11,43 */
	0xb,		/* 11,44 */
	0xb,		/* 11,45 */
	0xb,		/* 11,46 */
	0xb,		/* 11,47 */
	0xb,		/* 11,48 */
	0xb,		/* 11,49 */
	0xb,		/* 11,50 */
	0xb,		/* 11,51 */
	0x1,		/* 11,52 */
	0xb,		/* 11,53 */
	0xb,		/* 11,54 */
	0xb,		/* 11,55 */
	0xb,		/* 11,56 */
	0xb,		/* 11,57 */
	0x1,		/* 11,58 */
	0x1,		/* 11,59 */
	0x1,		/* 11,60 */
	0x1,		/* 11,61 */
	0x9,		/* 11,62 */
	0x9,		/* 11,63 */
	0x9,		/* 11,64 */
	0x9,		/* 11,65 */
	0x9,		/* 11,66 */
	0x9,		/* 11,67 */
	0x9,		/* 11,68 */
	0x1,		/* 11,69 */
	0x9,		/* 11,70 */
	0x9,		/* 11,71 */
	0x9,		/* 11,72 */
	0x1,		/* 11,73 */
	0x9,		/* 11,74 */
	0x9,		/* 11,75 */
	0x9,		/* 11,76 */
	0x9,		/* 11,77 */
	0x1,		/* 11,78 */
	0x1,		/* 11,79 */
	0x1,		/* 11,80 */
	0x1,		/* 11,81 */
	0x1,		/* 11,82 */
	0x1,		/* 11,83 */
	0x1,		/* 11,84 */
	0x9,		/* 11,85 */
	0x9,		/* 11,86 */
	0x1,		/* 11,87 */
	0x1,		/* 11,88 */
	0x1,		/* 11,89 */
	0x1,		/* 11,90 */
	0x1,		/* 11,91 */
	0x1,		/* 11,92 */
	0x1,		/* 11,93 */
	0x1,		/* 11,94 */
	0x1,		/* 11,95 */
	0xb,		/* 11,96 */
	0xb,		/* 11,97 */
	0x1,		/* 11,98 */
	0x1,		/* 11,99 */
	0x1,		/* 11,100 */
	0x1,		/* 11,101 */
	0x9,		/* 11,102 */
	0x9,		/* 11,103 */
	0x9,		/* 11,104 */
	0x9,		/* 11,105 */
	0x9,		/* 11,106 */
	0x9,		/* 11,107 */
	0x9,		/* 11,108 */
	0x9,		/* 11,109 */
	0x9,		/* 11,110 */
	0x9,		/* 11,111 */
	0x1,		/* 11,112 */
	0x1,		/* 11,113 */
	0x1,		/* 11,114 */
	0x1,		/* 11,115 */
	0x1,		/* 11,116 */
	0x1,		/* 11,117 */
	0x1,		/* 11,118 */
	0x1,		/* 11,119 */
	0x1,		/* 11,120 */
	0x1,		/* 11,121 */
	0x1,		/* 11,122 */
	0x1,		/* 11,123 */
	0x1,		/* 11,124 */
	0x1,		/* 11,125 */
	0x1,		/* 11,126 */
	0x1,		/* 11,127 */
	0x1,		/* 11,128 */
	0x1,		/* 11,129 */
	0x9,		/* 11,130 */
	0x9,		/* 11,131 */
	0x1,		/* 11,132 */
	0xb,		/* 11,133 */
	0xb,		/* 11,134 */
	0xb,		/* 11,135 */
	0xb,		/* 11,136 */
	0xb,		/* 11,137 */
	0xb,		/* 11,138 */
	0xb,		/* 11,139 */
	0xb,		/* 11,140 */
	0x1,		/* 11,141 */
	0xb,		/* 11,142 */
	0xb,		/* 11,143 */
	0xb,		/* 11,144 */
	0x1,		/* 11,145 */
	0xb,		/* 11,146 */
	0xb,		/* 11,147 */
	0xb,		/* 11,148 */
	0xb,		/* 11,149 */
	0xb,		/* 11,150 */
	0xb,		/* 11,151 */
	0xb,		/* 11,152 */
	0xb,		/* 11,153 */
	0xb,		/* 11,154 */
	0xb,		/* 11,155 */
	0xb,		/* 11,156 */
	0xb,		/* 11,157 */
	0xb,		/* 11,158 */
	0xb,		/* 11,159 */
	0xb,		/* 11,160 */
	0xb,		/* 11,161 */
	0xb,		/* 11,162 */
	0xb,		/* 11,163 */
	0xb,		/* 11,164 */
	0xb,		/* 11,165 */
	0xb,		/* 11,166 */
	0xb,		/* 11,167 */
	0xb,		/* 11,168 */
	0x1,		/* 11,169 */
	0xb,		/* 11,170 */
	0xb,		/* 11,171 */
	0xb,		/* 11,172 */
	0xb,		/* 11,173 */
	0xb,		/* 11,174 */
	0xb,		/* 11,175 */
	0xb,		/* 11,176 */
	0xb,		/* 11,177 */
	0xb,		/* 11,178 */
	0xb,		/* 11,179 */
	0x1,		/* 11,180 */
	0xb,		/* 11,181 */
	0xb,		/* 11,182 */
	0xb,		/* 11,183 */
	0xb,		/* 11,184 */
	0xb,		/* 11,185 */
	0x1,		/* 11,186 */
	0x1,		/* 11,187 */
	0x1,		/* 11,188 */
	0x1,		/* 11,189 */
	0x9,		/* 11,190 */
	0x9,		/* 11,191 */
	0x9,		/* 11,192 */
	0x9,		/* 11,193 */
	0x9,		/* 11,194 */
	0x9,		/* 11,195 */
	0x9,		/* 11,196 */
	0x1,		/* 11,197 */
	0x9,		/* 11,198 */
	0x9,		/* 11,199 */
	0x9,		/* 11,200 */
	0x1,		/* 11,201 */
	0x9,		/* 11,202 */
	0x9,		/* 11,203 */
	0x9,		/* 11,204 */
	0x9,		/* 11,205 */
	0x1,		/* 11,206 */
	0x1,		/* 11,207 */
	0x1,		/* 11,208 */
	0x1,		/* 11,209 */
	0x1,		/* 11,210 */
	0x1,		/* 11,211 */
	0x1,		/* 11,212 */
	0x9,		/* 11,213 */
	0x9,		/* 11,214 */
	0x1,		/* 11,215 */
	0x1,		/* 11,216 */
	0x1,		/* 11,217 */
	0x1,		/* 11,218 */
	0x1,		/* 11,219 */
	0x1,		/* 11,220 */
	0x1,		/* 11,221 */
	0xb,		/* 11,222 */
	0x1,		/* 11,223 */
	0xb,		/* 11,224 */
	0xb,		/* 11,225 */
	0x1,		/* 11,226 */
	0x1,		/* 11,227 */
	0x1,		/* 11,228 */
	0x1,		/* 11,229 */
	0x9,		/* 11,230 */
	0x9,		/* 11,231 */
	0x9,		/* 11,232 */
	0x9,		/* 11,233 */
	0x9,		/* 11,234 */
	0x9,		/* 11,235 */
	0x9,		/* 11,236 */
	0x9,		/* 11,237 */
	0x9,		/* 11,238 */
	0x9,		/* 11,239 */
	0x1,		/* 11,240 */
	0x1,		/* 11,241 */
	0x1,		/* 11,242 */
	0x1,		/* 11,243 */
	0x1,		/* 11,244 */
	0x1,		/* 11,245 */
	0x1,		/* 11,246 */
	0x1,		/* 11,247 */
	0x1,		/* 11,248 */
	0x1,		/* 11,249 */
	0x1,		/* 11,250 */
	0x1,		/* 11,251 */
	0x1,		/* 11,252 */
	0x1,		/* 11,253 */
	0x1,		/* 11,254 */
	0x1,		/* 11,255 */
	0x1,		/* 12,0 */
	0x1,		/* 12,1 */
	0x9,		/* 12,2 */
	0x9,		/* 12,3 */
	0x1,		/* 12,4 */
	0xb,		/* 12,5 */
	0xb,		/* 12,6 */
	0xb,		/* 12,7 */
	0xb,		/* 12,8 */
	0xb,		/* 12,9 */
	0xb,		/* 12,10 */
	0xb,		/* 12,11 */
	0xb,		/* 12,12 */
	0x1,		/* 12,13 */
	0xb,		/* 12,14 */
	0xb,		/* 12,15 */
	0xb,		/* 12,16 */
	0x1,		/* 12,17 */
	0xb,		/* 12,18 */
	0xb,		/* 12,19 */
	0xb,		/* 12,20 */
	0xb,		/* 12,21 */
	0xb,		/* 12,22 */
	0xb,		/* 12,23 */
	0xb,		/* 12,24 */
	0xb,		/* 12,25 */
	0xb,		/* 12,26 */
	0xb,		/* 12,27 */
	0xb,		/* 12,28 */
	0xb,		/* 12,29 */
	0xb,		/* 12,30 */
	0xb,		/* 12,31 */
	0xb,		/* 12,32 */
	0xb,		/* 12,33 */
	0xb,		/* 12,34 */
	0xb,		/* 12,35 */
	0xb,		/* 12,36 */
	0xb,		/* 12,37 */
	0xb,		/* 12,38 */
	0xb,		/* 12,39 */
	0xb,		/* 12,40 */
	0x1,		/* 12,41 */
	0xb,		/* 12,42 */
	0xb,		/* 12,43 */
	0xb,		/* 12,44 */
	0xb,		/* 12,45 */
	0xb,		/* 12,46 */
	0xb,		/* 12,47 */
	0xb,		/* 12,48 */
	0xb,		/* 12,49 */
	0xb,		/* 12,50 */
	0xb,		/* 12,51 */
	0xb,		/* 12,52 */
	0xb,		/* 12,53 */
	0xb,		/* 12,54 */
	0xb,		/* 12,55 */
	0xb,		/* 12,56 */
	0xb,		/* 12,57 */
	0x1,		/* 12,58 */
	0x1,		/* 12,59 */
	0x1,		/* 12,60 */
	0x1,		/* 12,61 */
	0x9,		/* 12,62 */
	0x9,		/* 12,63 */
	0x9,		/* 12,64 */
	0x9,		/* 12,65 */
	0x9,		/* 12,66 */
	0x9,		/* 12,67 */
	0x1,		/* 12,68 */
	0x1,		/* 12,69 */
	0x9,		/* 12,70 */
	0x9,		/* 12,71 */
	0x9,		/* 12,72 */
	0x1,		/* 12,73 */
	0x9,		/* 12,74 */
	0x9,		/* 12,75 */
	0x9,		/* 12,76 */
	0x9,		/* 12,77 */
	0x1,		/* 12,78 */
	0x1,		/* 12,79 */
	0x1,		/* 12,80 */
	0x1,		/* 12,81 */
	0x1,		/* 12,82 */
	0x1,		/* 12,83 */
	0x1,		/* 12,84 */
	0x1,		/* 12,85 */
	0x1,		/* 12,86 */
	0x9,		/* 12,87 */
	0x1,		/* 12,88 */
	0x1,		/* 12,89 */
	0x1,		/* 12,90 */
	0x1,		/* 12,91 */
	0x1,		/* 12,92 */
	0x1,		/* 12,93 */
	0x1,		/* 12,94 */
	0x1,		/* 12,95 */
	0xb,		/* 12,96 */
	0xb,		/* 12,97 */
	0x1,		/* 12,98 */
	0x1,		/* 12,99 */
	0x1,		/* 12,100 */
	0x1,		/* 12,101 */
	0x9,		/* 12,102 */
	0x9,		/* 12,103 */
	0x9,		/* 12,104 */
	0x9,		/* 12,105 */
	0x9,		/* 12,106 */
	0x9,		/* 12,107 */
	0x9,		/* 12,108 */
	0x9,		/* 12,109 */
	0x9,		/* 12,110 */
	0x9,		/* 12,111 */
	0x1,		/* 12,112 */
	0x1,		/* 12,113 */
	0x1,		/* 12,114 */
	0x1,		/* 12,115 */
	0x1,		/* 12,116 */
	0x1,		/* 12,117 */
	0x1,		/* 12,118 */
	0x1,		/* 12,119 */
	0x1,		/* 12,120 */
	0x1,		/* 12,121 */
	0x1,		/* 12,122 */
	0x1,		/* 12,123 */
	0x1,		/* 12,124 */
	0x1,		/* 12,125 */
	0x1,		/* 12,126 */
	0x1,		/* 12,127 */
	0x1,		/* 12,128 */
	0x1,		/* 12,129 */
	0x1,		/* 12,130 */
	0x1,		/* 12,131 */
	0x1,		/* 12,132 */
	0x1,		/* 12,133 */
	0x1,		/* 12,134 */
	0x1,		/* 12,135 */
	0x1,		/* 12,136 */
	0x1,		/* 12,137 */
	0x1,		/* 12,138 */
	0x1,		/* 12,139 */
	0x1,		/* 12,140 */
	0x1,		/* 12,141 */
	0x1,		/* 12,142 */
	0x1,		/* 12,143 */
	0x1,		/* 12,144 */
	0x1,		/* 12,145 */
	0x1,		/* 12,146 */
	0x1,		/* 12,147 */
	0x1,		/* 12,148 */
	0x1,		/* 12,149 */
	0x1,		/* 12,150 */
	0x1,		/* 12,151 */
	0x1,		/* 12,152 */
	0x1,		/* 12,153 */
	0x1,		/* 12,154 */
	0x1,		/* 12,155 */
	0x1,		/* 12,156 */
	0x1,		/* 12,157 */
	0x1,		/* 12,158 */
	0x1,		/* 12,159 */
	0x1,		/* 12,160 */
	0x1,		/* 12,161 */
	0x1,		/* 12,162 */
	0x1,		/* 12,163 */
	0x1,		/* 12,164 */
	0x1,		/* 12,165 */
	0x1,		/* 12,166 */
	0x1,		/* 12,167 */
	0x1,		/* 12,168 */
	0x1,		/* 12,169 */
	0x1,		/* 12,170 */
	0x1,		/* 12,171 */
	0x1,		/* 12,172 */
	0x1,		/* 12,173 */
	0x1,		/* 12,174 */
	0x1,		/* 12,175 */
	0x1,		/* 12,176 */
	0x1,		/* 12,177 */
	0x1,		/* 12,178 */
	0x1,		/* 12,179 */
	0x1,		/* 12,180 */
	0x1,		/* 12,181 */
	0x1,		/* 12,182 */
	0x1,		/* 12,183 */
	0x1,		/* 12,184 */
	0x1,		/* 12,185 */
	0x1,		/* 12,186 */
	0x1,		/* 12,187 */
	0x1,		/* 12,188 */
	0x1,		/* 12,189 */
	0x1,		/* 12,190 */
	0x1,		/* 12,191 */
	0x1,		/* 12,192 */
	0x1,		/* 12,193 */
	0x1,		/* 12,194 */
	0x1,		/* 12,195 */
	0x1,		/* 12,196 */
	0x1,		/* 12,197 */
	0x1,		/* 12,198 */
	0x1,		/* 12,199 */
	0x1,		/* 12,200 */
	0x1,		/* 12,201 */
	0x1,		/* 12,202 */
	0x1,		/* 12,203 */
	0x1,		/* 12,204 */
	0x1,		/* 12,205 */
	0x1,		/* 12,206 */
	0x1,		/* 12,207 */
	0x1,		/* 12,208 */
	0x1,		/* 12,209 */
	0x1,		/* 12,210 */
	0x1,		/* 12,211 */
	0x1,		/* 12,212 */
	0x1,		/* 12,213 */
	0x1,		/* 12,214 */
	0x1,		/* 12,215 */
	0x1,		/* 12,216 */
	0x1,		/* 12,217 */
	0x1,		/* 12,218 */
	0x1,		/* 12,219 */
	0x1,		/* 12,220 */
	0x1,		/* 12,221 */
	0x1,		/* 12,222 */
	0x1,		/* 12,223 */
	0x1,		/* 12,224 */
	0x1,		/* 12,225 */
	0x1,		/* 12,226 */
	0x1,		/* 12,227 */
	0x1,		/* 12,228 */
	0x1,		/* 12,229 */
	0x1,		/* 12,230 */
	0x1,		/* 12,231 */
	0x1,		/* 12,232 */
	0x1,		/* 12,233 */
	0x1,		/* 12,234 */
	0x1,		/* 12,235 */
	0x1,		/* 12,236 */
	0x1,		/* 12,237 */
	0x1,		/* 12,238 */
	0x1,		/* 12,239 */
	0x1,		/* 12,240 */
	0x1,		/* 12,241 */
	0x1,		/* 12,242 */
	0x1,		/* 12,243 */
	0x1,		/* 12,244 */
	0x1,		/* 12,245 */
	0x1,		/* 12,246 */
	0x1,		/* 12,247 */
	0x1,		/* 12,248 */
	0x1,		/* 12,249 */
	0x1,		/* 12,250 */
	0x1,		/* 12,251 */
	0x1,		/* 12,252 */
	0x1,		/* 12,253 */
	0x1,		/* 12,254 */
	0x1,		/* 12,255 */
	0x1,		/* 13,0 */
	0xb,		/* 13,1 */
	0xb,		/* 13,2 */
	0xb,		/* 13,3 */
	0xb,		/* 13,4 */
	0xb,		/* 13,5 */
	0xb,		/* 13,6 */
	0xb,		/* 13,7 */
	0xb,		/* 13,8 */
	0xb,		/* 13,9 */
	0xb,		/* 13,10 */
	0xb,		/* 13,11 */
	0xb,		/* 13,12 */
	0xb,		/* 13,13 */
	0xb,		/* 13,14 */
	0xb,		/* 13,15 */
	0xb,		/* 13,16 */
	0xb,		/* 13,17 */
	0xb,		/* 13,18 */
	0xb,		/* 13,19 */
	0xb,		/* 13,20 */
	0xb,		/* 13,21 */
	0xb,		/* 13,22 */
	0xb,		/* 13,23 */
	0xb,		/* 13,24 */
	0xb,		/* 13,25 */
	0xb,		/* 13,26 */
	0xb,		/* 13,27 */
	0xb,		/* 13,28 */
	0xb,		/* 13,29 */
	0xb,		/* 13,30 */
	0xb,		/* 13,31 */
	0xb,		/* 13,32 */
	0xb,		/* 13,33 */
	0xb,		/* 13,34 */
	0xb,		/* 13,35 */
	0xb,		/* 13,36 */
	0xb,		/* 13,37 */
	0xb,		/* 13,38 */
	0xb,		/* 13,39 */
	0xb,		/* 13,40 */
	0xb,		/* 13,41 */
	0xb,		/* 13,42 */
	0xb,		/* 13,43 */
	0xb,		/* 13,44 */
	0xb,		/* 13,45 */
	0xb,		/* 13,46 */
	0x1,		/* 13,47 */
	0xb,		/* 13,48 */
	0x9,		/* 13,49 */
	0xb,		/* 13,50 */
	0xb,		/* 13,51 */
	0x9,		/* 13,52 */
	0x9,		/* 13,53 */
	0x9,		/* 13,54 */
	0x9,		/* 13,55 */
	0x9,		/* 13,56 */
	0x9,		/* 13,57 */
	0x9,		/* 13,58 */
	0x1,		/* 13,59 */
	0x1,		/* 13,60 */
	0x1,		/* 13,61 */
	0x1,		/* 13,62 */
	0x1,		/* 13,63 */
	0xb,		/* 13,64 */
	0xb,		/* 13,65 */
	0xb,		/* 13,66 */
	0xb,		/* 13,67 */
	0xb,		/* 13,68 */
	0xb,		/* 13,69 */
	0x9,		/* 13,70 */
	0x9,		/* 13,71 */
	0x9,		/* 13,72 */
	0x9,		/* 13,73 */
	0x9,		/* 13,74 */
	0x9,		/* 13,75 */
	0x9,		/* 13,76 */
	0x9,		/* 13,77 */
	0x9,		/* 13,78 */
	0x1,		/* 13,79 */
	0x9,		/* 13,80 */
	0x9,		/* 13,81 */
	0x9,		/* 13,82 */
	0x9,		/* 13,83 */
	0x9,		/* 13,84 */
	0x9,		/* 13,85 */
	0x9,		/* 13,86 */
	0x9,		/* 13,87 */
	0x9,		/* 13,88 */
	0x9,		/* 13,89 */
	0x1,		/* 13,90 */
	0x1,		/* 13,91 */
	0x1,		/* 13,92 */
	0x1,		/* 13,93 */
	0x1,		/* 13,94 */
	0x1,		/* 13,95 */
	0x1,		/* 13,96 */
	0x1,		/* 13,97 */
	0x1,		/* 13,98 */
	0x1,		/* 13,99 */
	0x1,		/* 13,100 */
	0x1,		/* 13,101 */
	0x1,		/* 13,102 */
	0x1,		/* 13,103 */
	0x1,		/* 13,104 */
	0x1,		/* 13,105 */
	0x1,		/* 13,106 */
	0x1,		/* 13,107 */
	0x1,		/* 13,108 */
	0x1,		/* 13,109 */
	0x1,		/* 13,110 */
	0x1,		/* 13,111 */
	0x1,		/* 13,112 */
	0x1,		/* 13,113 */
	0x1,		/* 13,114 */
	0x1,		/* 13,115 */
	0x1,		/* 13,116 */
	0x1,		/* 13,117 */
	0x1,		/* 13,118 */
	0x1,		/* 13,119 */
	0x1,		/* 13,120 */
	0x1,		/* 13,121 */
	0x1,		/* 13,122 */
	0x1,		/* 13,123 */
	0x1,		/* 13,124 */
	0x1,		/* 13,125 */
	0x1,		/* 13,126 */
	0x1,		/* 13,127 */
	0x1,		/* 13,128 */
	0xb,		/* 13,129 */
	0xb,		/* 13,130 */
	0x1,		/* 13,131 */
	0xb,		/* 13,132 */
	0x1,		/* 13,133 */
	0x1,		/* 13,134 */
	0xb,		/* 13,135 */
	0xb,		/* 13,136 */
	0x1,		/* 13,137 */
	0xb,		/* 13,138 */
	0x1,		/* 13,139 */
	0x1,		/* 13,140 */
	0xb,		/* 13,141 */
	0x1,		/* 13,142 */
	0x1,		/* 13,143 */
	0x1,		/* 13,144 */
	0x1,		/* 13,145 */
	0x1,		/* 13,146 */
	0x1,		/* 13,147 */
	0xb,		/* 13,148 */
	0xb,		/* 13,149 */
	0xb,		/* 13,150 */
	0xb,		/* 13,151 */
	0x1,		/* 13,152 */
	0xb,		/* 13,153 */
	0xb,		/* 13,154 */
	0xb,		/* 13,155 */
	0xb,		/* 13,156 */
	0xb,		/* 13,157 */
	0xb,		/* 13,158 */
	0xb,		/* 13,159 */
	0x1,		/* 13,160 */
	0xb,		/* 13,161 */
	0xb,		/* 13,162 */
	0xb,		/* 13,163 */
	0x1,		/* 13,164 */
	0xb,		/* 13,165 */
	0x1,		/* 13,166 */
	0xb,		/* 13,167 */
	0x1,		/* 13,168 */
	0x1,		/* 13,169 */
	0xb,		/* 13,170 */
	0xb,		/* 13,171 */
	0x1,		/* 13,172 */
	0xb,		/* 13,173 */
	0xb,		/* 13,174 */
	0x1,		/* 13,175 */
	0xb,		/* 13,176 */
	0x9,		/* 13,177 */
	0xb,		/* 13,178 */
	0xb,		/* 13,179 */
	0x9,		/* 13,180 */
	0x9,		/* 13,181 */
	0x9,		/* 13,182 */
	0x9,		/* 13,183 */
	0x9,		/* 13,184 */
	0x9,		/* 13,185 */
	0x1,		/* 13,186 */
	0x9,		/* 13,187 */
	0x9,		/* 13,188 */
	0xb,		/* 13,189 */
	0x1,		/* 13,190 */
	0x1,		/* 13,191 */
	0xb,		/* 13,192 */
	0xb,		/* 13,193 */
	0xb,		/* 13,194 */
	0xb,		/* 13,195 */
	0xb,		/* 13,196 */
	0x1,		/* 13,197 */
	0x9,		/* 13,198 */
	0x1,		/* 13,199 */
	0x9,		/* 13,200 */
	0x9,		/* 13,201 */
	0x9,		/* 13,202 */
	0x9,		/* 13,203 */
	0x9,		/* 13,204 */
	0x9,		/* 13,205 */
	0x1,		/* 13,206 */
	0x1,		/* 13,207 */
	0x9,		/* 13,208 */
	0x9,		/* 13,209 */
	0x9,		/* 13,210 */
	0x9,		/* 13,211 */
	0x9,		/* 13,212 */
	0x9,		/* 13,213 */
	0x9,		/* 13,214 */
	0x9,		/* 13,215 */
	0x9,		/* 13,216 */
	0x9,		/* 13,217 */
	0x1,		/* 13,218 */
	0x1,		/* 13,219 */
	0x1,		/* 13,220 */
	0x1,		/* 13,221 */
	0x1,		/* 13,222 */
	0x1,		/* 13,223 */
	0x1,		/* 13,224 */
	0x1,		/* 13,225 */
	0x1,		/* 13,226 */
	0x1,		/* 13,227 */
	0x1,		/* 13,228 */
	0x1,		/* 13,229 */
	0x1,		/* 13,230 */
	0x1,		/* 13,231 */
	0x1,		/* 13,232 */
	0x1,		/* 13,233 */
	0x1,		/* 13,234 */
	0x1,		/* 13,235 */
	0x1,		/* 13,236 */
	0x1,		/* 13,237 */
	0x1,		/* 13,238 */
	0x1,		/* 13,239 */
	0x1,		/* 13,240 */
	0x1,		/* 13,241 */
	0x1,		/* 13,242 */
	0x1,		/* 13,243 */
	0x1,		/* 13,244 */
	0x1,		/* 13,245 */
	0x1,		/* 13,246 */
	0x1,		/* 13,247 */
	0x1,		/* 13,248 */
	0x1,		/* 13,249 */
	0x1,		/* 13,250 */
	0x1,		/* 13,251 */
	0x1,		/* 13,252 */
	0x1,		/* 13,253 */
	0x1,		/* 13,254 */
	0x1,		/* 13,255 */
	0x1,		/* 14,0 */
	0x1,		/* 14,1 */
	0x1,		/* 14,2 */
	0x1,		/* 14,3 */
	0x1,		/* 14,4 */
	0x1,		/* 14,5 */
	0x1,		/* 14,6 */
	0x1,		/* 14,7 */
	0x1,		/* 14,8 */
	0x1,		/* 14,9 */
	0x1,		/* 14,10 */
	0x1,		/* 14,11 */
	0x1,		/* 14,12 */
	0x1,		/* 14,13 */
	0x1,		/* 14,14 */
	0x1,		/* 14,15 */
	0x1,		/* 14,16 */
	0x1,		/* 14,17 */
	0x1,		/* 14,18 */
	0x1,		/* 14,19 */
	0x1,		/* 14,20 */
	0x1,		/* 14,21 */
	0x1,		/* 14,22 */
	0x1,		/* 14,23 */
	0x9,		/* 14,24 */
	0x9,		/* 14,25 */
	0x1,		/* 14,26 */
	0x1,		/* 14,27 */
	0x1,		/* 14,28 */
	0x1,		/* 14,29 */
	0x1,		/* 14,30 */
	0x1,		/* 14,31 */
	0x9,		/* 14,32 */
	0x9,		/* 14,33 */
	0x9,		/* 14,34 */
	0x9,		/* 14,35 */
	0x9,		/* 14,36 */
	0x9,		/* 14,37 */
	0x9,		/* 14,38 */
	0x9,		/* 14,39 */
	0x9,		/* 14,40 */
	0x9,		/* 14,41 */
	0x1,		/* 14,42 */
	0x1,		/* 14,43 */
	0x1,		/* 14,44 */
	0x1,		/* 14,45 */
	0x1,		/* 14,46 */
	0x1,		/* 14,47 */
	0x1,		/* 14,48 */
	0x1,		/* 14,49 */
	0x1,		/* 14,50 */
	0x1,		/* 14,51 */
	0x1,		/* 14,52 */
	0x9,		/* 14,53 */
	0x1,		/* 14,54 */
	0x9,		/* 14,55 */
	0x1,		/* 14,56 */
	0x9,		/* 14,57 */
	0x1,		/* 14,58 */
	0x1,		/* 14,59 */
	0x1,		/* 14,60 */
	0x1,		/* 14,61 */
	0x9,		/* 14,62 */
	0x9,		/* 14,63 */
	0xb,		/* 14,64 */
	0xb,		/* 14,65 */
	0xb,		/* 14,66 */
	0xb,		/* 14,67 */
	0xb,		/* 14,68 */
	0xb,		/* 14,69 */
	0xb,		/* 14,70 */
	0xb,		/* 14,71 */
	0x1,		/* 14,72 */
	0xb,		/* 14,73 */
	0xb,		/* 14,74 */
	0xb,		/* 14,75 */
	0xb,		/* 14,76 */
	0xb,		/* 14,77 */
	0xb,		/* 14,78 */
	0xb,		/* 14,79 */
	0xb,		/* 14,80 */
	0xb,		/* 14,81 */
	0xb,		/* 14,82 */
	0xb,		/* 14,83 */
	0xb,		/* 14,84 */
	0xb,		/* 14,85 */
	0xb,		/* 14,86 */
	0xb,		/* 14,87 */
	0xb,		/* 14,88 */
	0xb,		/* 14,89 */
	0xb,		/* 14,90 */
	0xb,		/* 14,91 */
	0xb,		/* 14,92 */
	0xb,		/* 14,93 */
	0xb,		/* 14,94 */
	0xb,		/* 14,95 */
	0xb,		/* 14,96 */
	0xb,		/* 14,97 */
	0xb,		/* 14,98 */
	0xb,		/* 14,99 */
	0xb,		/* 14,100 */
	0xb,		/* 14,101 */
	0xb,		/* 14,102 */
	0xb,		/* 14,103 */
	0xb,		/* 14,104 */
	0xb,		/* 14,105 */
	0x1,		/* 14,106 */
	0x1,		/* 14,107 */
	0x1,		/* 14,108 */
	0x1,		/* 14,109 */
	0x1,		/* 14,110 */
	0x1,		/* 14,111 */
	0x1,		/* 14,112 */
	0x9,		/* 14,113 */
	0x9,		/* 14,114 */
	0x9,		/* 14,115 */
	0x9,		/* 14,116 */
	0x9,		/* 14,117 */
	0x9,		/* 14,118 */
	0x9,		/* 14,119 */
	0x9,		/* 14,120 */
	0x9,		/* 14,121 */
	0x9,		/* 14,122 */
	0x9,		/* 14,123 */
	0x9,		/* 14,124 */
	0x9,		/* 14,125 */
	0x9,		/* 14,126 */
	0x9,		/* 14,127 */
	0x9,		/* 14,128 */
	0x9,		/* 14,129 */
	0x9,		/* 14,130 */
	0x9,		/* 14,131 */
	0x9,		/* 14,132 */
	0x1,		/* 14,133 */
	0x9,		/* 14,134 */
	0x9,		/* 14,135 */
	0x9,		/* 14,136 */
	0x9,		/* 14,137 */
	0x9,		/* 14,138 */
	0x9,		/* 14,139 */
	0x1,		/* 14,140 */
	0x1,		/* 14,141 */
	0x1,		/* 14,142 */
	0x1,		/* 14,143 */
	0x9,		/* 14,144 */
	0x9,		/* 14,145 */
	0x9,		/* 14,146 */
	0x9,		/* 14,147 */
	0x9,		/* 14,148 */
	0x9,		/* 14,149 */
	0x1,		/* 14,150 */
	0x9,		/* 14,151 */
	0x1,		/* 14,152 */
	0x9,		/* 14,153 */
	0x9,		/* 14,154 */
	0x9,		/* 14,155 */
	0x9,		/* 14,156 */
	0x9,		/* 14,157 */
	0x9,		/* 14,158 */
	0x9,		/* 14,159 */
	0x9,		/* 14,160 */
	0x9,		/* 14,161 */
	0x9,		/* 14,162 */
	0x9,		/* 14,163 */
	0x9,		/* 14,164 */
	0x9,		/* 14,165 */
	0x9,		/* 14,166 */
	0x9,		/* 14,167 */
	0x9,		/* 14,168 */
	0x9,		/* 14,169 */
	0x9,		/* 14,170 */
	0x9,		/* 14,171 */
	0x9,		/* 14,172 */
	0x9,		/* 14,173 */
	0x1,		/* 14,174 */
	0x1,		/* 14,175 */
	0x1,		/* 14,176 */
	0x9,		/* 14,177 */
	0x9,		/* 14,178 */
	0x9,		/* 14,179 */
	0x9,		/* 14,180 */
	0x9,		/* 14,181 */
	0x9,		/* 14,182 */
	0x9,		/* 14,183 */
	0x1,		/* 14,184 */
	0x9,		/* 14,185 */
	0x1,		/* 14,186 */
	0x1,		/* 14,187 */
	0x1,		/* 14,188 */
	0x1,		/* 14,189 */
	0x1,		/* 14,190 */
	0x1,		/* 14,191 */
	0x1,		/* 14,192 */
	0x1,		/* 14,193 */
	0x1,		/* 14,194 */
	0x1,		/* 14,195 */
	0x1,		/* 14,196 */
	0x1,		/* 14,197 */
	0x1,		/* 14,198 */
	0x1,		/* 14,199 */
	0x1,		/* 14,200 */
	0x1,		/* 14,201 */
	0x1,		/* 14,202 */
	0x1,		/* 14,203 */
	0x1,		/* 14,204 */
	0x1,		/* 14,205 */
	0x1,		/* 14,206 */
	0x1,		/* 14,207 */
	0x1,		/* 14,208 */
	0x1,		/* 14,209 */
	0x1,		/* 14,210 */
	0x1,		/* 14,211 */
	0x1,		/* 14,212 */
	0x1,		/* 14,213 */
	0x1,		/* 14,214 */
	0x1,		/* 14,215 */
	0x1,		/* 14,216 */
	0x1,		/* 14,217 */
	0x1,		/* 14,218 */
	0x1,		/* 14,219 */
	0x1,		/* 14,220 */
	0x1,		/* 14,221 */
	0x1,		/* 14,222 */
	0x1,		/* 14,223 */
	0x1,		/* 14,224 */
	0x1,		/* 14,225 */
	0x1,		/* 14,226 */
	0x1,		/* 14,227 */
	0x1,		/* 14,228 */
	0x1,		/* 14,229 */
	0x1,		/* 14,230 */
	0x1,		/* 14,231 */
	0x1,		/* 14,232 */
	0x1,		/* 14,233 */
	0x1,		/* 14,234 */
	0x1,		/* 14,235 */
	0x1,		/* 14,236 */
	0x1,		/* 14,237 */
	0x1,		/* 14,238 */
	0x1,		/* 14,239 */
	0x1,		/* 14,240 */
	0x1,		/* 14,241 */
	0x1,		/* 14,242 */
	0x1,		/* 14,243 */
	0x1,		/* 14,244 */
	0x1,		/* 14,245 */
	0x1,		/* 14,246 */
	0x1,		/* 14,247 */
	0x1,		/* 14,248 */
	0x1,		/* 14,249 */
	0x1,		/* 14,250 */
	0x1,		/* 14,251 */
	0x1,		/* 14,252 */
	0x1,		/* 14,253 */
	0x1,		/* 14,254 */
	0x1,		/* 14,255 */
	0x1,		/* 15,0 */
	0x1,		/* 15,1 */
	0x1,		/* 15,2 */
	0x1,		/* 15,3 */
	0x1,		/* 15,4 */
	0x1,		/* 15,5 */
	0x1,		/* 15,6 */
	0x1,		/* 15,7 */
	0x1,		/* 15,8 */
	0x1,		/* 15,9 */
	0x1,		/* 15,10 */
	0x1,		/* 15,11 */
	0x1,		/* 15,12 */
	0x1,		/* 15,13 */
	0x1,		/* 15,14 */
	0x1,		/* 15,15 */
	0x1,		/* 15,16 */
	0x1,		/* 15,17 */
	0x1,		/* 15,18 */
	0x1,		/* 15,19 */
	0x1,		/* 15,20 */
	0x1,		/* 15,21 */
	0x1,		/* 15,22 */
	0x1,		/* 15,23 */
	0x1,		/* 15,24 */
	0x1,		/* 15,25 */
	0x1,		/* 15,26 */
	0x1,		/* 15,27 */
	0x1,		/* 15,28 */
	0x1,		/* 15,29 */
	0x1,		/* 15,30 */
	0x1,		/* 15,31 */
	0x1,		/* 15,32 */
	0x1,		/* 15,33 */
	0x1,		/* 15,34 */
	0x1,		/* 15,35 */
	0x1,		/* 15,36 */
	0x1,		/* 15,37 */
	0x1,		/* 15,38 */
	0x1,		/* 15,39 */
	0x1,		/* 15,40 */
	0x1,		/* 15,41 */
	0x1,		/* 15,42 */
	0x1,		/* 15,43 */
	0x1,		/* 15,44 */
	0x1,		/* 15,45 */
	0x1,		/* 15,46 */
	0x1,		/* 15,47 */
	0x1,		/* 15,48 */
	0x1,		/* 15,49 */
	0x1,		/* 15,50 */
	0x1,		/* 15,51 */
	0x1,		/* 15,52 */
	0x1,		/* 15,53 */
	0x1,		/* 15,54 */
	0x1,		/* 15,55 */
	0x1,		/* 15,56 */
	0x1,		/* 15,57 */
	0x1,		/* 15,58 */
	0x1,		/* 15,59 */
	0x1,		/* 15,60 */
	0x1,		/* 15,61 */
	0x1,		/* 15,62 */
	0x1,		/* 15,63 */
	0x1,		/* 15,64 */
	0x1,		/* 15,65 */
	0x1,		/* 15,66 */
	0x1,		/* 15,67 */
	0x1,		/* 15,68 */
	0x1,		/* 15,69 */
	0x1,		/* 15,70 */
	0x1,		/* 15,71 */
	0x1,		/* 15,72 */
	0x1,		/* 15,73 */
	0x1,		/* 15,74 */
	0x1,		/* 15,75 */
	0x1,		/* 15,76 */
	0x1,		/* 15,77 */
	0x1,		/* 15,78 */
	0x1,		/* 15,79 */
	0x1,		/* 15,80 */
	0x1,		/* 15,81 */
	0x1,		/* 15,82 */
	0x1,		/* 15,83 */
	0x1,		/* 15,84 */
	0x1,		/* 15,85 */
	0x1,		/* 15,86 */
	0x1,		/* 15,87 */
	0x1,		/* 15,88 */
	0x1,		/* 15,89 */
	0x1,		/* 15,90 */
	0x1,		/* 15,91 */
	0x1,		/* 15,92 */
	0x1,		/* 15,93 */
	0x1,		/* 15,94 */
	0x1,		/* 15,95 */
	0x1,		/* 15,96 */
	0x1,		/* 15,97 */
	0x1,		/* 15,98 */
	0x1,		/* 15,99 */
	0x1,		/* 15,100 */
	0x1,		/* 15,101 */
	0x1,		/* 15,102 */
	0x1,		/* 15,103 */
	0x1,		/* 15,104 */
	0x1,		/* 15,105 */
	0x1,		/* 15,106 */
	0x1,		/* 15,107 */
	0x1,		/* 15,108 */
	0x1,		/* 15,109 */
	0x1,		/* 15,110 */
	0x1,		/* 15,111 */
	0x1,		/* 15,112 */
	0x1,		/* 15,113 */
	0x1,		/* 15,114 */
	0x1,		/* 15,115 */
	0x1,		/* 15,116 */
	0x1,		/* 15,117 */
	0x1,		/* 15,118 */
	0x1,		/* 15,119 */
	0x1,		/* 15,120 */
	0x1,		/* 15,121 */
	0x1,		/* 15,122 */
	0x1,		/* 15,123 */
	0x1,		/* 15,124 */
	0x1,		/* 15,125 */
	0x1,		/* 15,126 */
	0x1,		/* 15,127 */
	0x1,		/* 15,128 */
	0x1,		/* 15,129 */
	0x1,		/* 15,130 */
	0x1,		/* 15,131 */
	0x1,		/* 15,132 */
	0x1,		/* 15,133 */
	0x1,		/* 15,134 */
	0x1,		/* 15,135 */
	0x1,		/* 15,136 */
	0x1,		/* 15,137 */
	0x1,		/* 15,138 */
	0x1,		/* 15,139 */
	0x1,		/* 15,140 */
	0x1,		/* 15,141 */
	0x1,		/* 15,142 */
	0x1,		/* 15,143 */
	0x1,		/* 15,144 */
	0x1,		/* 15,145 */
	0x1,		/* 15,146 */
	0x1,		/* 15,147 */
	0x1,		/* 15,148 */
	0x1,		/* 15,149 */
	0x1,		/* 15,150 */
	0x1,		/* 15,151 */
	0x1,		/* 15,152 */
	0x1,		/* 15,153 */
	0x1,		/* 15,154 */
	0x1,		/* 15,155 */
	0x1,		/* 15,156 */
	0x1,		/* 15,157 */
	0x1,		/* 15,158 */
	0x1,		/* 15,159 */
	0xb,		/* 15,160 */
	0xb,		/* 15,161 */
	0xb,		/* 15,162 */
	0xb,		/* 15,163 */
	0xb,		/* 15,164 */
	0xb,		/* 15,165 */
	0xb,		/* 15,166 */
	0xb,		/* 15,167 */
	0xb,		/* 15,168 */
	0xb,		/* 15,169 */
	0xb,		/* 15,170 */
	0xb,		/* 15,171 */
	0xb,		/* 15,172 */
	0xb,		/* 15,173 */
	0xb,		/* 15,174 */
	0xb,		/* 15,175 */
	0xb,		/* 15,176 */
	0xb,		/* 15,177 */
	0xb,		/* 15,178 */
	0xb,		/* 15,179 */
	0xb,		/* 15,180 */
	0xb,		/* 15,181 */
	0xb,		/* 15,182 */
	0xb,		/* 15,183 */
	0xb,		/* 15,184 */
	0xb,		/* 15,185 */
	0xb,		/* 15,186 */
	0xb,		/* 15,187 */
	0xb,		/* 15,188 */
	0xb,		/* 15,189 */
	0xb,		/* 15,190 */
	0xb,		/* 15,191 */
	0xb,		/* 15,192 */
	0xb,		/* 15,193 */
	0xb,		/* 15,194 */
	0xb,		/* 15,195 */
	0xb,		/* 15,196 */
	0xb,		/* 15,197 */
	0x1,		/* 15,198 */
	0x1,		/* 15,199 */
	0x1,		/* 15,200 */
	0x1,		/* 15,201 */
	0x1,		/* 15,202 */
	0x1,		/* 15,203 */
	0x1,		/* 15,204 */
	0x1,		/* 15,205 */
	0x1,		/* 15,206 */
	0x1,		/* 15,207 */
	0xb,		/* 15,208 */
	0xb,		/* 15,209 */
	0xb,		/* 15,210 */
	0xb,		/* 15,211 */
	0xb,		/* 15,212 */
	0xb,		/* 15,213 */
	0xb,		/* 15,214 */
	0xb,		/* 15,215 */
	0xb,		/* 15,216 */
	0xb,		/* 15,217 */
	0xb,		/* 15,218 */
	0xb,		/* 15,219 */
	0xb,		/* 15,220 */
	0xb,		/* 15,221 */
	0xb,		/* 15,222 */
	0xb,		/* 15,223 */
	0xb,		/* 15,224 */
	0xb,		/* 15,225 */
	0xb,		/* 15,226 */
	0xb,		/* 15,227 */
	0xb,		/* 15,228 */
	0xb,		/* 15,229 */
	0xb,		/* 15,230 */
	0xb,		/* 15,231 */
	0xb,		/* 15,232 */
	0xb,		/* 15,233 */
	0xb,		/* 15,234 */
	0xb,		/* 15,235 */
	0xb,		/* 15,236 */
	0xb,		/* 15,237 */
	0xb,		/* 15,238 */
	0xb,		/* 15,239 */
	0xb,		/* 15,240 */
	0xb,		/* 15,241 */
	0xb,		/* 15,242 */
	0xb,		/* 15,243 */
	0xb,		/* 15,244 */
	0xb,		/* 15,245 */
	0xb,		/* 15,246 */
	0x1,		/* 15,247 */
	0x1,		/* 15,248 */
	0x1,		/* 15,249 */
	0x1,		/* 15,250 */
	0x1,		/* 15,251 */
	0x1,		/* 15,252 */
	0x1,		/* 15,253 */
	0x1,		/* 15,254 */
	0x1,		/* 15,255 */
	0xb,		/* 16,0 */
	0x1,		/* 16,1 */
	0xb,		/* 16,2 */
	0xb,		/* 16,3 */
	0x1,		/* 16,4 */
	0xb,		/* 16,5 */
	0xb,		/* 16,6 */
	0xb,		/* 16,7 */
	0x1,		/* 16,8 */
	0xb,		/* 16,9 */
	0x1,		/* 16,10 */
	0xb,		/* 16,11 */
	0xb,		/* 16,12 */
	0x1,		/* 16,13 */
	0xb,		/* 16,14 */
	0xb,		/* 16,15 */
	0xb,		/* 16,16 */
	0xb,		/* 16,17 */
	0xb,		/* 16,18 */
	0x1,		/* 16,19 */
	0x1,		/* 16,20 */
	0x1,		/* 16,21 */
	0x1,		/* 16,22 */
	0x1,		/* 16,23 */
	0x1,		/* 16,24 */
	0x1,		/* 16,25 */
	0x1,		/* 16,26 */
	0x1,		/* 16,27 */
	0x1,		/* 16,28 */
	0x1,		/* 16,29 */
	0x1,		/* 16,30 */
	0x1,		/* 16,31 */
	0x1,		/* 16,32 */
	0x1,		/* 16,33 */
	0x1,		/* 16,34 */
	0x1,		/* 16,35 */
	0x1,		/* 16,36 */
	0x1,		/* 16,37 */
	0x1,		/* 16,38 */
	0x1,		/* 16,39 */
	0x1,		/* 16,40 */
	0x1,		/* 16,41 */
	0x1,		/* 16,42 */
	0x1,		/* 16,43 */
	0x1,		/* 16,44 */
	0x1,		/* 16,45 */
	0x1,		/* 16,46 */
	0x1,		/* 16,47 */
	0x1,		/* 16,48 */
	0x1,		/* 16,49 */
	0x1,		/* 16,50 */
	0x1,		/* 16,51 */
	0x1,		/* 16,52 */
	0x1,		/* 16,53 */
	0x1,		/* 16,54 */
	0x1,		/* 16,55 */
	0x1,		/* 16,56 */
	0x1,		/* 16,57 */
	0x1,		/* 16,58 */
	0x1,		/* 16,59 */
	0xb,		/* 16,60 */
	0x1,		/* 16,61 */
	0xb,		/* 16,62 */
	0x1,		/* 16,63 */
	0xb,		/* 16,64 */
	0x1,		/* 16,65 */
	0x1,		/* 16,66 */
	0x1,		/* 16,67 */
	0x1,		/* 16,68 */
	0x1,		/* 16,69 */
	0x1,		/* 16,70 */
	0x1,		/* 16,71 */
	0x1,		/* 16,72 */
	0x1,		/* 16,73 */
	0x1,		/* 16,74 */
	0x1,		/* 16,75 */
	0xb,		/* 16,76 */
	0x1,		/* 16,77 */
	0xb,		/* 16,78 */
	0x1,		/* 16,79 */
	0xb,		/* 16,80 */
	0x1,		/* 16,81 */
	0x1,		/* 16,82 */
	0x1,		/* 16,83 */
	0xb,		/* 16,84 */
	0xb,		/* 16,85 */
	0x1,		/* 16,86 */
	0x1,		/* 16,87 */
	0x1,		/* 16,88 */
	0xb,		/* 16,89 */
	0x1,		/* 16,90 */
	0x1,		/* 16,91 */
	0x1,		/* 16,92 */
	0x1,		/* 16,93 */
	0x1,		/* 16,94 */
	0xb,		/* 16,95 */
	0xb,		/* 16,96 */
	0xb,		/* 16,97 */
	0x1,		/* 16,98 */
	0xb,		/* 16,99 */
	0x1,		/* 16,100 */
	0xb,		/* 16,101 */
	0x1,		/* 16,102 */
	0xb,		/* 16,103 */
	0x1,		/* 16,104 */
	0xb,		/* 16,105 */
	0x1,		/* 16,106 */
	0x1,		/* 16,107 */
	0x1,		/* 16,108 */
	0xb,		/* 16,109 */
	0xb,		/* 16,110 */
	0x1,		/* 16,111 */
	0x1,		/* 16,112 */
	0x1,		/* 16,113 */
	0xb,		/* 16,114 */
	0xb,		/* 16,115 */
	0x1,		/* 16,116 */
	0xb,		/* 16,117 */
	0x1,		/* 16,118 */
	0x1,		/* 16,119 */
	0x1,		/* 16,120 */
	0x1,		/* 16,121 */
	0x1,		/* 16,122 */
	0x1,		/* 16,123 */
	0x1,		/* 16,124 */
	0x1,		/* 16,125 */
	0x1,		/* 16,126 */
	0x1,		/* 16,127 */
	0x1,		/* 16,128 */
	0x1,		/* 16,129 */
	0x1,		/* 16,130 */
	0x1,		/* 16,131 */
	0x1,		/* 16,132 */
	0x1,		/* 16,133 */
	0x1,		/* 16,134 */
	0x1,		/* 16,135 */
	0x1,		/* 16,136 */
	0x1,		/* 16,137 */
	0x1,		/* 16,138 */
	0x1,		/* 16,139 */
	0x1,		/* 16,140 */
	0x1,		/* 16,141 */
	0x1,		/* 16,142 */
	0x1,		/* 16,143 */
	0x1,		/* 16,144 */
	0x1,		/* 16,145 */
	0x1,		/* 16,146 */
	0x1,		/* 16,147 */
	0x1,		/* 16,148 */
	0x1,		/* 16,149 */
	0x1,		/* 16,150 */
	0x1,		/* 16,151 */
	0x1,		/* 16,152 */
	0x1,		/* 16,153 */
	0x1,		/* 16,154 */
	0x1,		/* 16,155 */
	0x1,		/* 16,156 */
	0x1,		/* 16,157 */
	0xb,		/* 16,158 */
	0x1,		/* 16,159 */
	0x1,		/* 16,160 */
	0x1,		/* 16,161 */
	0x1,		/* 16,162 */
	0x1,		/* 16,163 */
	0x1,		/* 16,164 */
	0x1,		/* 16,165 */
	0x1,		/* 16,166 */
	0x1,		/* 16,167 */
	0xb,		/* 16,168 */
	0x1,		/* 16,169 */
	0x1,		/* 16,170 */
	0xb,		/* 16,171 */
	0x1,		/* 16,172 */
	0x1,		/* 16,173 */
	0xb,		/* 16,174 */
	0xb,		/* 16,175 */
	0x1,		/* 16,176 */
	0x1,		/* 16,177 */
	0x1,		/* 16,178 */
	0x1,		/* 16,179 */
	0x1,		/* 16,180 */
	0x1,		/* 16,181 */
	0x1,		/* 16,182 */
	0xb,		/* 16,183 */
	0xb,		/* 16,184 */
	0x1,		/* 16,185 */
	0xb,		/* 16,186 */
	0x1,		/* 16,187 */
	0xb,		/* 16,188 */
	0xb,		/* 16,189 */
	0xb,		/* 16,190 */
	0xb,		/* 16,191 */
	0xb,		/* 16,192 */
	0xb,		/* 16,193 */
	0xb,		/* 16,194 */
	0x1,		/* 16,195 */
	0x1,		/* 16,196 */
	0x1,		/* 16,197 */
	0x1,		/* 16,198 */
	0x1,		/* 16,199 */
	0x1,		/* 16,200 */
	0x1,		/* 16,201 */
	0x1,		/* 16,202 */
	0x1,		/* 16,203 */
	0x1,		/* 16,204 */
	0x1,		/* 16,205 */
	0x1,		/* 16,206 */
	0x1,		/* 16,207 */
	0x1,		/* 16,208 */
	0x1,		/* 16,209 */
	0x1,		/* 16,210 */
	0x1,		/* 16,211 */
	0x1,		/* 16,212 */
	0x1,		/* 16,213 */
	0x1,		/* 16,214 */
	0x1,		/* 16,215 */
	0x1,		/* 16,216 */
	0x1,		/* 16,217 */
	0x1,		/* 16,218 */
	0x1,		/* 16,219 */
	0x1,		/* 16,220 */
	0x1,		/* 16,221 */
	0x1,		/* 16,222 */
	0x1,		/* 16,223 */
	0x1,		/* 16,224 */
	0x1,		/* 16,225 */
	0x1,		/* 16,226 */
	0x1,		/* 16,227 */
	0x1,		/* 16,228 */
	0x1,		/* 16,229 */
	0x1,		/* 16,230 */
	0x1,		/* 16,231 */
	0x1,		/* 16,232 */
	0x1,		/* 16,233 */
	0x1,		/* 16,234 */
	0xb,		/* 16,235 */
	0x1,		/* 16,236 */
	0x1,		/* 16,237 */
	0x1,		/* 16,238 */
	0x1,		/* 16,239 */
	0xb,		/* 16,240 */
	0x1,		/* 16,241 */
	0x1,		/* 16,242 */
	0x1,		/* 16,243 */
	0x1,		/* 16,244 */
	0x1,		/* 16,245 */
	0x1,		/* 16,246 */
	0x1,		/* 16,247 */
	0x1,		/* 16,248 */
	0xb,		/* 16,249 */
	0x1,		/* 16,250 */
	0x1,		/* 16,251 */
	0x1,		/* 16,252 */
	0x1,		/* 16,253 */
	0x1,		/* 16,254 */
	0x1,		/* 16,255 */
	0xb,		/* 17,0 */
	0xb,		/* 17,1 */
	0xb,		/* 17,2 */
	0xb,		/* 17,3 */
	0xb,		/* 17,4 */
	0xb,		/* 17,5 */
	0xb,		/* 17,6 */
	0xb,		/* 17,7 */
	0xb,		/* 17,8 */
	0xb,		/* 17,9 */
	0xb,		/* 17,10 */
	0xb,		/* 17,11 */
	0xb,		/* 17,12 */
	0xb,		/* 17,13 */
	0xb,		/* 17,14 */
	0xb,		/* 17,15 */
	0xb,		/* 17,16 */
	0xb,		/* 17,17 */
	0xb,		/* 17,18 */
	0xb,		/* 17,19 */
	0xb,		/* 17,20 */
	0xb,		/* 17,21 */
	0xb,		/* 17,22 */
	0xb,		/* 17,23 */
	0xb,		/* 17,24 */
	0xb,		/* 17,25 */
	0xb,		/* 17,26 */
	0xb,		/* 17,27 */
	0xb,		/* 17,28 */
	0xb,		/* 17,29 */
	0xb,		/* 17,30 */
	0xb,		/* 17,31 */
	0xb,		/* 17,32 */
	0xb,		/* 17,33 */
	0xb,		/* 17,34 */
	0xb,		/* 17,35 */
	0xb,		/* 17,36 */
	0xb,		/* 17,37 */
	0xb,		/* 17,38 */
	0xb,		/* 17,39 */
	0xb,		/* 17,40 */
	0xb,		/* 17,41 */
	0xb,		/* 17,42 */
	0xb,		/* 17,43 */
	0xb,		/* 17,44 */
	0xb,		/* 17,45 */
	0xb,		/* 17,46 */
	0xb,		/* 17,47 */
	0xb,		/* 17,48 */
	0xb,		/* 17,49 */
	0xb,		/* 17,50 */
	0xb,		/* 17,51 */
	0xb,		/* 17,52 */
	0xb,		/* 17,53 */
	0xb,		/* 17,54 */
	0xb,		/* 17,55 */
	0xb,		/* 17,56 */
	0xb,		/* 17,57 */
	0xb,		/* 17,58 */
	0xb,		/* 17,59 */
	0xb,		/* 17,60 */
	0xb,		/* 17,61 */
	0xb,		/* 17,62 */
	0xb,		/* 17,63 */
	0xb,		/* 17,64 */
	0xb,		/* 17,65 */
	0xb,		/* 17,66 */
	0xb,		/* 17,67 */
	0xb,		/* 17,68 */
	0xb,		/* 17,69 */
	0xb,		/* 17,70 */
	0xb,		/* 17,71 */
	0xb,		/* 17,72 */
	0xb,		/* 17,73 */
	0xb,		/* 17,74 */
	0xb,		/* 17,75 */
	0xb,		/* 17,76 */
	0xb,		/* 17,77 */
	0xb,		/* 17,78 */
	0xb,		/* 17,79 */
	0xb,		/* 17,80 */
	0xb,		/* 17,81 */
	0xb,		/* 17,82 */
	0xb,		/* 17,83 */
	0xb,		/* 17,84 */
	0xb,		/* 17,85 */
	0xb,		/* 17,86 */
	0xb,		/* 17,87 */
	0xb,		/* 17,88 */
	0xb,		/* 17,89 */
	0xb,		/* 17,90 */
	0xb,		/* 17,91 */
	0xb,		/* 17,92 */
	0xb,		/* 17,93 */
	0xb,		/* 17,94 */
	0xb,		/* 17,95 */
	0xb,		/* 17,96 */
	0xb,		/* 17,97 */
	0xb,		/* 17,98 */
	0xb,		/* 17,99 */
	0xb,		/* 17,100 */
	0xb,		/* 17,101 */
	0xb,		/* 17,102 */
	0xb,		/* 17,103 */
	0xb,		/* 17,104 */
	0xb,		/* 17,105 */
	0xb,		/* 17,106 */
	0xb,		/* 17,107 */
	0xb,		/* 17,108 */
	0xb,		/* 17,109 */
	0xb,		/* 17,110 */
	0xb,		/* 17,111 */
	0xb,		/* 17,112 */
	0xb,		/* 17,113 */
	0xb,		/* 17,114 */
	0xb,		/* 17,115 */
	0xb,		/* 17,116 */
	0xb,		/* 17,117 */
	0xb,		/* 17,118 */
	0xb,		/* 17,119 */
	0xb,		/* 17,120 */
	0xb,		/* 17,121 */
	0xb,		/* 17,122 */
	0xb,		/* 17,123 */
	0xb,		/* 17,124 */
	0xb,		/* 17,125 */
	0xb,		/* 17,126 */
	0xb,		/* 17,127 */
	0xb,		/* 17,128 */
	0xb,		/* 17,129 */
	0xb,		/* 17,130 */
	0xb,		/* 17,131 */
	0xb,		/* 17,132 */
	0xb,		/* 17,133 */
	0xb,		/* 17,134 */
	0xb,		/* 17,135 */
	0xb,		/* 17,136 */
	0xb,		/* 17,137 */
	0xb,		/* 17,138 */
	0xb,		/* 17,139 */
	0xb,		/* 17,140 */
	0xb,		/* 17,141 */
	0xb,		/* 17,142 */
	0xb,		/* 17,143 */
	0xb,		/* 17,144 */
	0xb,		/* 17,145 */
	0xb,		/* 17,146 */
	0xb,		/* 17,147 */
	0xb,		/* 17,148 */
	0xb,		/* 17,149 */
	0xb,		/* 17,150 */
	0xb,		/* 17,151 */
	0xb,		/* 17,152 */
	0xb,		/* 17,153 */
	0xb,		/* 17,154 */
	0xb,		/* 17,155 */
	0x1,		/* 17,156 */
	0x1,		/* 17,157 */
	0x1,		/* 17,158 */
	0x1,		/* 17,159 */
	0xb,		/* 17,160 */
	0xb,		/* 17,161 */
	0xb,		/* 17,162 */
	0xb,		/* 17,163 */
	0xb,		/* 17,164 */
	0xb,		/* 17,165 */
	0xb,		/* 17,166 */
	0xb,		/* 17,167 */
	0xb,		/* 17,168 */
	0xb,		/* 17,169 */
	0xb,		/* 17,170 */
	0xb,		/* 17,171 */
	0xb,		/* 17,172 */
	0xb,		/* 17,173 */
	0xb,		/* 17,174 */
	0xb,		/* 17,175 */
	0xb,		/* 17,176 */
	0xb,		/* 17,177 */
	0xb,		/* 17,178 */
	0xb,		/* 17,179 */
	0xb,		/* 17,180 */
	0xb,		/* 17,181 */
	0xb,		/* 17,182 */
	0xb,		/* 17,183 */
	0xb,		/* 17,184 */
	0xb,		/* 17,185 */
	0xb,		/* 17,186 */
	0xb,		/* 17,187 */
	0xb,		/* 17,188 */
	0xb,		/* 17,189 */
	0xb,		/* 17,190 */
	0xb,		/* 17,191 */
	0xb,		/* 17,192 */
	0xb,		/* 17,193 */
	0xb,		/* 17,194 */
	0xb,		/* 17,195 */
	0xb,		/* 17,196 */
	0xb,		/* 17,197 */
	0xb,		/* 17,198 */
	0xb,		/* 17,199 */
	0xb,		/* 17,200 */
	0xb,		/* 17,201 */
	0xb,		/* 17,202 */
	0xb,		/* 17,203 */
	0xb,		/* 17,204 */
	0xb,		/* 17,205 */
	0xb,		/* 17,206 */
	0xb,		/* 17,207 */
	0xb,		/* 17,208 */
	0xb,		/* 17,209 */
	0xb,		/* 17,210 */
	0xb,		/* 17,211 */
	0xb,		/* 17,212 */
	0xb,		/* 17,213 */
	0xb,		/* 17,214 */
	0xb,		/* 17,215 */
	0xb,		/* 17,216 */
	0xb,		/* 17,217 */
	0xb,		/* 17,218 */
	0xb,		/* 17,219 */
	0xb,		/* 17,220 */
	0xb,		/* 17,221 */
	0xb,		/* 17,222 */
	0xb,		/* 17,223 */
	0xb,		/* 17,224 */
	0xb,		/* 17,225 */
	0xb,		/* 17,226 */
	0xb,		/* 17,227 */
	0xb,		/* 17,228 */
	0xb,		/* 17,229 */
	0xb,		/* 17,230 */
	0xb,		/* 17,231 */
	0xb,		/* 17,232 */
	0xb,		/* 17,233 */
	0xb,		/* 17,234 */
	0xb,		/* 17,235 */
	0xb,		/* 17,236 */
	0xb,		/* 17,237 */
	0xb,		/* 17,238 */
	0xb,		/* 17,239 */
	0xb,		/* 17,240 */
	0xb,		/* 17,241 */
	0xb,		/* 17,242 */
	0xb,		/* 17,243 */
	0xb,		/* 17,244 */
	0xb,		/* 17,245 */
	0xb,		/* 17,246 */
	0xb,		/* 17,247 */
	0xb,		/* 17,248 */
	0xb,		/* 17,249 */
	0x1,		/* 17,250 */
	0x1,		/* 17,251 */
	0x1,		/* 17,252 */
	0x1,		/* 17,253 */
	0x1,		/* 17,254 */
	0x1,		/* 17,255 */
	0xb,		/* 18,0 */
	0xb,		/* 18,1 */
	0xb,		/* 18,2 */
	0xb,		/* 18,3 */
	0xb,		/* 18,4 */
	0xb,		/* 18,5 */
	0xb,		/* 18,6 */
	0xb,		/* 18,7 */
	0xb,		/* 18,8 */
	0xb,		/* 18,9 */
	0xb,		/* 18,10 */
	0xb,		/* 18,11 */
	0xb,		/* 18,12 */
	0xb,		/* 18,13 */
	0xb,		/* 18,14 */
	0xb,		/* 18,15 */
	0xb,		/* 18,16 */
	0xb,		/* 18,17 */
	0xb,		/* 18,18 */
	0xb,		/* 18,19 */
	0xb,		/* 18,20 */
	0xb,		/* 18,21 */
	0x1,		/* 18,22 */
	0x1,		/* 18,23 */
	0xb,		/* 18,24 */
	0xb,		/* 18,25 */
	0xb,		/* 18,26 */
	0xb,		/* 18,27 */
	0xb,		/* 18,28 */
	0xb,		/* 18,29 */
	0x1,		/* 18,30 */
	0x1,		/* 18,31 */
	0xb,		/* 18,32 */
	0xb,		/* 18,33 */
	0xb,		/* 18,34 */
	0xb,		/* 18,35 */
	0xb,		/* 18,36 */
	0xb,		/* 18,37 */
	0xb,		/* 18,38 */
	0xb,		/* 18,39 */
	0xb,		/* 18,40 */
	0xb,		/* 18,41 */
	0xb,		/* 18,42 */
	0xb,		/* 18,43 */
	0xb,		/* 18,44 */
	0xb,		/* 18,45 */
	0xb,		/* 18,46 */
	0xb,		/* 18,47 */
	0xb,		/* 18,48 */
	0xb,		/* 18,49 */
	0xb,		/* 18,50 */
	0xb,		/* 18,51 */
	0xb,		/* 18,52 */
	0xb,		/* 18,53 */
	0xb,		/* 18,54 */
	0xb,		/* 18,55 */
	0xb,		/* 18,56 */
	0xb,		/* 18,57 */
	0xb,		/* 18,58 */
	0xb,		/* 18,59 */
	0xb,		/* 18,60 */
	0xb,		/* 18,61 */
	0xb,		/* 18,62 */
	0xb,		/* 18,63 */
	0xb,		/* 18,64 */
	0xb,		/* 18,65 */
	0xb,		/* 18,66 */
	0xb,		/* 18,67 */
	0xb,		/* 18,68 */
	0xb,		/* 18,69 */
	0x1,		/* 18,70 */
	0x1,		/* 18,71 */
	0xb,		/* 18,72 */
	0xb,		/* 18,73 */
	0xb,		/* 18,74 */
	0xb,		/* 18,75 */
	0xb,		/* 18,76 */
	0xb,		/* 18,77 */
	0x1,		/* 18,78 */
	0x1,		/* 18,79 */
	0xb,		/* 18,80 */
	0xb,		/* 18,81 */
	0xb,		/* 18,82 */
	0xb,		/* 18,83 */
	0xb,		/* 18,84 */
	0xb,		/* 18,85 */
	0xb,		/* 18,86 */
	0xb,		/* 18,87 */
	0x1,		/* 18,88 */
	0xb,		/* 18,89 */
	0x1,		/* 18,90 */
	0xb,		/* 18,91 */
	0x1,		/* 18,92 */
	0xb,		/* 18,93 */
	0x1,		/* 18,94 */
	0xb,		/* 18,95 */
	0xb,		/* 18,96 */
	0xb,		/* 18,97 */
	0xb,		/* 18,98 */
	0xb,		/* 18,99 */
	0xb,		/* 18,100 */
	0xb,		/* 18,101 */
	0xb,		/* 18,102 */
	0xb,		/* 18,103 */
	0xb,		/* 18,104 */
	0xb,		/* 18,105 */
	0xb,		/* 18,106 */
	0xb,		/* 18,107 */
	0xb,		/* 18,108 */
	0xb,		/* 18,109 */
	0xb,		/* 18,110 */
	0xb,		/* 18,111 */
	0xb,		/* 18,112 */
	0xb,		/* 18,113 */
	0xb,		/* 18,114 */
	0xb,		/* 18,115 */
	0xb,		/* 18,116 */
	0xb,		/* 18,117 */
	0xb,		/* 18,118 */
	0xb,		/* 18,119 */
	0xb,		/* 18,120 */
	0xb,		/* 18,121 */
	0xb,		/* 18,122 */
	0xb,		/* 18,123 */
	0xb,		/* 18,124 */
	0xb,		/* 18,125 */
	0x1,		/* 18,126 */
	0x1,		/* 18,127 */
	0xb,		/* 18,128 */
	0xb,		/* 18,129 */
	0xb,		/* 18,130 */
	0xb,		/* 18,131 */
	0xb,		/* 18,132 */
	0xb,		/* 18,133 */
	0xb,		/* 18,134 */
	0xb,		/* 18,135 */
	0xb,		/* 18,136 */
	0xb,		/* 18,137 */
	0xb,		/* 18,138 */
	0xb,		/* 18,139 */
	0xb,		/* 18,140 */
	0xb,		/* 18,141 */
	0xb,		/* 18,142 */
	0xb,		/* 18,143 */
	0xb,		/* 18,144 */
	0xb,		/* 18,145 */
	0xb,		/* 18,146 */
	0xb,		/* 18,147 */
	0xb,		/* 18,148 */
	0xb,		/* 18,149 */
	0xb,		/* 18,150 */
	0xb,		/* 18,151 */
	0xb,		/* 18,152 */
	0xb,		/* 18,153 */
	0xb,		/* 18,154 */
	0xb,		/* 18,155 */
	0xb,		/* 18,156 */
	0xb,		/* 18,157 */
	0xb,		/* 18,158 */
	0xb,		/* 18,159 */
	0xb,		/* 18,160 */
	0xb,		/* 18,161 */
	0xb,		/* 18,162 */
	0xb,		/* 18,163 */
	0xb,		/* 18,164 */
	0xb,		/* 18,165 */
	0xb,		/* 18,166 */
	0xb,		/* 18,167 */
	0xb,		/* 18,168 */
	0xb,		/* 18,169 */
	0xb,		/* 18,170 */
	0xb,		/* 18,171 */
	0xb,		/* 18,172 */
	0xb,		/* 18,173 */
	0xb,		/* 18,174 */
	0xb,		/* 18,175 */
	0xb,		/* 18,176 */
	0xb,		/* 18,177 */
	0xb,		/* 18,178 */
	0xb,		/* 18,179 */
	0xb,		/* 18,180 */
	0x1,		/* 18,181 */
	0xb,		/* 18,182 */
	0xb,		/* 18,183 */
	0xb,		/* 18,184 */
	0xb,		/* 18,185 */
	0xb,		/* 18,186 */
	0xb,		/* 18,187 */
	0xb,		/* 18,188 */
	0x1,		/* 18,189 */
	0xb,		/* 18,190 */
	0x1,		/* 18,191 */
	0x1,		/* 18,192 */
	0x1,		/* 18,193 */
	0xb,		/* 18,194 */
	0xb,		/* 18,195 */
	0xb,		/* 18,196 */
	0x1,		/* 18,197 */
	0xb,		/* 18,198 */
	0xb,		/* 18,199 */
	0xb,		/* 18,200 */
	0xb,		/* 18,201 */
	0xb,		/* 18,202 */
	0xb,		/* 18,203 */
	0xb,		/* 18,204 */
	0x1,		/* 18,205 */
	0x1,		/* 18,206 */
	0x1,		/* 18,207 */
	0xb,		/* 18,208 */
	0xb,		/* 18,209 */
	0xb,		/* 18,210 */
	0xb,		/* 18,211 */
	0x1,		/* 18,212 */
	0x1,		/* 18,213 */
	0xb,		/* 18,214 */
	0xb,		/* 18,215 */
	0xb,		/* 18,216 */
	0xb,		/* 18,217 */
	0xb,		/* 18,218 */
	0xb,		/* 18,219 */
	0x1,		/* 18,220 */
	0x1,		/* 18,221 */
	0x1,		/* 18,222 */
	0x1,		/* 18,223 */
	0xb,		/* 18,224 */
	0xb,		/* 18,225 */
	0xb,		/* 18,226 */
	0xb,		/* 18,227 */
	0xb,		/* 18,228 */
	0xb,		/* 18,229 */
	0xb,		/* 18,230 */
	0xb,		/* 18,231 */
	0xb,		/* 18,232 */
	0xb,		/* 18,233 */
	0xb,		/* 18,234 */
	0xb,		/* 18,235 */
	0xb,		/* 18,236 */
	0x1,		/* 18,237 */
	0x1,		/* 18,238 */
	0x1,		/* 18,239 */
	0x1,		/* 18,240 */
	0x1,		/* 18,241 */
	0xb,		/* 18,242 */
	0xb,		/* 18,243 */
	0xb,		/* 18,244 */
	0x1,		/* 18,245 */
	0xb,		/* 18,246 */
	0xb,		/* 18,247 */
	0xb,		/* 18,248 */
	0xb,		/* 18,249 */
	0xb,		/* 18,250 */
	0xb,		/* 18,251 */
	0xb,		/* 18,252 */
	0x1,		/* 18,253 */
	0x1,		/* 18,254 */
	0x1,		/* 18,255 */
	0x1,		/* 19,0 */
	0x1,		/* 19,1 */
	0x1,		/* 19,2 */
	0x1,		/* 19,3 */
	0x1,		/* 19,4 */
	0x1,		/* 19,5 */
	0x1,		/* 19,6 */
	0x1,		/* 19,7 */
	0x1,		/* 19,8 */
	0x1,		/* 19,9 */
	0x1,		/* 19,10 */
	0x1,		/* 19,11 */
	0x9,		/* 19,12 */
	0x9,		/* 19,13 */
	0x9,		/* 19,14 */
	0x9,		/* 19,15 */
	0x1,		/* 19,16 */
	0x1,		/* 19,17 */
	0x1,		/* 19,18 */
	0x1,		/* 19,19 */
	0x1,		/* 19,20 */
	0x1,		/* 19,21 */
	0x1,		/* 19,22 */
	0x1,		/* 19,23 */
	0x1,		/* 19,24 */
	0x1,		/* 19,25 */
	0x1,		/* 19,26 */
	0x1,		/* 19,27 */
	0x1,		/* 19,28 */
	0x1,		/* 19,29 */
	0x1,		/* 19,30 */
	0x1,		/* 19,31 */
	0x1,		/* 19,32 */
	0x1,		/* 19,33 */
	0x1,		/* 19,34 */
	0x1,		/* 19,35 */
	0x1,		/* 19,36 */
	0x1,		/* 19,37 */
	0x1,		/* 19,38 */
	0x1,		/* 19,39 */
	0x1,		/* 19,40 */
	0x1,		/* 19,41 */
	0x9,		/* 19,42 */
	0x9,		/* 19,43 */
	0x9,		/* 19,44 */
	0x9,		/* 19,45 */
	0x9,		/* 19,46 */
	0x1,		/* 19,47 */
	0x1,		/* 19,48 */
	0x1,		/* 19,49 */
	0x1,		/* 19,50 */
	0x1,		/* 19,51 */
	0x1,		/* 19,52 */
	0x1,		/* 19,53 */
	0x1,		/* 19,54 */
	0x1,		/* 19,55 */
	0x1,		/* 19,56 */
	0x1,		/* 19,57 */
	0x1,		/* 19,58 */
	0x1,		/* 19,59 */
	0x1,		/* 19,60 */
	0x1,		/* 19,61 */
	0x1,		/* 19,62 */
	0x1,		/* 19,63 */
	0x1,		/* 19,64 */
	0x1,		/* 19,65 */
	0x1,		/* 19,66 */
	0x1,		/* 19,67 */
	0x1,		/* 19,68 */
	0x1,		/* 19,69 */
	0x1,		/* 19,70 */
	0x1,		/* 19,71 */
	0x1,		/* 19,72 */
	0x1,		/* 19,73 */
	0x1,		/* 19,74 */
	0x1,		/* 19,75 */
	0x1,		/* 19,76 */
	0x1,		/* 19,77 */
	0x1,		/* 19,78 */
	0x1,		/* 19,79 */
	0x1,		/* 19,80 */
	0x1,		/* 19,81 */
	0x1,		/* 19,82 */
	0x1,		/* 19,83 */
	0x1,		/* 19,84 */
	0x1,		/* 19,85 */
	0x1,		/* 19,86 */
	0x1,		/* 19,87 */
	0x1,		/* 19,88 */
	0x1,		/* 19,89 */
	0x1,		/* 19,90 */
	0x1,		/* 19,91 */
	0x1,		/* 19,92 */
	0x1,		/* 19,93 */
	0x1,		/* 19,94 */
	0x1,		/* 19,95 */
	0x1,		/* 19,96 */
	0x1,		/* 19,97 */
	0x1,		/* 19,98 */
	0x1,		/* 19,99 */
	0x1,		/* 19,100 */
	0x1,		/* 19,101 */
	0x1,		/* 19,102 */
	0x1,		/* 19,103 */
	0x1,		/* 19,104 */
	0x1,		/* 19,105 */
	0x9,		/* 19,106 */
	0x9,		/* 19,107 */
	0x9,		/* 19,108 */
	0x9,		/* 19,109 */
	0x9,		/* 19,110 */
	0x9,		/* 19,111 */
	0x1,		/* 19,112 */
	0x1,		/* 19,113 */
	0x1,		/* 19,114 */
	0x1,		/* 19,115 */
	0x1,		/* 19,116 */
	0x1,		/* 19,117 */
	0x1,		/* 19,118 */
	0x1,		/* 19,119 */
	0x1,		/* 19,120 */
	0x1,		/* 19,121 */
	0x1,		/* 19,122 */
	0x1,		/* 19,123 */
	0x1,		/* 19,124 */
	0x1,		/* 19,125 */
	0x1,		/* 19,126 */
	0x1,		/* 19,127 */
	0x1,		/* 19,128 */
	0x1,		/* 19,129 */
	0x1,		/* 19,130 */
	0x1,		/* 19,131 */
	0x1,		/* 19,132 */
	0x1,		/* 19,133 */
	0x1,		/* 19,134 */
	0x1,		/* 19,135 */
	0x1,		/* 19,136 */
	0x1,		/* 19,137 */
	0x1,		/* 19,138 */
	0x1,		/* 19,139 */
	0x1,		/* 19,140 */
	0x1,		/* 19,141 */
	0x1,		/* 19,142 */
	0x1,		/* 19,143 */
	0x1,		/* 19,144 */
	0x1,		/* 19,145 */
	0x1,		/* 19,146 */
	0x1,		/* 19,147 */
	0x1,		/* 19,148 */
	0x1,		/* 19,149 */
	0x1,		/* 19,150 */
	0x1,		/* 19,151 */
	0x1,		/* 19,152 */
	0x1,		/* 19,153 */
	0x1,		/* 19,154 */
	0x1,		/* 19,155 */
	0x1,		/* 19,156 */
	0x1,		/* 19,157 */
	0x1,		/* 19,158 */
	0x1,		/* 19,159 */
	0x1,		/* 19,160 */
	0x1,		/* 19,161 */
	0x1,		/* 19,162 */
	0x1,		/* 19,163 */
	0x1,		/* 19,164 */
	0x1,		/* 19,165 */
	0x1,		/* 19,166 */
	0x1,		/* 19,167 */
	0x1,		/* 19,168 */
	0x1,		/* 19,169 */
	0x1,		/* 19,170 */
	0x1,		/* 19,171 */
	0x1,		/* 19,172 */
	0x1,		/* 19,173 */
	0x1,		/* 19,174 */
	0x1,		/* 19,175 */
	0x1,		/* 19,176 */
	0x1,		/* 19,177 */
	0x1,		/* 19,178 */
	0x1,		/* 19,179 */
	0x1,		/* 19,180 */
	0x1,		/* 19,181 */
	0x1,		/* 19,182 */
	0x1,		/* 19,183 */
	0x1,		/* 19,184 */
	0x1,		/* 19,185 */
	0x1,		/* 19,186 */
	0x1,		/* 19,187 */
	0x1,		/* 19,188 */
	0x1,		/* 19,189 */
	0x1,		/* 19,190 */
	0x1,		/* 19,191 */
	0x1,		/* 19,192 */
	0x1,		/* 19,193 */
	0x1,		/* 19,194 */
	0x1,		/* 19,195 */
	0x1,		/* 19,196 */
	0x1,		/* 19,197 */
	0x1,		/* 19,198 */
	0x1,		/* 19,199 */
	0x1,		/* 19,200 */
	0x1,		/* 19,201 */
	0x1,		/* 19,202 */
	0x1,		/* 19,203 */
	0x1,		/* 19,204 */
	0x1,		/* 19,205 */
	0x1,		/* 19,206 */
	0x1,		/* 19,207 */
	0x9,		/* 19,208 */
	0x9,		/* 19,209 */
	0x9,		/* 19,210 */
	0x9,		/* 19,211 */
	0x9,		/* 19,212 */
	0x9,		/* 19,213 */
	0x9,		/* 19,214 */
	0x9,		/* 19,215 */
	0x9,		/* 19,216 */
	0x9,		/* 19,217 */
	0x9,		/* 19,218 */
	0x9,		/* 19,219 */
	0x9,		/* 19,220 */
	0x1,		/* 19,221 */
	0x1,		/* 19,222 */
	0x1,		/* 19,223 */
	0x1,		/* 19,224 */
	0x9,		/* 19,225 */
	0x1,		/* 19,226 */
	0x1,		/* 19,227 */
	0x1,		/* 19,228 */
	0x1,		/* 19,229 */
	0x1,		/* 19,230 */
	0x1,		/* 19,231 */
	0x1,		/* 19,232 */
	0x1,		/* 19,233 */
	0x1,		/* 19,234 */
	0x1,		/* 19,235 */
	0x1,		/* 19,236 */
	0x1,		/* 19,237 */
	0x1,		/* 19,238 */
	0x1,		/* 19,239 */
	0x1,		/* 19,240 */
	0x1,		/* 19,241 */
	0x1,		/* 19,242 */
	0x1,		/* 19,243 */
	0x1,		/* 19,244 */
	0x1,		/* 19,245 */
	0x1,		/* 19,246 */
	0x1,		/* 19,247 */
	0x1,		/* 19,248 */
	0x1,		/* 19,249 */
	0x1,		/* 19,250 */
	0x1,		/* 19,251 */
	0x1,		/* 19,252 */
	0x1,		/* 19,253 */
	0x1,		/* 19,254 */
	0x1,		/* 19,255 */
	0x1,		/* 20,0 */
	0x1,		/* 20,1 */
	0x1,		/* 20,2 */
	0x1,		/* 20,3 */
	0x1,		/* 20,4 */
	0x1,		/* 20,5 */
	0x1,		/* 20,6 */
	0x1,		/* 20,7 */
	0x1,		/* 20,8 */
	0x1,		/* 20,9 */
	0x1,		/* 20,10 */
	0x1,		/* 20,11 */
	0x1,		/* 20,12 */
	0x1,		/* 20,13 */
	0x1,		/* 20,14 */
	0x1,		/* 20,15 */
	0x1,		/* 20,16 */
	0x1,		/* 20,17 */
	0x1,		/* 20,18 */
	0x1,		/* 20,19 */
	0x1,		/* 20,20 */
	0x1,		/* 20,21 */
	0x1,		/* 20,22 */
	0x1,		/* 20,23 */
	0x1,		/* 20,24 */
	0x1,		/* 20,25 */
	0x1,		/* 20,26 */
	0x1,		/* 20,27 */
	0x1,		/* 20,28 */
	0x1,		/* 20,29 */
	0x1,		/* 20,30 */
	0x1,		/* 20,31 */
	0x1,		/* 20,32 */
	0x1,		/* 20,33 */
	0x1,		/* 20,34 */
	0x1,		/* 20,35 */
	0x1,		/* 20,36 */
	0x1,		/* 20,37 */
	0xb,		/* 20,38 */
	0x1,		/* 20,39 */
	0x1,		/* 20,40 */
	0x1,		/* 20,41 */
	0xb,		/* 20,42 */
	0xb,		/* 20,43 */
	0x1,		/* 20,44 */
	0x1,		/* 20,45 */
	0xb,		/* 20,46 */
	0x1,		/* 20,47 */
	0x1,		/* 20,48 */
	0x1,		/* 20,49 */
	0x1,		/* 20,50 */
	0x1,		/* 20,51 */
	0x1,		/* 20,52 */
	0x1,		/* 20,53 */
	0x1,		/* 20,54 */
	0x1,		/* 20,55 */
	0x1,		/* 20,56 */
	0x1,		/* 20,57 */
	0x1,		/* 20,58 */
	0x1,		/* 20,59 */
	0x1,		/* 20,60 */
	0x1,		/* 20,61 */
	0x1,		/* 20,62 */
	0x1,		/* 20,63 */
	0x1,		/* 20,64 */
	0x1,		/* 20,65 */
	0x1,		/* 20,66 */
	0x1,		/* 20,67 */
	0x1,		/* 20,68 */
	0x1,		/* 20,69 */
	0x1,		/* 20,70 */
	0x1,		/* 20,71 */
	0x1,		/* 20,72 */
	0x1,		/* 20,73 */
	0x1,		/* 20,74 */
	0x1,		/* 20,75 */
	0x1,		/* 20,76 */
	0x1,		/* 20,77 */
	0x1,		/* 20,78 */
	0x1,		/* 20,79 */
	0x1,		/* 20,80 */
	0x1,		/* 20,81 */
	0x1,		/* 20,82 */
	0x1,		/* 20,83 */
	0x1,		/* 20,84 */
	0x1,		/* 20,85 */
	0x1,		/* 20,86 */
	0x1,		/* 20,87 */
	0x1,		/* 20,88 */
	0x1,		/* 20,89 */
	0x1,		/* 20,90 */
	0x1,		/* 20,91 */
	0x1,		/* 20,92 */
	0x1,		/* 20,93 */
	0x1,		/* 20,94 */
	0x1,		/* 20,95 */
	0x1,		/* 20,96 */
	0x1,		/* 20,97 */
	0x1,		/* 20,98 */
	0x1,		/* 20,99 */
	0x1,		/* 20,100 */
	0x1,		/* 20,101 */
	0x1,		/* 20,102 */
	0x1,		/* 20,103 */
	0x1,		/* 20,104 */
	0x1,		/* 20,105 */
	0x1,		/* 20,106 */
	0x1,		/* 20,107 */
	0x1,		/* 20,108 */
	0x1,		/* 20,109 */
	0x1,		/* 20,110 */
	0x1,		/* 20,111 */
	0x1,		/* 20,112 */
	0x1,		/* 20,113 */
	0x1,		/* 20,114 */
	0x1,		/* 20,115 */
	0x1,		/* 20,116 */
	0x1,		/* 20,117 */
	0x1,		/* 20,118 */
	0x1,		/* 20,119 */
	0x1,		/* 20,120 */
	0x1,		/* 20,121 */
	0x1,		/* 20,122 */
	0x1,		/* 20,123 */
	0x1,		/* 20,124 */
	0x1,		/* 20,125 */
	0x1,		/* 20,126 */
	0x1,		/* 20,127 */
	0xb,		/* 20,128 */
	0xb,		/* 20,129 */
	0xb,		/* 20,130 */
	0x1,		/* 20,131 */
	0x1,		/* 20,132 */
	0x1,		/* 20,133 */
	0x1,		/* 20,134 */
	0x1,		/* 20,135 */
	0x1,		/* 20,136 */
	0x1,		/* 20,137 */
	0x1,		/* 20,138 */
	0x1,		/* 20,139 */
	0x1,		/* 20,140 */
	0x1,		/* 20,141 */
	0x1,		/* 20,142 */
	0x1,		/* 20,143 */
	0x1,		/* 20,144 */
	0x1,		/* 20,145 */
	0x1,		/* 20,146 */
	0x1,		/* 20,147 */
	0x1,		/* 20,148 */
	0x1,		/* 20,149 */
	0x1,		/* 20,150 */
	0x1,		/* 20,151 */
	0x1,		/* 20,152 */
	0x1,		/* 20,153 */
	0x1,		/* 20,154 */
	0x1,		/* 20,155 */
	0x1,		/* 20,156 */
	0x1,		/* 20,157 */
	0x1,		/* 20,158 */
	0x1,		/* 20,159 */
	0x1,		/* 20,160 */
	0x1,		/* 20,161 */
	0x1,		/* 20,162 */
	0x1,		/* 20,163 */
	0x1,		/* 20,164 */
	0x1,		/* 20,165 */
	0x1,		/* 20,166 */
	0x1,		/* 20,167 */
	0x1,		/* 20,168 */
	0x1,		/* 20,169 */
	0x1,		/* 20,170 */
	0x1,		/* 20,171 */
	0x1,		/* 20,172 */
	0x1,		/* 20,173 */
	0x1,		/* 20,174 */
	0x1,		/* 20,175 */
	0x1,		/* 20,176 */
	0x1,		/* 20,177 */
	0x1,		/* 20,178 */
	0x1,		/* 20,179 */
	0x1,		/* 20,180 */
	0x1,		/* 20,181 */
	0x1,		/* 20,182 */
	0x1,		/* 20,183 */
	0x1,		/* 20,184 */
	0x1,		/* 20,185 */
	0x1,		/* 20,186 */
	0x1,		/* 20,187 */
	0x1,		/* 20,188 */
	0x1,		/* 20,189 */
	0x1,		/* 20,190 */
	0x1,		/* 20,191 */
	0x1,		/* 20,192 */
	0x1,		/* 20,193 */
	0x1,		/* 20,194 */
	0x1,		/* 20,195 */
	0x1,		/* 20,196 */
	0x1,		/* 20,197 */
	0x1,		/* 20,198 */
	0x1,		/* 20,199 */
	0x1,		/* 20,200 */
	0x1,		/* 20,201 */
	0x1,		/* 20,202 */
	0x1,		/* 20,203 */
	0x1,		/* 20,204 */
	0x1,		/* 20,205 */
	0x1,		/* 20,206 */
	0x1,		/* 20,207 */
	0x1,		/* 20,208 */
	0x1,		/* 20,209 */
	0x1,		/* 20,210 */
	0x1,		/* 20,211 */
	0x1,		/* 20,212 */
	0x1,		/* 20,213 */
	0x1,		/* 20,214 */
	0x1,		/* 20,215 */
	0x1,		/* 20,216 */
	0x1,		/* 20,217 */
	0x1,		/* 20,218 */
	0x1,		/* 20,219 */
	0x1,		/* 20,220 */
	0x1,		/* 20,221 */
	0x1,		/* 20,222 */
	0x1,		/* 20,223 */
	0x1,		/* 20,224 */
	0x1,		/* 20,225 */
	0x1,		/* 20,226 */
	0x1,		/* 20,227 */
	0x1,		/* 20,228 */
	0x1,		/* 20,229 */
	0x1,		/* 20,230 */
	0x1,		/* 20,231 */
	0x1,		/* 20,232 */
	0x1,		/* 20,233 */
	0x1,		/* 20,234 */
	0x1,		/* 20,235 */
	0x1,		/* 20,236 */
	0x1,		/* 20,237 */
	0x1,		/* 20,238 */
	0x1,		/* 20,239 */
	0x1,		/* 20,240 */
	0x1,		/* 20,241 */
	0x1,		/* 20,242 */
	0x1,		/* 20,243 */
	0x1,		/* 20,244 */
	0x1,		/* 20,245 */
	0x1,		/* 20,246 */
	0x1,		/* 20,247 */
	0x1,		/* 20,248 */
	0x1,		/* 20,249 */
	0x1,		/* 20,250 */
	0x1,		/* 20,251 */
	0x1,		/* 20,252 */
	0x1,		/* 20,253 */
	0x1,		/* 20,254 */
	0x1,		/* 20,255 */
	0x1,		/* 21,0 */
	0x1,		/* 21,1 */
	0x1,		/* 21,2 */
	0x1,		/* 21,3 */
	0x1,		/* 21,4 */
	0x9,		/* 21,5 */
	0x1,		/* 21,6 */
	0xb,		/* 21,7 */
	0x1,		/* 21,8 */
	0x1,		/* 21,9 */
	0x1,		/* 21,10 */
	0x1,		/* 21,11 */
	0x1,		/* 21,12 */
	0x1,		/* 21,13 */
	0x1,		/* 21,14 */
	0x1,		/* 21,15 */
	0x1,		/* 21,16 */
	0x1,		/* 21,17 */
	0x1,		/* 21,18 */
	0x1,		/* 21,19 */
	0x1,		/* 21,20 */
	0x1,		/* 21,21 */
	0x1,		/* 21,22 */
	0x1,		/* 21,23 */
	0x1,		/* 21,24 */
	0x1,		/* 21,25 */
	0x1,		/* 21,26 */
	0x1,		/* 21,27 */
	0x1,		/* 21,28 */
	0x1,		/* 21,29 */
	0x1,		/* 21,30 */
	0x1,		/* 21,31 */
	0x1,		/* 21,32 */
	0xb,		/* 21,33 */
	0xb,		/* 21,34 */
	0xb,		/* 21,35 */
	0xb,		/* 21,36 */
	0xb,		/* 21,37 */
	0xb,		/* 21,38 */
	0xb,		/* 21,39 */
	0xb,		/* 21,40 */
	0xb,		/* 21,41 */
	0x9,		/* 21,42 */
	0x9,		/* 21,43 */
	0x9,		/* 21,44 */
	0x9,		/* 21,45 */
	0x9,		/* 21,46 */
	0x9,		/* 21,47 */
	0x1,		/* 21,48 */
	0x9,		/* 21,49 */
	0x9,		/* 21,50 */
	0x9,		/* 21,51 */
	0x9,		/* 21,52 */
	0x9,		/* 21,53 */
	0x1,		/* 21,54 */
	0x1,		/* 21,55 */
	0x1,		/* 21,56 */
	0x1,		/* 21,57 */
	0x1,		/* 21,58 */
	0x1,		/* 21,59 */
	0x1,		/* 21,60 */
	0x1,		/* 21,61 */
	0x1,		/* 21,62 */
	0x1,		/* 21,63 */
	0x1,		/* 21,64 */
	0xb,		/* 21,65 */
	0xb,		/* 21,66 */
	0xb,		/* 21,67 */
	0xb,		/* 21,68 */
	0xb,		/* 21,69 */
	0xb,		/* 21,70 */
	0xb,		/* 21,71 */
	0xb,		/* 21,72 */
	0xb,		/* 21,73 */
	0xb,		/* 21,74 */
	0xb,		/* 21,75 */
	0xb,		/* 21,76 */
	0xb,		/* 21,77 */
	0xb,		/* 21,78 */
	0xb,		/* 21,79 */
	0xb,		/* 21,80 */
	0xb,		/* 21,81 */
	0xb,		/* 21,82 */
	0xb,		/* 21,83 */
	0xb,		/* 21,84 */
	0xb,		/* 21,85 */
	0xb,		/* 21,86 */
	0xb,		/* 21,87 */
	0xb,		/* 21,88 */
	0xb,		/* 21,89 */
	0xb,		/* 21,90 */
	0xb,		/* 21,91 */
	0xb,		/* 21,92 */
	0xb,		/* 21,93 */
	0xb,		/* 21,94 */
	0xb,		/* 21,95 */
	0xb,		/* 21,96 */
	0xb,		/* 21,97 */
	0xb,		/* 21,98 */
	0xb,		/* 21,99 */
	0xb,		/* 21,100 */
	0xb,		/* 21,101 */
	0xb,		/* 21,102 */
	0xb,		/* 21,103 */
	0xb,		/* 21,104 */
	0xb,		/* 21,105 */
	0xb,		/* 21,106 */
	0xb,		/* 21,107 */
	0xb,		/* 21,108 */
	0xb,		/* 21,109 */
	0xb,		/* 21,110 */
	0xb,		/* 21,111 */
	0xb,		/* 21,112 */
	0xb,		/* 21,113 */
	0xb,		/* 21,114 */
	0xb,		/* 21,115 */
	0xb,		/* 21,116 */
	0xb,		/* 21,117 */
	0xb,		/* 21,118 */
	0xb,		/* 21,119 */
	0xb,		/* 21,120 */
	0xb,		/* 21,121 */
	0xb,		/* 21,122 */
	0xb,		/* 21,123 */
	0xb,		/* 21,124 */
	0xb,		/* 21,125 */
	0xb,		/* 21,126 */
	0xb,		/* 21,127 */
	0xb,		/* 21,128 */
	0xb,		/* 21,129 */
	0xb,		/* 21,130 */
	0xb,		/* 21,131 */
	0xb,		/* 21,132 */
	0xb,		/* 21,133 */
	0xb,		/* 21,134 */
	0xb,		/* 21,135 */
	0xb,		/* 21,136 */
	0xb,		/* 21,137 */
	0xb,		/* 21,138 */
	0xb,		/* 21,139 */
	0xb,		/* 21,140 */
	0xb,		/* 21,141 */
	0xb,		/* 21,142 */
	0xb,		/* 21,143 */
	0xb,		/* 21,144 */
	0xb,		/* 21,145 */
	0xb,		/* 21,146 */
	0xb,		/* 21,147 */
	0xb,		/* 21,148 */
	0x1,		/* 21,149 */
	0x1,		/* 21,150 */
	0x1,		/* 21,151 */
	0x1,		/* 21,152 */
	0x9,		/* 21,153 */
	0x9,		/* 21,154 */
	0x1,		/* 21,155 */
	0x1,		/* 21,156 */
	0x9,		/* 21,157 */
	0x9,		/* 21,158 */
	0x1,		/* 21,159 */
	0x1,		/* 21,160 */
	0xb,		/* 21,161 */
	0xb,		/* 21,162 */
	0xb,		/* 21,163 */
	0xb,		/* 21,164 */
	0xb,		/* 21,165 */
	0xb,		/* 21,166 */
	0xb,		/* 21,167 */
	0xb,		/* 21,168 */
	0xb,		/* 21,169 */
	0xb,		/* 21,170 */
	0xb,		/* 21,171 */
	0xb,		/* 21,172 */
	0xb,		/* 21,173 */
	0xb,		/* 21,174 */
	0xb,		/* 21,175 */
	0xb,		/* 21,176 */
	0xb,		/* 21,177 */
	0xb,		/* 21,178 */
	0xb,		/* 21,179 */
	0xb,		/* 21,180 */
	0xb,		/* 21,181 */
	0xb,		/* 21,182 */
	0xb,		/* 21,183 */
	0xb,		/* 21,184 */
	0xb,		/* 21,185 */
	0xb,		/* 21,186 */
	0xb,		/* 21,187 */
	0xb,		/* 21,188 */
	0xb,		/* 21,189 */
	0xb,		/* 21,190 */
	0xb,		/* 21,191 */
	0xb,		/* 21,192 */
	0xb,		/* 21,193 */
	0xb,		/* 21,194 */
	0xb,		/* 21,195 */
	0xb,		/* 21,196 */
	0xb,		/* 21,197 */
	0xb,		/* 21,198 */
	0xb,		/* 21,199 */
	0xb,		/* 21,200 */
	0xb,		/* 21,201 */
	0xb,		/* 21,202 */
	0xb,		/* 21,203 */
	0xb,		/* 21,204 */
	0xb,		/* 21,205 */
	0xb,		/* 21,206 */
	0xb,		/* 21,207 */
	0xb,		/* 21,208 */
	0xb,		/* 21,209 */
	0xb,		/* 21,210 */
	0xb,		/* 21,211 */
	0xb,		/* 21,212 */
	0xb,		/* 21,213 */
	0xb,		/* 21,214 */
	0xb,		/* 21,215 */
	0xb,		/* 21,216 */
	0xb,		/* 21,217 */
	0xb,		/* 21,218 */
	0xb,		/* 21,219 */
	0xb,		/* 21,220 */
	0xb,		/* 21,221 */
	0xb,		/* 21,222 */
	0xb,		/* 21,223 */
	0xb,		/* 21,224 */
	0xb,		/* 21,225 */
	0xb,		/* 21,226 */
	0xb,		/* 21,227 */
	0xb,		/* 21,228 */
	0xb,		/* 21,229 */
	0xb,		/* 21,230 */
	0xb,		/* 21,231 */
	0xb,		/* 21,232 */
	0xb,		/* 21,233 */
	0xb,		/* 21,234 */
	0xb,		/* 21,235 */
	0xb,		/* 21,236 */
	0xb,		/* 21,237 */
	0xb,		/* 21,238 */
	0xb,		/* 21,239 */
	0xb,		/* 21,240 */
	0xb,		/* 21,241 */
	0xb,		/* 21,242 */
	0xb,		/* 21,243 */
	0xb,		/* 21,244 */
	0xb,		/* 21,245 */
	0xb,		/* 21,246 */
	0xb,		/* 21,247 */
	0xb,		/* 21,248 */
	0xb,		/* 21,249 */
	0xb,		/* 21,250 */
	0x1,		/* 21,251 */
	0x9,		/* 21,252 */
	0x9,		/* 21,253 */
	0x9,		/* 21,254 */
	0x1,		/* 21,255 */
	0x1,		/* 22,0 */
	0x1,		/* 22,1 */
	0x1,		/* 22,2 */
	0x1,		/* 22,3 */
	0x1,		/* 22,4 */
	0xb,		/* 22,5 */
	0xb,		/* 22,6 */
	0xb,		/* 22,7 */
	0xb,		/* 22,8 */
	0xb,		/* 22,9 */
	0xb,		/* 22,10 */
	0xb,		/* 22,11 */
	0xb,		/* 22,12 */
	0xb,		/* 22,13 */
	0xb,		/* 22,14 */
	0xb,		/* 22,15 */
	0xb,		/* 22,16 */
	0xb,		/* 22,17 */
	0xb,		/* 22,18 */
	0xb,		/* 22,19 */
	0xb,		/* 22,20 */
	0xb,		/* 22,21 */
	0xb,		/* 22,22 */
	0xb,		/* 22,23 */
	0xb,		/* 22,24 */
	0xb,		/* 22,25 */
	0xb,		/* 22,26 */
	0xb,		/* 22,27 */
	0xb,		/* 22,28 */
	0xb,		/* 22,29 */
	0xb,		/* 22,30 */
	0xb,		/* 22,31 */
	0xb,		/* 22,32 */
	0xb,		/* 22,33 */
	0xb,		/* 22,34 */
	0xb,		/* 22,35 */
	0xb,		/* 22,36 */
	0xb,		/* 22,37 */
	0xb,		/* 22,38 */
	0xb,		/* 22,39 */
	0xb,		/* 22,40 */
	0xb,		/* 22,41 */
	0xb,		/* 22,42 */
	0xb,		/* 22,43 */
	0xb,		/* 22,44 */
	0x1,		/* 22,45 */
	0x1,		/* 22,46 */
	0x1,		/* 22,47 */
	0x1,		/* 22,48 */
	0x1,		/* 22,49 */
	0x1,		/* 22,50 */
	0x1,		/* 22,51 */
	0x1,		/* 22,52 */
	0x1,		/* 22,53 */
	0x1,		/* 22,54 */
	0x1,		/* 22,55 */
	0x1,		/* 22,56 */
	0x1,		/* 22,57 */
	0x1,		/* 22,58 */
	0x1,		/* 22,59 */
	0x1,		/* 22,60 */
	0x1,		/* 22,61 */
	0x1,		/* 22,62 */
	0x1,		/* 22,63 */
	0x1,		/* 22,64 */
	0x1,		/* 22,65 */
	0x1,		/* 22,66 */
	0x1,		/* 22,67 */
	0x1,		/* 22,68 */
	0x1,		/* 22,69 */
	0x1,		/* 22,70 */
	0x1,		/* 22,71 */
	0x1,		/* 22,72 */
	0x1,		/* 22,73 */
	0x1,		/* 22,74 */
	0x1,		/* 22,75 */
	0x1,		/* 22,76 */
	0x1,		/* 22,77 */
	0x1,		/* 22,78 */
	0x1,		/* 22,79 */
	0x1,		/* 22,80 */
	0x1,		/* 22,81 */
	0x1,		/* 22,82 */
	0x1,		/* 22,83 */
	0x1,		/* 22,84 */
	0x1,		/* 22,85 */
	0x1,		/* 22,86 */
	0x1,		/* 22,87 */
	0x1,		/* 22,88 */
	0x1,		/* 22,89 */
	0x1,		/* 22,90 */
	0x1,		/* 22,91 */
	0x1,		/* 22,92 */
	0x1,		/* 22,93 */
	0x1,		/* 22,94 */
	0x1,		/* 22,95 */
	0x1,		/* 22,96 */
	0x1,		/* 22,97 */
	0x1,		/* 22,98 */
	0x1,		/* 22,99 */
	0x1,		/* 22,100 */
	0x1,		/* 22,101 */
	0x1,		/* 22,102 */
	0x1,		/* 22,103 */
	0x1,		/* 22,104 */
	0x1,		/* 22,105 */
	0x1,		/* 22,106 */
	0x1,		/* 22,107 */
	0x1,		/* 22,108 */
	0x1,		/* 22,109 */
	0x1,		/* 22,110 */
	0x1,		/* 22,111 */
	0x1,		/* 22,112 */
	0x1,		/* 22,113 */
	0x1,		/* 22,114 */
	0x1,		/* 22,115 */
	0x1,		/* 22,116 */
	0x1,		/* 22,117 */
	0x1,		/* 22,118 */
	0x1,		/* 22,119 */
	0x1,		/* 22,120 */
	0x1,		/* 22,121 */
	0x1,		/* 22,122 */
	0x1,		/* 22,123 */
	0x1,		/* 22,124 */
	0x1,		/* 22,125 */
	0x1,		/* 22,126 */
	0x1,		/* 22,127 */
	0x1,		/* 22,128 */
	0x1,		/* 22,129 */
	0x1,		/* 22,130 */
	0x1,		/* 22,131 */
	0x1,		/* 22,132 */
	0x1,		/* 22,133 */
	0x1,		/* 22,134 */
	0x1,		/* 22,135 */
	0x1,		/* 22,136 */
	0x1,		/* 22,137 */
	0x1,		/* 22,138 */
	0x1,		/* 22,139 */
	0x1,		/* 22,140 */
	0x1,		/* 22,141 */
	0x1,		/* 22,142 */
	0x1,		/* 22,143 */
	0x1,		/* 22,144 */
	0x1,		/* 22,145 */
	0x1,		/* 22,146 */
	0x1,		/* 22,147 */
	0x1,		/* 22,148 */
	0x1,		/* 22,149 */
	0x1,		/* 22,150 */
	0x1,		/* 22,151 */
	0x1,		/* 22,152 */
	0x1,		/* 22,153 */
	0x1,		/* 22,154 */
	0x1,		/* 22,155 */
	0x1,		/* 22,156 */
	0x1,		/* 22,157 */
	0x1,		/* 22,158 */
	0x1,		/* 22,159 */
	0x1,		/* 22,160 */
	0x1,		/* 22,161 */
	0x1,		/* 22,162 */
	0x1,		/* 22,163 */
	0x1,		/* 22,164 */
	0x1,		/* 22,165 */
	0x1,		/* 22,166 */
	0x1,		/* 22,167 */
	0x1,		/* 22,168 */
	0x1,		/* 22,169 */
	0x1,		/* 22,170 */
	0x1,		/* 22,171 */
	0x1,		/* 22,172 */
	0x1,		/* 22,173 */
	0x1,		/* 22,174 */
	0x1,		/* 22,175 */
	0x1,		/* 22,176 */
	0x1,		/* 22,177 */
	0x1,		/* 22,178 */
	0x1,		/* 22,179 */
	0x1,		/* 22,180 */
	0x1,		/* 22,181 */
	0x1,		/* 22,182 */
	0x1,		/* 22,183 */
	0x1,		/* 22,184 */
	0x1,		/* 22,185 */
	0x1,		/* 22,186 */
	0x1,		/* 22,187 */
	0x1,		/* 22,188 */
	0x1,		/* 22,189 */
	0x1,		/* 22,190 */
	0x1,		/* 22,191 */
	0x1,		/* 22,192 */
	0x1,		/* 22,193 */
	0x1,		/* 22,194 */
	0x1,		/* 22,195 */
	0x1,		/* 22,196 */
	0x1,		/* 22,197 */
	0x1,		/* 22,198 */
	0x1,		/* 22,199 */
	0x1,		/* 22,200 */
	0x1,		/* 22,201 */
	0x1,		/* 22,202 */
	0x1,		/* 22,203 */
	0x1,		/* 22,204 */
	0x1,		/* 22,205 */
	0x1,		/* 22,206 */
	0x1,		/* 22,207 */
	0x1,		/* 22,208 */
	0x1,		/* 22,209 */
	0x1,		/* 22,210 */
	0x1,		/* 22,211 */
	0x1,		/* 22,212 */
	0x1,		/* 22,213 */
	0x1,		/* 22,214 */
	0x1,		/* 22,215 */
	0x1,		/* 22,216 */
	0x1,		/* 22,217 */
	0x1,		/* 22,218 */
	0x1,		/* 22,219 */
	0x1,		/* 22,220 */
	0x1,		/* 22,221 */
	0x1,		/* 22,222 */
	0x1,		/* 22,223 */
	0x1,		/* 22,224 */
	0x1,		/* 22,225 */
	0x1,		/* 22,226 */
	0x1,		/* 22,227 */
	0x1,		/* 22,228 */
	0x1,		/* 22,229 */
	0x1,		/* 22,230 */
	0x1,		/* 22,231 */
	0x1,		/* 22,232 */
	0x1,		/* 22,233 */
	0x1,		/* 22,234 */
	0x1,		/* 22,235 */
	0x1,		/* 22,236 */
	0x1,		/* 22,237 */
	0x1,		/* 22,238 */
	0x1,		/* 22,239 */
	0x1,		/* 22,240 */
	0x1,		/* 22,241 */
	0x1,		/* 22,242 */
	0x1,		/* 22,243 */
	0x1,		/* 22,244 */
	0x1,		/* 22,245 */
	0x1,		/* 22,246 */
	0x1,		/* 22,247 */
	0x1,		/* 22,248 */
	0x1,		/* 22,249 */
	0x1,		/* 22,250 */
	0x1,		/* 22,251 */
	0x1,		/* 22,252 */
	0x1,		/* 22,253 */
	0x1,		/* 22,254 */
	0x1,		/* 22,255 */
	0xb,		/* 23,0 */
	0xb,		/* 23,1 */
	0xb,		/* 23,2 */
	0xb,		/* 23,3 */
	0xb,		/* 23,4 */
	0xb,		/* 23,5 */
	0xb,		/* 23,6 */
	0xb,		/* 23,7 */
	0xb,		/* 23,8 */
	0xb,		/* 23,9 */
	0xb,		/* 23,10 */
	0xb,		/* 23,11 */
	0xb,		/* 23,12 */
	0xb,		/* 23,13 */
	0xb,		/* 23,14 */
	0xb,		/* 23,15 */
	0xb,		/* 23,16 */
	0xb,		/* 23,17 */
	0xb,		/* 23,18 */
	0xb,		/* 23,19 */
	0xb,		/* 23,20 */
	0xb,		/* 23,21 */
	0xb,		/* 23,22 */
	0xb,		/* 23,23 */
	0xb,		/* 23,24 */
	0xb,		/* 23,25 */
	0xb,		/* 23,26 */
	0xb,		/* 23,27 */
	0xb,		/* 23,28 */
	0xb,		/* 23,29 */
	0xb,		/* 23,30 */
	0xb,		/* 23,31 */
	0xb,		/* 23,32 */
	0xb,		/* 23,33 */
	0xb,		/* 23,34 */
	0xb,		/* 23,35 */
	0xb,		/* 23,36 */
	0xb,		/* 23,37 */
	0xb,		/* 23,38 */
	0xb,		/* 23,39 */
	0xb,		/* 23,40 */
	0xb,		/* 23,41 */
	0xb,		/* 23,42 */
	0xb,		/* 23,43 */
	0xb,		/* 23,44 */
	0xb,		/* 23,45 */
	0xb,		/* 23,46 */
	0xb,		/* 23,47 */
	0xb,		/* 23,48 */
	0xb,		/* 23,49 */
	0xb,		/* 23,50 */
	0xb,		/* 23,51 */
	0xb,		/* 23,52 */
	0xb,		/* 23,53 */
	0xb,		/* 23,54 */
	0xb,		/* 23,55 */
	0xb,		/* 23,56 */
	0xb,		/* 23,57 */
	0xb,		/* 23,58 */
	0xb,		/* 23,59 */
	0xb,		/* 23,60 */
	0xb,		/* 23,61 */
	0xb,		/* 23,62 */
	0xb,		/* 23,63 */
	0xb,		/* 23,64 */
	0xb,		/* 23,65 */
	0xb,		/* 23,66 */
	0xb,		/* 23,67 */
	0xb,		/* 23,68 */
	0xb,		/* 23,69 */
	0xb,		/* 23,70 */
	0xb,		/* 23,71 */
	0xb,		/* 23,72 */
	0xb,		/* 23,73 */
	0xb,		/* 23,74 */
	0xb,		/* 23,75 */
	0xb,		/* 23,76 */
	0xb,		/* 23,77 */
	0xb,		/* 23,78 */
	0xb,		/* 23,79 */
	0xb,		/* 23,80 */
	0xb,		/* 23,81 */
	0xb,		/* 23,82 */
	0xb,		/* 23,83 */
	0xb,		/* 23,84 */
	0xb,		/* 23,85 */
	0xb,		/* 23,86 */
	0xb,		/* 23,87 */
	0xb,		/* 23,88 */
	0xb,		/* 23,89 */
	0xb,		/* 23,90 */
	0xb,		/* 23,91 */
	0xb,		/* 23,92 */
	0xb,		/* 23,93 */
	0xb,		/* 23,94 */
	0xb,		/* 23,95 */
	0xb,		/* 23,96 */
	0xb,		/* 23,97 */
	0xb,		/* 23,98 */
	0xb,		/* 23,99 */
	0xb,		/* 23,100 */
	0xb,		/* 23,101 */
	0xb,		/* 23,102 */
	0xb,		/* 23,103 */
	0xb,		/* 23,104 */
	0xb,		/* 23,105 */
	0xb,		/* 23,106 */
	0xb,		/* 23,107 */
	0xb,		/* 23,108 */
	0xb,		/* 23,109 */
	0xb,		/* 23,110 */
	0xb,		/* 23,111 */
	0xb,		/* 23,112 */
	0xb,		/* 23,113 */
	0xb,		/* 23,114 */
	0xb,		/* 23,115 */
	0xb,		/* 23,116 */
	0xb,		/* 23,117 */
	0xb,		/* 23,118 */
	0xb,		/* 23,119 */
	0xb,		/* 23,120 */
	0xb,		/* 23,121 */
	0xb,		/* 23,122 */
	0xb,		/* 23,123 */
	0xb,		/* 23,124 */
	0xb,		/* 23,125 */
	0xb,		/* 23,126 */
	0xb,		/* 23,127 */
	0xb,		/* 23,128 */
	0xb,		/* 23,129 */
	0xb,		/* 23,130 */
	0xb,		/* 23,131 */
	0xb,		/* 23,132 */
	0xb,		/* 23,133 */
	0xb,		/* 23,134 */
	0xb,		/* 23,135 */
	0xb,		/* 23,136 */
	0xb,		/* 23,137 */
	0xb,		/* 23,138 */
	0xb,		/* 23,139 */
	0xb,		/* 23,140 */
	0xb,		/* 23,141 */
	0xb,		/* 23,142 */
	0xb,		/* 23,143 */
	0xb,		/* 23,144 */
	0xb,		/* 23,145 */
	0xb,		/* 23,146 */
	0xb,		/* 23,147 */
	0xb,		/* 23,148 */
	0xb,		/* 23,149 */
	0xb,		/* 23,150 */
	0xb,		/* 23,151 */
	0xb,		/* 23,152 */
	0xb,		/* 23,153 */
	0xb,		/* 23,154 */
	0xb,		/* 23,155 */
	0xb,		/* 23,156 */
	0xb,		/* 23,157 */
	0xb,		/* 23,158 */
	0xb,		/* 23,159 */
	0xb,		/* 23,160 */
	0xb,		/* 23,161 */
	0xb,		/* 23,162 */
	0xb,		/* 23,163 */
	0xb,		/* 23,164 */
	0xb,		/* 23,165 */
	0xb,		/* 23,166 */
	0xb,		/* 23,167 */
	0xb,		/* 23,168 */
	0xb,		/* 23,169 */
	0xb,		/* 23,170 */
	0xb,		/* 23,171 */
	0xb,		/* 23,172 */
	0xb,		/* 23,173 */
	0xb,		/* 23,174 */
	0xb,		/* 23,175 */
	0xb,		/* 23,176 */
	0xb,		/* 23,177 */
	0xb,		/* 23,178 */
	0xb,		/* 23,179 */
	0xb,		/* 23,180 */
	0xb,		/* 23,181 */
	0xb,		/* 23,182 */
	0xb,		/* 23,183 */
	0xb,		/* 23,184 */
	0xb,		/* 23,185 */
	0xb,		/* 23,186 */
	0xb,		/* 23,187 */
	0xb,		/* 23,188 */
	0xb,		/* 23,189 */
	0xb,		/* 23,190 */
	0xb,		/* 23,191 */
	0xb,		/* 23,192 */
	0xb,		/* 23,193 */
	0xb,		/* 23,194 */
	0xb,		/* 23,195 */
	0xb,		/* 23,196 */
	0xb,		/* 23,197 */
	0xb,		/* 23,198 */
	0xb,		/* 23,199 */
	0xb,		/* 23,200 */
	0xb,		/* 23,201 */
	0xb,		/* 23,202 */
	0xb,		/* 23,203 */
	0xb,		/* 23,204 */
	0xb,		/* 23,205 */
	0xb,		/* 23,206 */
	0xb,		/* 23,207 */
	0xb,		/* 23,208 */
	0xb,		/* 23,209 */
	0xb,		/* 23,210 */
	0xb,		/* 23,211 */
	0xb,		/* 23,212 */
	0xb,		/* 23,213 */
	0xb,		/* 23,214 */
	0xb,		/* 23,215 */
	0xb,		/* 23,216 */
	0xb,		/* 23,217 */
	0xb,		/* 23,218 */
	0xb,		/* 23,219 */
	0xb,		/* 23,220 */
	0xb,		/* 23,221 */
	0xb,		/* 23,222 */
	0xb,		/* 23,223 */
	0xb,		/* 23,224 */
	0xb,		/* 23,225 */
	0xb,		/* 23,226 */
	0xb,		/* 23,227 */
	0xb,		/* 23,228 */
	0xb,		/* 23,229 */
	0xb,		/* 23,230 */
	0xb,		/* 23,231 */
	0xb,		/* 23,232 */
	0xb,		/* 23,233 */
	0xb,		/* 23,234 */
	0xb,		/* 23,235 */
	0xb,		/* 23,236 */
	0xb,		/* 23,237 */
	0xb,		/* 23,238 */
	0xb,		/* 23,239 */
	0xb,		/* 23,240 */
	0xb,		/* 23,241 */
	0xb,		/* 23,242 */
	0xb,		/* 23,243 */
	0xb,		/* 23,244 */
	0xb,		/* 23,245 */
	0xb,		/* 23,246 */
	0xb,		/* 23,247 */
	0xb,		/* 23,248 */
	0xb,		/* 23,249 */
	0xb,		/* 23,250 */
	0xb,		/* 23,251 */
	0xb,		/* 23,252 */
	0xb,		/* 23,253 */
	0xb,		/* 23,254 */
	0xb,		/* 23,255 */
	0xb,		/* 24,0 */
	0xb,		/* 24,1 */
	0xb,		/* 24,2 */
	0xb,		/* 24,3 */
	0xb,		/* 24,4 */
	0xb,		/* 24,5 */
	0xb,		/* 24,6 */
	0xb,		/* 24,7 */
	0xb,		/* 24,8 */
	0xb,		/* 24,9 */
	0xb,		/* 24,10 */
	0xb,		/* 24,11 */
	0xb,		/* 24,12 */
	0xb,		/* 24,13 */
	0xb,		/* 24,14 */
	0xb,		/* 24,15 */
	0xb,		/* 24,16 */
	0xb,		/* 24,17 */
	0xb,		/* 24,18 */
	0xb,		/* 24,19 */
	0xb,		/* 24,20 */
	0xb,		/* 24,21 */
	0xb,		/* 24,22 */
	0xb,		/* 24,23 */
	0xb,		/* 24,24 */
	0xb,		/* 24,25 */
	0xb,		/* 24,26 */
	0xb,		/* 24,27 */
	0xb,		/* 24,28 */
	0xb,		/* 24,29 */
	0xb,		/* 24,30 */
	0xb,		/* 24,31 */
	0xb,		/* 24,32 */
	0xb,		/* 24,33 */
	0xb,		/* 24,34 */
	0xb,		/* 24,35 */
	0xb,		/* 24,36 */
	0xb,		/* 24,37 */
	0xb,		/* 24,38 */
	0xb,		/* 24,39 */
	0xb,		/* 24,40 */
	0xb,		/* 24,41 */
	0xb,		/* 24,42 */
	0xb,		/* 24,43 */
	0xb,		/* 24,44 */
	0xb,		/* 24,45 */
	0xb,		/* 24,46 */
	0xb,		/* 24,47 */
	0xb,		/* 24,48 */
	0xb,		/* 24,49 */
	0xb,		/* 24,50 */
	0xb,		/* 24,51 */
	0xb,		/* 24,52 */
	0xb,		/* 24,53 */
	0xb,		/* 24,54 */
	0xb,		/* 24,55 */
	0xb,		/* 24,56 */
	0xb,		/* 24,57 */
	0xb,		/* 24,58 */
	0xb,		/* 24,59 */
	0xb,		/* 24,60 */
	0xb,		/* 24,61 */
	0xb,		/* 24,62 */
	0xb,		/* 24,63 */
	0xb,		/* 24,64 */
	0xb,		/* 24,65 */
	0xb,		/* 24,66 */
	0xb,		/* 24,67 */
	0xb,		/* 24,68 */
	0xb,		/* 24,69 */
	0xb,		/* 24,70 */
	0xb,		/* 24,71 */
	0xb,		/* 24,72 */
	0xb,		/* 24,73 */
	0xb,		/* 24,74 */
	0xb,		/* 24,75 */
	0xb,		/* 24,76 */
	0xb,		/* 24,77 */
	0xb,		/* 24,78 */
	0xb,		/* 24,79 */
	0xb,		/* 24,80 */
	0xb,		/* 24,81 */
	0xb,		/* 24,82 */
	0xb,		/* 24,83 */
	0xb,		/* 24,84 */
	0xb,		/* 24,85 */
	0xb,		/* 24,86 */
	0xb,		/* 24,87 */
	0xb,		/* 24,88 */
	0xb,		/* 24,89 */
	0xb,		/* 24,90 */
	0xb,		/* 24,91 */
	0xb,		/* 24,92 */
	0xb,		/* 24,93 */
	0xb,		/* 24,94 */
	0xb,		/* 24,95 */
	0xb,		/* 24,96 */
	0xb,		/* 24,97 */
	0xb,		/* 24,98 */
	0xb,		/* 24,99 */
	0xb,		/* 24,100 */
	0xb,		/* 24,101 */
	0xb,		/* 24,102 */
	0xb,		/* 24,103 */
	0xb,		/* 24,104 */
	0xb,		/* 24,105 */
	0xb,		/* 24,106 */
	0xb,		/* 24,107 */
	0xb,		/* 24,108 */
	0xb,		/* 24,109 */
	0xb,		/* 24,110 */
	0xb,		/* 24,111 */
	0xb,		/* 24,112 */
	0xb,		/* 24,113 */
	0xb,		/* 24,114 */
	0xb,		/* 24,115 */
	0xb,		/* 24,116 */
	0xb,		/* 24,117 */
	0xb,		/* 24,118 */
	0xb,		/* 24,119 */
	0xb,		/* 24,120 */
	0xb,		/* 24,121 */
	0xb,		/* 24,122 */
	0xb,		/* 24,123 */
	0xb,		/* 24,124 */
	0xb,		/* 24,125 */
	0xb,		/* 24,126 */
	0xb,		/* 24,127 */
	0xb,		/* 24,128 */
	0xb,		/* 24,129 */
	0xb,		/* 24,130 */
	0xb,		/* 24,131 */
	0xb,		/* 24,132 */
	0xb,		/* 24,133 */
	0xb,		/* 24,134 */
	0xb,		/* 24,135 */
	0xb,		/* 24,136 */
	0xb,		/* 24,137 */
	0xb,		/* 24,138 */
	0xb,		/* 24,139 */
	0xb,		/* 24,140 */
	0xb,		/* 24,141 */
	0xb,		/* 24,142 */
	0xb,		/* 24,143 */
	0xb,		/* 24,144 */
	0xb,		/* 24,145 */
	0xb,		/* 24,146 */
	0xb,		/* 24,147 */
	0xb,		/* 24,148 */
	0xb,		/* 24,149 */
	0xb,		/* 24,150 */
	0xb,		/* 24,151 */
	0xb,		/* 24,152 */
	0xb,		/* 24,153 */
	0xb,		/* 24,154 */
	0xb,		/* 24,155 */
	0xb,		/* 24,156 */
	0xb,		/* 24,157 */
	0xb,		/* 24,158 */
	0xb,		/* 24,159 */
	0xb,		/* 24,160 */
	0xb,		/* 24,161 */
	0xb,		/* 24,162 */
	0xb,		/* 24,163 */
	0xb,		/* 24,164 */
	0xb,		/* 24,165 */
	0x1,		/* 24,166 */
	0x1,		/* 24,167 */
	0x1,		/* 24,168 */
	0x1,		/* 24,169 */
	0x1,		/* 24,170 */
	0x1,		/* 24,171 */
	0x1,		/* 24,172 */
	0x1,		/* 24,173 */
	0x1,		/* 24,174 */
	0x1,		/* 24,175 */
	0x1,		/* 24,176 */
	0x1,		/* 24,177 */
	0x1,		/* 24,178 */
	0x1,		/* 24,179 */
	0x1,		/* 24,180 */
	0x1,		/* 24,181 */
	0x1,		/* 24,182 */
	0x1,		/* 24,183 */
	0x1,		/* 24,184 */
	0x1,		/* 24,185 */
	0x1,		/* 24,186 */
	0x1,		/* 24,187 */
	0x1,		/* 24,188 */
	0x1,		/* 24,189 */
	0x1,		/* 24,190 */
	0x1,		/* 24,191 */
	0x1,		/* 24,192 */
	0x1,		/* 24,193 */
	0x1,		/* 24,194 */
	0x1,		/* 24,195 */
	0x1,		/* 24,196 */
	0x1,		/* 24,197 */
	0x1,		/* 24,198 */
	0x1,		/* 24,199 */
	0x1,		/* 24,200 */
	0x1,		/* 24,201 */
	0x1,		/* 24,202 */
	0x1,		/* 24,203 */
	0x1,		/* 24,204 */
	0x1,		/* 24,205 */
	0x1,		/* 24,206 */
	0x1,		/* 24,207 */
	0x1,		/* 24,208 */
	0x1,		/* 24,209 */
	0x1,		/* 24,210 */
	0x1,		/* 24,211 */
	0x1,		/* 24,212 */
	0x1,		/* 24,213 */
	0x1,		/* 24,214 */
	0x1,		/* 24,215 */
	0x1,		/* 24,216 */
	0x1,		/* 24,217 */
	0x1,		/* 24,218 */
	0x1,		/* 24,219 */
	0x1,		/* 24,220 */
	0x1,		/* 24,221 */
	0x1,		/* 24,222 */
	0x1,		/* 24,223 */
	0x1,		/* 24,224 */
	0x1,		/* 24,225 */
	0x1,		/* 24,226 */
	0x1,		/* 24,227 */
	0x1,		/* 24,228 */
	0x1,		/* 24,229 */
	0x1,		/* 24,230 */
	0x1,		/* 24,231 */
	0x1,		/* 24,232 */
	0x1,		/* 24,233 */
	0x1,		/* 24,234 */
	0x1,		/* 24,235 */
	0x1,		/* 24,236 */
	0x1,		/* 24,237 */
	0x1,		/* 24,238 */
	0x1,		/* 24,239 */
	0x1,		/* 24,240 */
	0x1,		/* 24,241 */
	0x1,		/* 24,242 */
	0x1,		/* 24,243 */
	0x1,		/* 24,244 */
	0x1,		/* 24,245 */
	0x1,		/* 24,246 */
	0x1,		/* 24,247 */
	0x1,		/* 24,248 */
	0x1,		/* 24,249 */
	0x1,		/* 24,250 */
	0x1,		/* 24,251 */
	0x1,		/* 24,252 */
	0x1,		/* 24,253 */
	0x1,		/* 24,254 */
	0x1,		/* 24,255 */
	0xb,		/* 25,0 */
	0xb,		/* 25,1 */
	0xb,		/* 25,2 */
	0xb,		/* 25,3 */
	0xb,		/* 25,4 */
	0xb,		/* 25,5 */
	0xb,		/* 25,6 */
	0xb,		/* 25,7 */
	0xb,		/* 25,8 */
	0xb,		/* 25,9 */
	0xb,		/* 25,10 */
	0xb,		/* 25,11 */
	0xb,		/* 25,12 */
	0xb,		/* 25,13 */
	0xb,		/* 25,14 */
	0xb,		/* 25,15 */
	0xb,		/* 25,16 */
	0xb,		/* 25,17 */
	0xb,		/* 25,18 */
	0xb,		/* 25,19 */
	0xb,		/* 25,20 */
	0xb,		/* 25,21 */
	0xb,		/* 25,22 */
	0xb,		/* 25,23 */
	0xb,		/* 25,24 */
	0xb,		/* 25,25 */
	0xb,		/* 25,26 */
	0xb,		/* 25,27 */
	0xb,		/* 25,28 */
	0xb,		/* 25,29 */
	0xb,		/* 25,30 */
	0xb,		/* 25,31 */
	0xb,		/* 25,32 */
	0xb,		/* 25,33 */
	0xb,		/* 25,34 */
	0xb,		/* 25,35 */
	0xb,		/* 25,36 */
	0xb,		/* 25,37 */
	0xb,		/* 25,38 */
	0xb,		/* 25,39 */
	0xb,		/* 25,40 */
	0xb,		/* 25,41 */
	0xb,		/* 25,42 */
	0xb,		/* 25,43 */
	0xb,		/* 25,44 */
	0xb,		/* 25,45 */
	0xb,		/* 25,46 */
	0xb,		/* 25,47 */
	0xb,		/* 25,48 */
	0xb,		/* 25,49 */
	0xb,		/* 25,50 */
	0xb,		/* 25,51 */
	0xb,		/* 25,52 */
	0xb,		/* 25,53 */
	0xb,		/* 25,54 */
	0xb,		/* 25,55 */
	0xb,		/* 25,56 */
	0xb,		/* 25,57 */
	0xb,		/* 25,58 */
	0xb,		/* 25,59 */
	0xb,		/* 25,60 */
	0xb,		/* 25,61 */
	0xb,		/* 25,62 */
	0xb,		/* 25,63 */
	0xb,		/* 25,64 */
	0xb,		/* 25,65 */
	0xb,		/* 25,66 */
	0xb,		/* 25,67 */
	0xb,		/* 25,68 */
	0xb,		/* 25,69 */
	0xb,		/* 25,70 */
	0xb,		/* 25,71 */
	0xb,		/* 25,72 */
	0xb,		/* 25,73 */
	0xb,		/* 25,74 */
	0xb,		/* 25,75 */
	0xb,		/* 25,76 */
	0xb,		/* 25,77 */
	0xb,		/* 25,78 */
	0xb,		/* 25,79 */
	0xb,		/* 25,80 */
	0xb,		/* 25,81 */
	0xb,		/* 25,82 */
	0xb,		/* 25,83 */
	0xb,		/* 25,84 */
	0xb,		/* 25,85 */
	0xb,		/* 25,86 */
	0xb,		/* 25,87 */
	0xb,		/* 25,88 */
	0xb,		/* 25,89 */
	0xb,		/* 25,90 */
	0xb,		/* 25,91 */
	0xb,		/* 25,92 */
	0xb,		/* 25,93 */
	0xb,		/* 25,94 */
	0xb,		/* 25,95 */
	0xb,		/* 25,96 */
	0xb,		/* 25,97 */
	0xb,		/* 25,98 */
	0xb,		/* 25,99 */
	0xb,		/* 25,100 */
	0xb,		/* 25,101 */
	0xb,		/* 25,102 */
	0xb,		/* 25,103 */
	0xb,		/* 25,104 */
	0xb,		/* 25,105 */
	0xb,		/* 25,106 */
	0xb,		/* 25,107 */
	0xb,		/* 25,108 */
	0xb,		/* 25,109 */
	0xb,		/* 25,110 */
	0xb,		/* 25,111 */
	0xb,		/* 25,112 */
	0xb,		/* 25,113 */
	0xb,		/* 25,114 */
	0xb,		/* 25,115 */
	0xb,		/* 25,116 */
	0xb,		/* 25,117 */
	0xb,		/* 25,118 */
	0xb,		/* 25,119 */
	0xb,		/* 25,120 */
	0xb,		/* 25,121 */
	0xb,		/* 25,122 */
	0xb,		/* 25,123 */
	0xb,		/* 25,124 */
	0xb,		/* 25,125 */
	0xb,		/* 25,126 */
	0xb,		/* 25,127 */
	0xb,		/* 25,128 */
	0xb,		/* 25,129 */
	0xb,		/* 25,130 */
	0xb,		/* 25,131 */
	0xb,		/* 25,132 */
	0xb,		/* 25,133 */
	0xb,		/* 25,134 */
	0xb,		/* 25,135 */
	0xb,		/* 25,136 */
	0xb,		/* 25,137 */
	0xb,		/* 25,138 */
	0xb,		/* 25,139 */
	0xb,		/* 25,140 */
	0xb,		/* 25,141 */
	0xb,		/* 25,142 */
	0xb,		/* 25,143 */
	0xb,		/* 25,144 */
	0xb,		/* 25,145 */
	0xb,		/* 25,146 */
	0xb,		/* 25,147 */
	0xb,		/* 25,148 */
	0xb,		/* 25,149 */
	0xb,		/* 25,150 */
	0xb,		/* 25,151 */
	0xb,		/* 25,152 */
	0xb,		/* 25,153 */
	0xb,		/* 25,154 */
	0xb,		/* 25,155 */
	0xb,		/* 25,156 */
	0xb,		/* 25,157 */
	0xb,		/* 25,158 */
	0xb,		/* 25,159 */
	0xb,		/* 25,160 */
	0xb,		/* 25,161 */
	0xb,		/* 25,162 */
	0xb,		/* 25,163 */
	0x1,		/* 25,164 */
	0x1,		/* 25,165 */
	0x1,		/* 25,166 */
	0x1,		/* 25,167 */
	0x1,		/* 25,168 */
	0x1,		/* 25,169 */
	0x1,		/* 25,170 */
	0x1,		/* 25,171 */
	0x1,		/* 25,172 */
	0x1,		/* 25,173 */
	0x1,		/* 25,174 */
	0x1,		/* 25,175 */
	0x1,		/* 25,176 */
	0x1,		/* 25,177 */
	0x1,		/* 25,178 */
	0x1,		/* 25,179 */
	0x1,		/* 25,180 */
	0x1,		/* 25,181 */
	0x1,		/* 25,182 */
	0x1,		/* 25,183 */
	0x1,		/* 25,184 */
	0x1,		/* 25,185 */
	0x1,		/* 25,186 */
	0x1,		/* 25,187 */
	0x1,		/* 25,188 */
	0x1,		/* 25,189 */
	0x1,		/* 25,190 */
	0x1,		/* 25,191 */
	0x1,		/* 25,192 */
	0x1,		/* 25,193 */
	0x1,		/* 25,194 */
	0x1,		/* 25,195 */
	0x1,		/* 25,196 */
	0x1,		/* 25,197 */
	0x1,		/* 25,198 */
	0x1,		/* 25,199 */
	0x1,		/* 25,200 */
	0x1,		/* 25,201 */
	0x1,		/* 25,202 */
	0x1,		/* 25,203 */
	0x1,		/* 25,204 */
	0x1,		/* 25,205 */
	0x1,		/* 25,206 */
	0x1,		/* 25,207 */
	0x1,		/* 25,208 */
	0x1,		/* 25,209 */
	0x1,		/* 25,210 */
	0x1,		/* 25,211 */
	0x1,		/* 25,212 */
	0x1,		/* 25,213 */
	0x1,		/* 25,214 */
	0x1,		/* 25,215 */
	0x1,		/* 25,216 */
	0x1,		/* 25,217 */
	0x1,		/* 25,218 */
	0x1,		/* 25,219 */
	0x1,		/* 25,220 */
	0x1,		/* 25,221 */
	0x1,		/* 25,222 */
	0x1,		/* 25,223 */
	0x1,		/* 25,224 */
	0x1,		/* 25,225 */
	0x1,		/* 25,226 */
	0x1,		/* 25,227 */
	0x1,		/* 25,228 */
	0x1,		/* 25,229 */
	0x1,		/* 25,230 */
	0x1,		/* 25,231 */
	0x1,		/* 25,232 */
	0x1,		/* 25,233 */
	0x1,		/* 25,234 */
	0x1,		/* 25,235 */
	0x1,		/* 25,236 */
	0x1,		/* 25,237 */
	0x1,		/* 25,238 */
	0x1,		/* 25,239 */
	0x1,		/* 25,240 */
	0x1,		/* 25,241 */
	0x1,		/* 25,242 */
	0x1,		/* 25,243 */
	0x1,		/* 25,244 */
	0x1,		/* 25,245 */
	0x1,		/* 25,246 */
	0x1,		/* 25,247 */
	0x1,		/* 25,248 */
	0x1,		/* 25,249 */
	0x1,		/* 25,250 */
	0x1,		/* 25,251 */
	0x1,		/* 25,252 */
	0x1,		/* 25,253 */
	0x1,		/* 25,254 */
	0x1,		/* 25,255 */
	0x1,		/* 26,0 */
	0x1,		/* 26,1 */
	0x1,		/* 26,2 */
	0x1,		/* 26,3 */
	0x1,		/* 26,4 */
	0x1,		/* 26,5 */
	0x1,		/* 26,6 */
	0x1,		/* 26,7 */
	0x1,		/* 26,8 */
	0x1,		/* 26,9 */
	0x1,		/* 26,10 */
	0x1,		/* 26,11 */
	0x1,		/* 26,12 */
	0x1,		/* 26,13 */
	0x1,		/* 26,14 */
	0x1,		/* 26,15 */
	0x1,		/* 26,16 */
	0x1,		/* 26,17 */
	0x1,		/* 26,18 */
	0x1,		/* 26,19 */
	0x1,		/* 26,20 */
	0x1,		/* 26,21 */
	0x1,		/* 26,22 */
	0x1,		/* 26,23 */
	0x1,		/* 26,24 */
	0x1,		/* 26,25 */
	0x1,		/* 26,26 */
	0x1,		/* 26,27 */
	0x1,		/* 26,28 */
	0x1,		/* 26,29 */
	0x1,		/* 26,30 */
	0x1,		/* 26,31 */
	0x1,		/* 26,32 */
	0x1,		/* 26,33 */
	0x1,		/* 26,34 */
	0x1,		/* 26,35 */
	0x1,		/* 26,36 */
	0x1,		/* 26,37 */
	0x1,		/* 26,38 */
	0x1,		/* 26,39 */
	0x1,		/* 26,40 */
	0x1,		/* 26,41 */
	0x1,		/* 26,42 */
	0x1,		/* 26,43 */
	0x1,		/* 26,44 */
	0x1,		/* 26,45 */
	0x1,		/* 26,46 */
	0x1,		/* 26,47 */
	0x1,		/* 26,48 */
	0x1,		/* 26,49 */
	0x1,		/* 26,50 */
	0x1,		/* 26,51 */
	0x1,		/* 26,52 */
	0x1,		/* 26,53 */
	0x1,		/* 26,54 */
	0x1,		/* 26,55 */
	0x1,		/* 26,56 */
	0x1,		/* 26,57 */
	0x1,		/* 26,58 */
	0x1,		/* 26,59 */
	0x1,		/* 26,60 */
	0x1,		/* 26,61 */
	0x1,		/* 26,62 */
	0x1,		/* 26,63 */
	0x1,		/* 26,64 */
	0x1,		/* 26,65 */
	0x1,		/* 26,66 */
	0x1,		/* 26,67 */
	0x1,		/* 26,68 */
	0x1,		/* 26,69 */
	0x1,		/* 26,70 */
	0x1,		/* 26,71 */
	0x1,		/* 26,72 */
	0x1,		/* 26,73 */
	0x1,		/* 26,74 */
	0x1,		/* 26,75 */
	0x1,		/* 26,76 */
	0x1,		/* 26,77 */
	0x1,		/* 26,78 */
	0x1,		/* 26,79 */
	0x1,		/* 26,80 */
	0x1,		/* 26,81 */
	0x1,		/* 26,82 */
	0x1,		/* 26,83 */
	0x1,		/* 26,84 */
	0x1,		/* 26,85 */
	0x1,		/* 26,86 */
	0x1,		/* 26,87 */
	0x1,		/* 26,88 */
	0x1,		/* 26,89 */
	0x1,		/* 26,90 */
	0x1,		/* 26,91 */
	0x1,		/* 26,92 */
	0x1,		/* 26,93 */
	0x1,		/* 26,94 */
	0x1,		/* 26,95 */
	0x1,		/* 26,96 */
	0x1,		/* 26,97 */
	0x1,		/* 26,98 */
	0x1,		/* 26,99 */
	0x1,		/* 26,100 */
	0x1,		/* 26,101 */
	0x1,		/* 26,102 */
	0x1,		/* 26,103 */
	0x1,		/* 26,104 */
	0x1,		/* 26,105 */
	0x1,		/* 26,106 */
	0x1,		/* 26,107 */
	0x1,		/* 26,108 */
	0x1,		/* 26,109 */
	0x1,		/* 26,110 */
	0x1,		/* 26,111 */
	0x1,		/* 26,112 */
	0x1,		/* 26,113 */
	0x1,		/* 26,114 */
	0x1,		/* 26,115 */
	0x1,		/* 26,116 */
	0x1,		/* 26,117 */
	0x1,		/* 26,118 */
	0x1,		/* 26,119 */
	0x1,		/* 26,120 */
	0x1,		/* 26,121 */
	0x1,		/* 26,122 */
	0x1,		/* 26,123 */
	0x1,		/* 26,124 */
	0x1,		/* 26,125 */
	0x1,		/* 26,126 */
	0x1,		/* 26,127 */
	0x1,		/* 26,128 */
	0x1,		/* 26,129 */
	0x1,		/* 26,130 */
	0x1,		/* 26,131 */
	0x1,		/* 26,132 */
	0x1,		/* 26,133 */
	0x1,		/* 26,134 */
	0x1,		/* 26,135 */
	0x1,		/* 26,136 */
	0x1,		/* 26,137 */
	0x1,		/* 26,138 */
	0x1,		/* 26,139 */
	0x1,		/* 26,140 */
	0x1,		/* 26,141 */
	0x1,		/* 26,142 */
	0x1,		/* 26,143 */
	0x1,		/* 26,144 */
	0x1,		/* 26,145 */
	0x1,		/* 26,146 */
	0x1,		/* 26,147 */
	0x1,		/* 26,148 */
	0x1,		/* 26,149 */
	0x1,		/* 26,150 */
	0x1,		/* 26,151 */
	0x1,		/* 26,152 */
	0x1,		/* 26,153 */
	0x1,		/* 26,154 */
	0x1,		/* 26,155 */
	0x1,		/* 26,156 */
	0x1,		/* 26,157 */
	0x1,		/* 26,158 */
	0x1,		/* 26,159 */
	0x1,		/* 26,160 */
	0x1,		/* 26,161 */
	0x1,		/* 26,162 */
	0x1,		/* 26,163 */
	0x1,		/* 26,164 */
	0x1,		/* 26,165 */
	0x1,		/* 26,166 */
	0x1,		/* 26,167 */
	0x1,		/* 26,168 */
	0x1,		/* 26,169 */
	0x1,		/* 26,170 */
	0x1,		/* 26,171 */
	0x1,		/* 26,172 */
	0x1,		/* 26,173 */
	0x1,		/* 26,174 */
	0x1,		/* 26,175 */
	0x1,		/* 26,176 */
	0x1,		/* 26,177 */
	0x1,		/* 26,178 */
	0x1,		/* 26,179 */
	0x1,		/* 26,180 */
	0x1,		/* 26,181 */
	0x1,		/* 26,182 */
	0x1,		/* 26,183 */
	0x1,		/* 26,184 */
	0x1,		/* 26,185 */
	0x1,		/* 26,186 */
	0x1,		/* 26,187 */
	0x1,		/* 26,188 */
	0x1,		/* 26,189 */
	0x1,		/* 26,190 */
	0x1,		/* 26,191 */
	0x1,		/* 26,192 */
	0x1,		/* 26,193 */
	0x1,		/* 26,194 */
	0x1,		/* 26,195 */
	0x1,		/* 26,196 */
	0x1,		/* 26,197 */
	0x1,		/* 26,198 */
	0x1,		/* 26,199 */
	0x1,		/* 26,200 */
	0x1,		/* 26,201 */
	0x1,		/* 26,202 */
	0x1,		/* 26,203 */
	0x1,		/* 26,204 */
	0x1,		/* 26,205 */
	0x1,		/* 26,206 */
	0x1,		/* 26,207 */
	0x1,		/* 26,208 */
	0x1,		/* 26,209 */
	0x1,		/* 26,210 */
	0x1,		/* 26,211 */
	0x1,		/* 26,212 */
	0x1,		/* 26,213 */
	0x1,		/* 26,214 */
	0x1,		/* 26,215 */
	0x1,		/* 26,216 */
	0x1,		/* 26,217 */
	0x1,		/* 26,218 */
	0x1,		/* 26,219 */
	0x1,		/* 26,220 */
	0x1,		/* 26,221 */
	0x1,		/* 26,222 */
	0x1,		/* 26,223 */
	0x1,		/* 26,224 */
	0x1,		/* 26,225 */
	0x1,		/* 26,226 */
	0x1,		/* 26,227 */
	0x1,		/* 26,228 */
	0x1,		/* 26,229 */
	0x1,		/* 26,230 */
	0x1,		/* 26,231 */
	0x1,		/* 26,232 */
	0x1,		/* 26,233 */
	0x1,		/* 26,234 */
	0x1,		/* 26,235 */
	0x1,		/* 26,236 */
	0x1,		/* 26,237 */
	0x1,		/* 26,238 */
	0x1,		/* 26,239 */
	0x1,		/* 26,240 */
	0x1,		/* 26,241 */
	0x1,		/* 26,242 */
	0x1,		/* 26,243 */
	0x1,		/* 26,244 */
	0x1,		/* 26,245 */
	0x1,		/* 26,246 */
	0x1,		/* 26,247 */
	0x1,		/* 26,248 */
	0x1,		/* 26,249 */
	0x1,		/* 26,250 */
	0x1,		/* 26,251 */
	0x1,		/* 26,252 */
	0x1,		/* 26,253 */
	0x1,		/* 26,254 */
	0x9,		/* 26,255 */
	0x1,		/* 27,0 */
	0x1,		/* 27,1 */
	0x1,		/* 27,2 */
	0x1,		/* 27,3 */
	0x1,		/* 27,4 */
	0x1,		/* 27,5 */
	0x1,		/* 27,6 */
	0x1,		/* 27,7 */
	0x1,		/* 27,8 */
	0x1,		/* 27,9 */
	0x1,		/* 27,10 */
	0x1,		/* 27,11 */
	0x1,		/* 27,12 */
	0x1,		/* 27,13 */
	0x1,		/* 27,14 */
	0x1,		/* 27,15 */
	0x1,		/* 27,16 */
	0x1,		/* 27,17 */
	0x1,		/* 27,18 */
	0x1,		/* 27,19 */
	0x1,		/* 27,20 */
	0x1,		/* 27,21 */
	0x1,		/* 27,22 */
	0x1,		/* 27,23 */
	0x1,		/* 27,24 */
	0x1,		/* 27,25 */
	0x1,		/* 27,26 */
	0x1,		/* 27,27 */
	0x1,		/* 27,28 */
	0x1,		/* 27,29 */
	0x1,		/* 27,30 */
	0x1,		/* 27,31 */
	0x1,		/* 27,32 */
	0x1,		/* 27,33 */
	0x1,		/* 27,34 */
	0x1,		/* 27,35 */
	0x1,		/* 27,36 */
	0x1,		/* 27,37 */
	0x1,		/* 27,38 */
	0x1,		/* 27,39 */
	0x1,		/* 27,40 */
	0x1,		/* 27,41 */
	0x1,		/* 27,42 */
	0x1,		/* 27,43 */
	0x1,		/* 27,44 */
	0x1,		/* 27,45 */
	0x1,		/* 27,46 */
	0x1,		/* 27,47 */
	0x1,		/* 27,48 */
	0x1,		/* 27,49 */
	0x1,		/* 27,50 */
	0x1,		/* 27,51 */
	0x1,		/* 27,52 */
	0x1,		/* 27,53 */
	0x1,		/* 27,54 */
	0x1,		/* 27,55 */
	0x1,		/* 27,56 */
	0x1,		/* 27,57 */
	0x1,		/* 27,58 */
	0x1,		/* 27,59 */
	0x1,		/* 27,60 */
	0x1,		/* 27,61 */
	0x1,		/* 27,62 */
	0x1,		/* 27,63 */
	0x1,		/* 27,64 */
	0x1,		/* 27,65 */
	0x1,		/* 27,66 */
	0x1,		/* 27,67 */
	0x1,		/* 27,68 */
	0x1,		/* 27,69 */
	0x1,		/* 27,70 */
	0x1,		/* 27,71 */
	0x1,		/* 27,72 */
	0x1,		/* 27,73 */
	0x1,		/* 27,74 */
	0x1,		/* 27,75 */
	0x1,		/* 27,76 */
	0x1,		/* 27,77 */
	0x1,		/* 27,78 */
	0x1,		/* 27,79 */
	0x1,		/* 27,80 */
	0x1,		/* 27,81 */
	0x1,		/* 27,82 */
	0x1,		/* 27,83 */
	0x1,		/* 27,84 */
	0x1,		/* 27,85 */
	0x1,		/* 27,86 */
	0x1,		/* 27,87 */
	0x1,		/* 27,88 */
	0x1,		/* 27,89 */
	0x1,		/* 27,90 */
	0x1,		/* 27,91 */
	0x1,		/* 27,92 */
	0x1,		/* 27,93 */
	0x1,		/* 27,94 */
	0x1,		/* 27,95 */
	0x1,		/* 27,96 */
	0x1,		/* 27,97 */
	0x1,		/* 27,98 */
	0x1,		/* 27,99 */
	0x1,		/* 27,100 */
	0x1,		/* 27,101 */
	0x1,		/* 27,102 */
	0x1,		/* 27,103 */
	0x1,		/* 27,104 */
	0x1,		/* 27,105 */
	0x1,		/* 27,106 */
	0x1,		/* 27,107 */
	0x1,		/* 27,108 */
	0x1,		/* 27,109 */
	0x1,		/* 27,110 */
	0x1,		/* 27,111 */
	0x1,		/* 27,112 */
	0x1,		/* 27,113 */
	0x1,		/* 27,114 */
	0x1,		/* 27,115 */
	0x1,		/* 27,116 */
	0x1,		/* 27,117 */
	0x1,		/* 27,118 */
	0x1,		/* 27,119 */
	0x1,		/* 27,120 */
	0x1,		/* 27,121 */
	0x1,		/* 27,122 */
	0x1,		/* 27,123 */
	0x1,		/* 27,124 */
	0x1,		/* 27,125 */
	0x1,		/* 27,126 */
	0x1,		/* 27,127 */
	0x1,		/* 27,128 */
	0x1,		/* 27,129 */
	0x1,		/* 27,130 */
	0x1,		/* 27,131 */
	0x1,		/* 27,132 */
	0x1,		/* 27,133 */
	0x1,		/* 27,134 */
	0x1,		/* 27,135 */
	0x1,		/* 27,136 */
	0x1,		/* 27,137 */
	0x1,		/* 27,138 */
	0x1,		/* 27,139 */
	0x1,		/* 27,140 */
	0x1,		/* 27,141 */
	0x1,		/* 27,142 */
	0x1,		/* 27,143 */
	0x1,		/* 27,144 */
	0x1,		/* 27,145 */
	0x1,		/* 27,146 */
	0x1,		/* 27,147 */
	0x1,		/* 27,148 */
	0x1,		/* 27,149 */
	0x1,		/* 27,150 */
	0x1,		/* 27,151 */
	0x1,		/* 27,152 */
	0x1,		/* 27,153 */
	0x1,		/* 27,154 */
	0x1,		/* 27,155 */
	0x1,		/* 27,156 */
	0x1,		/* 27,157 */
	0x1,		/* 27,158 */
	0x1,		/* 27,159 */
	0x1,		/* 27,160 */
	0x1,		/* 27,161 */
	0x1,		/* 27,162 */
	0x1,		/* 27,163 */
	0x1,		/* 27,164 */
	0x1,		/* 27,165 */
	0x1,		/* 27,166 */
	0x1,		/* 27,167 */
	0x1,		/* 27,168 */
	0x1,		/* 27,169 */
	0x1,		/* 27,170 */
	0x1,		/* 27,171 */
	0x1,		/* 27,172 */
	0x1,		/* 27,173 */
	0x1,		/* 27,174 */
	0x1,		/* 27,175 */
	0x1,		/* 27,176 */
	0x1,		/* 27,177 */
	0x1,		/* 27,178 */
	0x1,		/* 27,179 */
	0x1,		/* 27,180 */
	0x1,		/* 27,181 */
	0x1,		/* 27,182 */
	0x1,		/* 27,183 */
	0x1,		/* 27,184 */
	0x1,		/* 27,185 */
	0x1,		/* 27,186 */
	0x1,		/* 27,187 */
	0x1,		/* 27,188 */
	0x1,		/* 27,189 */
	0x1,		/* 27,190 */
	0x1,		/* 27,191 */
	0x1,		/* 27,192 */
	0x1,		/* 27,193 */
	0x1,		/* 27,194 */
	0x1,		/* 27,195 */
	0x1,		/* 27,196 */
	0x1,		/* 27,197 */
	0x1,		/* 27,198 */
	0x1,		/* 27,199 */
	0x1,		/* 27,200 */
	0x1,		/* 27,201 */
	0x1,		/* 27,202 */
	0x1,		/* 27,203 */
	0x1,		/* 27,204 */
	0x1,		/* 27,205 */
	0x1,		/* 27,206 */
	0x1,		/* 27,207 */
	0x1,		/* 27,208 */
	0x1,		/* 27,209 */
	0x1,		/* 27,210 */
	0x1,		/* 27,211 */
	0x1,		/* 27,212 */
	0x1,		/* 27,213 */
	0x1,		/* 27,214 */
	0x1,		/* 27,215 */
	0x1,		/* 27,216 */
	0x1,		/* 27,217 */
	0x1,		/* 27,218 */
	0x1,		/* 27,219 */
	0x1,		/* 27,220 */
	0x1,		/* 27,221 */
	0x1,		/* 27,222 */
	0x1,		/* 27,223 */
	0x1,		/* 27,224 */
	0x1,		/* 27,225 */
	0x1,		/* 27,226 */
	0x1,		/* 27,227 */
	0x1,		/* 27,228 */
	0x1,		/* 27,229 */
	0x1,		/* 27,230 */
	0x1,		/* 27,231 */
	0x1,		/* 27,232 */
	0x1,		/* 27,233 */
	0x1,		/* 27,234 */
	0x1,		/* 27,235 */
	0x1,		/* 27,236 */
	0x1,		/* 27,237 */
	0x1,		/* 27,238 */
	0x1,		/* 27,239 */
	0x1,		/* 27,240 */
	0x1,		/* 27,241 */
	0x1,		/* 27,242 */
	0x1,		/* 27,243 */
	0x1,		/* 27,244 */
	0x1,		/* 27,245 */
	0x1,		/* 27,246 */
	0x1,		/* 27,247 */
	0x1,		/* 27,248 */
	0x1,		/* 27,249 */
	0x1,		/* 27,250 */
	0x1,		/* 27,251 */
	0x1,		/* 27,252 */
	0x1,		/* 27,253 */
	0x0,		/* 27,254 */
	0x0,		/* 27,255 */
    };
    static final int s_blocks[] = {
	0,		/* 0x000 - 0x0ff */
	1,		/* 0x100 - 0x1ff */
	2,		/* 0x200 - 0x2ff */
	3,		/* 0x300 - 0x3ff */
	4,		/* 0x400 - 0x4ff */
	5,		/* 0x500 - 0x5ff */
	6,		/* 0x600 - 0x6ff */
	7,		/* 0x700 - 0x7ff */
	7,		/* 0x800 - 0x8ff */
	8,		/* 0x900 - 0x9ff */
	9,		/* 0xa00 - 0xaff */
	10,		/* 0xb00 - 0xbff */
	11,		/* 0xc00 - 0xcff */
	12,		/* 0xd00 - 0xdff */
	13,		/* 0xe00 - 0xeff */
	14,		/* 0xf00 - 0xfff */
	15,		/* 0x1000 - 0x10ff */
	16,		/* 0x1100 - 0x11ff */
	7,		/* 0x1200 - 0x12ff */
	7,		/* 0x1300 - 0x13ff */
	7,		/* 0x1400 - 0x14ff */
	7,		/* 0x1500 - 0x15ff */
	7,		/* 0x1600 - 0x16ff */
	7,		/* 0x1700 - 0x17ff */
	7,		/* 0x1800 - 0x18ff */
	7,		/* 0x1900 - 0x19ff */
	7,		/* 0x1a00 - 0x1aff */
	7,		/* 0x1b00 - 0x1bff */
	7,		/* 0x1c00 - 0x1cff */
	7,		/* 0x1d00 - 0x1dff */
	17,		/* 0x1e00 - 0x1eff */
	18,		/* 0x1f00 - 0x1fff */
	19,		/* 0x2000 - 0x20ff */
	20,		/* 0x2100 - 0x21ff */
	7,		/* 0x2200 - 0x22ff */
	7,		/* 0x2300 - 0x23ff */
	7,		/* 0x2400 - 0x24ff */
	7,		/* 0x2500 - 0x25ff */
	7,		/* 0x2600 - 0x26ff */
	7,		/* 0x2700 - 0x27ff */
	7,		/* 0x2800 - 0x28ff */
	7,		/* 0x2900 - 0x29ff */
	7,		/* 0x2a00 - 0x2aff */
	7,		/* 0x2b00 - 0x2bff */
	7,		/* 0x2c00 - 0x2cff */
	7,		/* 0x2d00 - 0x2dff */
	7,		/* 0x2e00 - 0x2eff */
	7,		/* 0x2f00 - 0x2fff */
	21,		/* 0x3000 - 0x30ff */
	22,		/* 0x3100 - 0x31ff */
	7,		/* 0x3200 - 0x32ff */
	7,		/* 0x3300 - 0x33ff */
	7,		/* 0x3400 - 0x34ff */
	7,		/* 0x3500 - 0x35ff */
	7,		/* 0x3600 - 0x36ff */
	7,		/* 0x3700 - 0x37ff */
	7,		/* 0x3800 - 0x38ff */
	7,		/* 0x3900 - 0x39ff */
	7,		/* 0x3a00 - 0x3aff */
	7,		/* 0x3b00 - 0x3bff */
	7,		/* 0x3c00 - 0x3cff */
	7,		/* 0x3d00 - 0x3dff */
	7,		/* 0x3e00 - 0x3eff */
	7,		/* 0x3f00 - 0x3fff */
	7,		/* 0x4000 - 0x40ff */
	7,		/* 0x4100 - 0x41ff */
	7,		/* 0x4200 - 0x42ff */
	7,		/* 0x4300 - 0x43ff */
	7,		/* 0x4400 - 0x44ff */
	7,		/* 0x4500 - 0x45ff */
	7,		/* 0x4600 - 0x46ff */
	7,		/* 0x4700 - 0x47ff */
	7,		/* 0x4800 - 0x48ff */
	7,		/* 0x4900 - 0x49ff */
	7,		/* 0x4a00 - 0x4aff */
	7,		/* 0x4b00 - 0x4bff */
	7,		/* 0x4c00 - 0x4cff */
	7,		/* 0x4d00 - 0x4dff */
	23,		/* 0x4e00 - 0x4eff */
	23,		/* 0x4f00 - 0x4fff */
	23,		/* 0x5000 - 0x50ff */
	23,		/* 0x5100 - 0x51ff */
	23,		/* 0x5200 - 0x52ff */
	23,		/* 0x5300 - 0x53ff */
	23,		/* 0x5400 - 0x54ff */
	23,		/* 0x5500 - 0x55ff */
	23,		/* 0x5600 - 0x56ff */
	23,		/* 0x5700 - 0x57ff */
	23,		/* 0x5800 - 0x58ff */
	23,		/* 0x5900 - 0x59ff */
	23,		/* 0x5a00 - 0x5aff */
	23,		/* 0x5b00 - 0x5bff */
	23,		/* 0x5c00 - 0x5cff */
	23,		/* 0x5d00 - 0x5dff */
	23,		/* 0x5e00 - 0x5eff */
	23,		/* 0x5f00 - 0x5fff */
	23,		/* 0x6000 - 0x60ff */
	23,		/* 0x6100 - 0x61ff */
	23,		/* 0x6200 - 0x62ff */
	23,		/* 0x6300 - 0x63ff */
	23,		/* 0x6400 - 0x64ff */
	23,		/* 0x6500 - 0x65ff */
	23,		/* 0x6600 - 0x66ff */
	23,		/* 0x6700 - 0x67ff */
	23,		/* 0x6800 - 0x68ff */
	23,		/* 0x6900 - 0x69ff */
	23,		/* 0x6a00 - 0x6aff */
	23,		/* 0x6b00 - 0x6bff */
	23,		/* 0x6c00 - 0x6cff */
	23,		/* 0x6d00 - 0x6dff */
	23,		/* 0x6e00 - 0x6eff */
	23,		/* 0x6f00 - 0x6fff */
	23,		/* 0x7000 - 0x70ff */
	23,		/* 0x7100 - 0x71ff */
	23,		/* 0x7200 - 0x72ff */
	23,		/* 0x7300 - 0x73ff */
	23,		/* 0x7400 - 0x74ff */
	23,		/* 0x7500 - 0x75ff */
	23,		/* 0x7600 - 0x76ff */
	23,		/* 0x7700 - 0x77ff */
	23,		/* 0x7800 - 0x78ff */
	23,		/* 0x7900 - 0x79ff */
	23,		/* 0x7a00 - 0x7aff */
	23,		/* 0x7b00 - 0x7bff */
	23,		/* 0x7c00 - 0x7cff */
	23,		/* 0x7d00 - 0x7dff */
	23,		/* 0x7e00 - 0x7eff */
	23,		/* 0x7f00 - 0x7fff */
	23,		/* 0x8000 - 0x80ff */
	23,		/* 0x8100 - 0x81ff */
	23,		/* 0x8200 - 0x82ff */
	23,		/* 0x8300 - 0x83ff */
	23,		/* 0x8400 - 0x84ff */
	23,		/* 0x8500 - 0x85ff */
	23,		/* 0x8600 - 0x86ff */
	23,		/* 0x8700 - 0x87ff */
	23,		/* 0x8800 - 0x88ff */
	23,		/* 0x8900 - 0x89ff */
	23,		/* 0x8a00 - 0x8aff */
	23,		/* 0x8b00 - 0x8bff */
	23,		/* 0x8c00 - 0x8cff */
	23,		/* 0x8d00 - 0x8dff */
	23,		/* 0x8e00 - 0x8eff */
	23,		/* 0x8f00 - 0x8fff */
	23,		/* 0x9000 - 0x90ff */
	23,		/* 0x9100 - 0x91ff */
	23,		/* 0x9200 - 0x92ff */
	23,		/* 0x9300 - 0x93ff */
	23,		/* 0x9400 - 0x94ff */
	23,		/* 0x9500 - 0x95ff */
	23,		/* 0x9600 - 0x96ff */
	23,		/* 0x9700 - 0x97ff */
	23,		/* 0x9800 - 0x98ff */
	23,		/* 0x9900 - 0x99ff */
	23,		/* 0x9a00 - 0x9aff */
	23,		/* 0x9b00 - 0x9bff */
	23,		/* 0x9c00 - 0x9cff */
	23,		/* 0x9d00 - 0x9dff */
	23,		/* 0x9e00 - 0x9eff */
	24,		/* 0x9f00 - 0x9fff */
	7,		/* 0xa000 - 0xa0ff */
	7,		/* 0xa100 - 0xa1ff */
	7,		/* 0xa200 - 0xa2ff */
	7,		/* 0xa300 - 0xa3ff */
	7,		/* 0xa400 - 0xa4ff */
	7,		/* 0xa500 - 0xa5ff */
	7,		/* 0xa600 - 0xa6ff */
	7,		/* 0xa700 - 0xa7ff */
	7,		/* 0xa800 - 0xa8ff */
	7,		/* 0xa900 - 0xa9ff */
	7,		/* 0xaa00 - 0xaaff */
	7,		/* 0xab00 - 0xabff */
	23,		/* 0xac00 - 0xacff */
	23,		/* 0xad00 - 0xadff */
	23,		/* 0xae00 - 0xaeff */
	23,		/* 0xaf00 - 0xafff */
	23,		/* 0xb000 - 0xb0ff */
	23,		/* 0xb100 - 0xb1ff */
	23,		/* 0xb200 - 0xb2ff */
	23,		/* 0xb300 - 0xb3ff */
	23,		/* 0xb400 - 0xb4ff */
	23,		/* 0xb500 - 0xb5ff */
	23,		/* 0xb600 - 0xb6ff */
	23,		/* 0xb700 - 0xb7ff */
	23,		/* 0xb800 - 0xb8ff */
	23,		/* 0xb900 - 0xb9ff */
	23,		/* 0xba00 - 0xbaff */
	23,		/* 0xbb00 - 0xbbff */
	23,		/* 0xbc00 - 0xbcff */
	23,		/* 0xbd00 - 0xbdff */
	23,		/* 0xbe00 - 0xbeff */
	23,		/* 0xbf00 - 0xbfff */
	23,		/* 0xc000 - 0xc0ff */
	23,		/* 0xc100 - 0xc1ff */
	23,		/* 0xc200 - 0xc2ff */
	23,		/* 0xc300 - 0xc3ff */
	23,		/* 0xc400 - 0xc4ff */
	23,		/* 0xc500 - 0xc5ff */
	23,		/* 0xc600 - 0xc6ff */
	23,		/* 0xc700 - 0xc7ff */
	23,		/* 0xc800 - 0xc8ff */
	23,		/* 0xc900 - 0xc9ff */
	23,		/* 0xca00 - 0xcaff */
	23,		/* 0xcb00 - 0xcbff */
	23,		/* 0xcc00 - 0xccff */
	23,		/* 0xcd00 - 0xcdff */
	23,		/* 0xce00 - 0xceff */
	23,		/* 0xcf00 - 0xcfff */
	23,		/* 0xd000 - 0xd0ff */
	23,		/* 0xd100 - 0xd1ff */
	23,		/* 0xd200 - 0xd2ff */
	23,		/* 0xd300 - 0xd3ff */
	23,		/* 0xd400 - 0xd4ff */
	23,		/* 0xd500 - 0xd5ff */
	23,		/* 0xd600 - 0xd6ff */
	25,		/* 0xd700 - 0xd7ff */
	7,		/* 0xd800 - 0xd8ff */
	7,		/* 0xd900 - 0xd9ff */
	7,		/* 0xda00 - 0xdaff */
	7,		/* 0xdb00 - 0xdbff */
	7,		/* 0xdc00 - 0xdcff */
	7,		/* 0xdd00 - 0xddff */
	7,		/* 0xde00 - 0xdeff */
	7,		/* 0xdf00 - 0xdfff */
	7,		/* 0xe000 - 0xe0ff */
	7,		/* 0xe100 - 0xe1ff */
	7,		/* 0xe200 - 0xe2ff */
	7,		/* 0xe300 - 0xe3ff */
	7,		/* 0xe400 - 0xe4ff */
	7,		/* 0xe500 - 0xe5ff */
	7,		/* 0xe600 - 0xe6ff */
	7,		/* 0xe700 - 0xe7ff */
	7,		/* 0xe800 - 0xe8ff */
	7,		/* 0xe900 - 0xe9ff */
	7,		/* 0xea00 - 0xeaff */
	7,		/* 0xeb00 - 0xebff */
	7,		/* 0xec00 - 0xecff */
	7,		/* 0xed00 - 0xedff */
	7,		/* 0xee00 - 0xeeff */
	7,		/* 0xef00 - 0xefff */
	7,		/* 0xf000 - 0xf0ff */
	7,		/* 0xf100 - 0xf1ff */
	7,		/* 0xf200 - 0xf2ff */
	7,		/* 0xf300 - 0xf3ff */
	7,		/* 0xf400 - 0xf4ff */
	7,		/* 0xf500 - 0xf5ff */
	7,		/* 0xf600 - 0xf6ff */
	7,		/* 0xf700 - 0xf7ff */
	7,		/* 0xf800 - 0xf8ff */
	7,		/* 0xf900 - 0xf9ff */
	7,		/* 0xfa00 - 0xfaff */
	7,		/* 0xfb00 - 0xfbff */
	7,		/* 0xfc00 - 0xfcff */
	7,		/* 0xfd00 - 0xfdff */
	26,		/* 0xfe00 - 0xfeff */
	27,		/* 0xff00 - 0xffff */
    };
}
